@@ -25,6 +25,7 @@ DAEMON_ARGS="$DAEMON_ARGS -www 8080"
 DAEMON_ARGS="$DAEMON_ARGS -sslwww 443"
 #DAEMON_ARGS="$DAEMON_ARGS -log /tmp/domoticz.txt"
 #DAEMON_ARGS="$DAEMON_ARGS -syslog"
+#export PYTHONPATH=/home/pi/Domoticz_Python_Env:$PYTHONPATH
 
 # Exit if the package is not installed
 [ -x "$DAEMON" ] || exit 0
@@ -53,15 +54,52 @@ pidof_domoticz() {
 #
 do_start()
 {
-        # Return
-        #   0 if daemon has been started
-        #   1 if daemon was already running
-        #   2 if daemon could not be started
-        start-stop-daemon --chuid $USERNAME --start --quiet --pidfile $PIDFILE --exec $DAEMON --test > /dev/null \
-                || return 1
-        start-stop-daemon --start --quiet --pidfile $PIDFILE --exec $DAEMON -- \
-                $DAEMON_ARGS \
-                || return 2
+	# Script that waits for time synchronisation before starting Domoticz to prevent a crash
+	# on a cold boot when no real time clock is available.
+
+	# Check if systemd-timesyncd is enabled and running, otherwise ignore script
+	if systemctl --quiet is-enabled systemd-timesyncd && systemctl --quiet is-active systemd-timesyncd; then
+	    # Check if time is already synced, if so start Domoticz immediately
+	    if [ -f "/run/systemd/timesync/synchronized" ]; then
+		printf "Time synchronized, starting Domoticz...\n"
+	    else
+		# Check if custom time server(s) are defined
+		if grep -q "^#NTP=" /etc/systemd/timesyncd.conf; then
+		    printf "INFO: No time server(s) defined in /etc/systemd/timesyncd.conf, using default fallback server(s)\n"
+		fi
+		# Wait a maximum of 30 seconds until sync file is generated indicating successful time sync
+		printf "Waiting for time synchronization before starting Domoticz"
+		count=30
+		while [ ! -f "/run/systemd/timesync/synchronized" ]
+		do
+		    count=$((count-1))
+		    if [ $((count)) -lt 1 ]
+		    then
+			# If failed, print error message, exit loop and start Domoticz anyway
+			printf "\nWARNING: Time synchronization failed, check network and /etc/systemd/timesyncd.conf\n"
+			printf "Starting Domoticz without successful time synchronization...\n"
+			break
+		    fi
+		    printf "."
+		    sleep 1
+		done
+		#If the file was found in time, sync was successful and Domoticz will start immediately
+		if [ -f "/run/systemd/timesync/synchronized" ]
+		then
+		    printf "\nTime synchronization successful, starting Domoticz...\n"
+		fi
+	    fi
+	fi
+
+	# Return
+	#   0 if daemon has been started
+	#   1 if daemon was already running
+	#   2 if daemon could not be started
+	start-stop-daemon --chuid $USERNAME --start --quiet --pidfile $PIDFILE --exec $DAEMON --test > /dev/null \
+		|| return 1
+	start-stop-daemon --start --quiet --pidfile $PIDFILE --exec $DAEMON -- \
+		$DAEMON_ARGS \
+		|| return 2
 }
 
 #
