@@ -1,4 +1,3 @@
-local _ = require('lodash')
 local evenItemIdentifier = require('eventItemIdentifier')
 
 local eventMapping = {
@@ -7,12 +6,14 @@ local eventMapping = {
 	backupDoneHour = 'hourlyBackupFinished',
 	backupDoneMonth = 'monthlyBackupFinished',
 	start = 'start',
-	stop = 'stop'
+	stop = 'stop',
+	resetAllEvents = 'resetAllEvents',
+	resetAllDeviceStatus = 'resetAllDeviceStatus',
 }
 
 local function SystemEvent(domoticz, eventData)
 
-	-- eventData: {["message"]="", ["status"]="info", ["baseType"]="system", ["type"]="domoticzStart"}
+	-- eventData: {["message"]="", ["status"]="info", ["type"]="domoticzStart"}
 
 	local self = {}
 
@@ -23,10 +24,14 @@ local function SystemEvent(domoticz, eventData)
 	self.duration = eventData.data and eventData.data.duration or nil
 	self.location = eventData.data and eventData.data.location or nil
 
+	function self.dump( filename )
+		domoticz.logObject(self, filename, 'systemEvent')
+	end
+
 	evenItemIdentifier.setType(
 		self,
 		'isSystemEvent',
-		domoticz.BASE_TYPE_SYSTEM_EVENT,
+		domoticz.BASETYPE_SYSTEM_EVENT,
 		eventMapping[eventData.type]
 	)
 
