@@ -2,13 +2,13 @@ local jsonParser = require('JSON')
 local _ = require('lodash')
 
 local self = {
-	LOG_ERROR = 1,
-	LOG_FORCE = 0.5,
+	LOG_DEBUG = 1,
 	LOG_MODULE_EXEC_INFO = 2,
 	LOG_INFO = 3,
-	LOG_WARNING = 3,
-	LOG_DEBUG = 4,
-	DZVERSION = '3.1.7',
+	LOG_STATUS = 4,
+	LOG_ERROR = 5,
+	LOG_FORCE = 6,
+	DZVERSION = '3.1.10',
 }
 
 function jsonParser:unsupportedTypeEncoder(value_of_unsupported_type)
@@ -146,6 +146,19 @@ function self.stringSplit(text, sep, convertNumber, convertNil)
 	return t
 end
 
+function self.splitLine (line, word)
+	local start = 1
+	local first, last = 0
+	local t = {}
+	while true do
+		first, last = line:find('%s+'.. word .. '%s+', start)
+		table.insert(t,line:sub(start, ( ( first and first - 1) or #line)))
+		if not first then break end
+		start = last + 1
+	end
+	return t
+end
+
 function self.stringToSeconds(str)
 
 	local now = os.date('*t')
@@ -465,8 +478,10 @@ function self.toJSON(luaTable)
 end
 
 function self.log(msg, level)
-
-	if (level == nil) then level = self.LOG_INFO end
+    -- self.print(msg .. ', level=' .. level)
+	if (level == nil) then
+		level = self.LOG_INFO
+	end
 
 	if (type(level) ~= 'number') then
 		self.print('Error: log level is not a number. Got: ' .. tostring(level) .. ', type: ' .. type(level))
@@ -474,29 +489,36 @@ function self.log(msg, level)
 	end
 
 	local lLevel = _G.logLevel == nil and 1 or _G.logLevel
-	local marker = ''
 
-	if (level == self.LOG_ERROR) then
-		marker = marker .. 'Error: (' .. self.DZVERSION .. ') '
+	msg = self.toStr(msg)
+
+	-- print('level: ' .. level .. ',lLevel: ' .. lLevel .. ', msg: ' .. msg)
+
+	if (level < lLevel) then
+		return
+	end
+
+	local marker = ''
+	
+	if (level == self.LOG_INFO) then
+		marker = 'Info: '
+	elseif (level == self.LOG_STATUS) then
+		marker = 'Status: '
+	elseif (level == self.LOG_ERROR) then
+		marker = 'Error: '
 	elseif (level == self.LOG_DEBUG) then
-		marker = marker .. 'Debug: '
-	elseif (level == self.LOG_INFO or level == self.LOG_MODULE_EXEC_INFO) then
-		marker = marker .. 'Info: '
+		marker = 'Debug: '
+	elseif (level == self.LOG_MODULE_EXEC_INFO) then
+		marker = 'Exec: '
 	elseif (level == self.LOG_FORCE) then
-		marker = marker .. '!Info: '
+		marker = '!Info: '
 	end
 
 	if (_G.logMarker ~= nil) then
 		marker = marker .. _G.logMarker .. ': '
 	end
 
-	if (level <= lLevel) then
-		local maxLength = 6000 -- limit 3 * 2048 hardCoded in main/Logger.cpp
-		msg = self.toStr(msg)
-		for i = 1, #msg, maxLength do
-			self.print( marker .. msg:sub(i, i + maxLength - 1 ) )
-		end
-	end
+	self.print( marker .. msg )
 end
 
 function self.rgbToHSB(r, g, b)
