@@ -1008,7 +1008,7 @@ local testThermostatSetpoint = function(name)
 		["setPoint"] = 20.5,
 		["baseType"] = dz.BASETYPE_DEVICE,
 		["deviceSubType"] = "SetPoint";
-		["deviceType"] = "Thermostat";
+		["deviceType"] = "Setpoint";
 		["hardwareType"] = "Dummy (Does nothing, use for virtual switches only)";
 		["hardwareName"] = "dummy";
 		["hardwareTypeValue"] = 15;
