@@ -2,12 +2,11 @@
 #include "1WireSystem.h"
 #include <condition_variable>
 #include <list>
-#include "../../main/StoppableTask.h"
 
 class C1WireByKernel : public I_1WireSystem, StoppableTask
 {
 public:
-   C1WireByKernel();
+   C1WireByKernel(C1Wire *C1WareBase);
    ~C1WireByKernel() override;
 
    // I_1WireSystem implementation
