@@ -4,50 +4,24 @@
 #include "../main/json_helper.h"
 #include "../main/Helper.h"
 #include "../main/HTMLSanitizer.h"
-#include "../main/localtime_r.h"
 #include "../main/Logger.h"
 #include "../main/mainworker.h"
 #include "../main/SQLHelper.h"
 #include "../main/WebServer.h"
 #include "../httpclient/HTTPClient.h"
 
-struct STR_DEVICE {
-	int			unit;
-	const char *api_name;
-	const char *name;
-	int			deviceID;
-	uint8_t		subType;
-	int			switchType;
-	const char *api_state;
-};
-
-constexpr std::array<STR_DEVICE, 9> DevicesType{
-	{
-		{ 0, "switchBox", "Switch Box", pTypeLighting2, sTypeAC, STYPE_OnOff, "relay" },
-		{ 1, "shutterBox", "Shutter Box", pTypeLighting2, sTypeAC, STYPE_BlindsPercentageInverted, "shutter" },
-		{ 2, "wLightBoxS", "Light Box S", pTypeLighting2, sTypeAC, STYPE_Dimmer, "light" },
-		{ 3, "wLightBox", "Light Box", pTypeColorSwitch, sTypeColor_RGB_W, STYPE_Dimmer, "rgbw" },
-		{ 4, "gateBox", "Gate Box", pTypeGeneral, sTypePercentage, 0, "gate" },
-		{ 5, "dimmerBox", "Dimmer Box", pTypeLighting2, sTypeAC, STYPE_Dimmer, "dimmer" },
-		{ 6, "switchBoxD", "Switch Box D", pTypeLighting2, sTypeAC, STYPE_OnOff, "relay" },
-		{ 7, "airSensor", "Air Sensor", pTypeAirQuality, sTypeVoltcraft, 0, "air" },
-		{ 8, "tempSensor", "Temp Sensor", pTypeGeneral, sTypeTemperature, 0, "tempsensor" },
-	},
-};
-
-BleBox::BleBox(const int id, const int pollIntervalsec)
+BleBox::BleBox(const int id, const int pollIntervalsec, int showRSSI)
 {
 	m_HwdID = id;
-	m_RGBWisWhiteState = true;
-	m_RGBWbrightnessState = 255;
-	SetSettings(pollIntervalsec);
+
+	SetSettings(pollIntervalsec, showRSSI);
 }
 
 bool BleBox::StartHardware()
 {
 	RequestStart();
 
-	LoadNodes();
+	ReloadNodes();
 
 	m_thread = std::make_shared<std::thread>([this] { Do_Work(); });
 	SetThreadNameInt(m_thread->native_handle());
@@ -94,222 +68,206 @@ void BleBox::GetDevicesState()
 {
 	std::lock_guard<std::mutex> l(m_mutex);
 
-	for (const auto &device : m_devices)
+	for (const auto& device : m_devices)
 	{
+
 		std::stringstream sstr;
-		sstr << "/api/" << DevicesType[device.second].api_state << "/state";
+		sstr << "/api/" << DevicesType[device.bleBoxTypeId].api_state << "/state";
 		std::string command = sstr.str();
 
-		Json::Value root = SendCommand(device.first, command, 2);
+		Json::Value root = SendCommand(device.addressIP, command, 2);
 		if (root.empty())
 			continue;
 
-		int IP = IPToUInt(device.first);
-		if (IP != 0)
+		int deviceID = IPToInt(device.addressIP);
+
+		int signalQuality = 12;
+		if (m_ShowRSSI == 2)
 		{
-			switch (device.second)
+			int rssi = GetRSSI(device.addressIP);
+			if (rssi != 0)
 			{
-				case 1:
-				{
-					if (DoesNodeExists(root, "shutter") == false)
-						break;
-
-					root = root["shutter"];
-
-					if (DoesNodeExists(root, "state") == false)
-						break;
-
-					const int state = root["state"].asInt();
-
-					if (DoesNodeExists(root, "currentPos", "position") == false)
-						break;
-
-					const int currentPos = root["currentPos"]["position"].asInt();
-					const int pos = currentPos;
-
-					bool opened = true;
-					if ((state == 2 && pos == 100) || (state == 3))
-						opened = false;
-
-					SendSwitch(IP, 0, 255, opened, 100 - pos, DevicesType[device.second].name);
-					break;
-				}
-				case 2:
-				{
-					if (DoesNodeExists(root, "light", "currentColor") == false)
-						break;
-
-					const std::string currentColor = root["light"]["currentColor"].asString();
-					unsigned int hexNumber;
-					sscanf(currentColor.c_str(), "%x", &hexNumber);
-					int level = (int)(hexNumber / (255.0 / 100.0));
-
-					SendSwitch(IP, 0, 255, level > 0, level, DevicesType[device.second].name);
-					break;
-				}
-				case 3:
-				{
-					if (DoesNodeExists(root, "rgbw", "currentColor") == false)
-						break;
-
-					const std::string currentColor = root["rgbw"]["currentColor"].asString();
-					unsigned int hexNumber;
-					sscanf(currentColor.c_str(), "%x", &hexNumber);
-
-					SendRGBWSwitch(IP, 0, 255, hexNumber, true, DevicesType[device.second].name, m_Name);
-					break;
-				}
-				case 4:
-				{
-					if (DoesNodeExists(root, "currentPos") == false)
-						break;
-
-					const float level = root["currentPos"].asFloat();
-
-					SendPercentageSensor(IP, 1, 255, level, DevicesType[device.second].name);
-					break;
-				}
-				case 5:
-				{
-					if (DoesNodeExists(root, "dimmer", "currentBrightness") == false)
-						break;
-
-					const int currentPos = root["dimmer"]["currentBrightness"].asInt();
-					int level = (int)(currentPos / (255.0 / 100.0));
-
-					SendSwitch(IP, 0, 255, level > 0, level, DevicesType[device.second].name);
-					break;
-				}
-				case 0:
-				case 6:
-				{
-					if ((DoesNodeExists(root, "relays") == false) || (!root["relays"].isArray()))
-						break;
-
-					for (const auto &relay : root["relays"])
-					{
-						if ((DoesNodeExists(relay, "relay") == false) || (DoesNodeExists(relay, "state") == false))
-							break;
-						uint8_t relayNumber = (uint8_t)relay["relay"].asInt(); // 0 or 1
-						bool currentState = relay["state"].asBool();	       // 0 or 1
-						// std::string name = DevicesType[device.second].name + " " + relay["state"].asString();
-						SendSwitch(IP, relayNumber, 255, currentState, 0, DevicesType[device.second].name);
-					}
-
-					break;
-				}
-				case 7:
-				{
-					if (DoesNodeExists(root, "air") == false)
-						break;
-
-					root = root["air"];
-
-					if ((DoesNodeExists(root, "sensors") == false) || (!root["sensors"].isArray()))
-						break;
-
-					Json::Value sensors = root["sensors"];
-					Json::ArrayIndex count = sensors.size();
-					for (Json::ArrayIndex index = 0; index < count; index++)
-					{
-						Json::Value sensor = sensors[index];
-						if ((DoesNodeExists(sensor, "type") == false) || (DoesNodeExists(sensor, "value") == false))
-							break;
-						uint8_t value = (uint8_t)sensor["value"].asInt();
-						std::string type = sensor["type"].asString();
-
-						// TODO - how save IP address ??
-						SendAirQualitySensor(IP, index + 1, 255, value, type);
-					}
-
-					break;
-				}
-				case 8:
-				{
-					if (DoesNodeExists(root, "tempSensor") == false)
-						break;
-
-					root = root["tempSensor"];
-
-					if ((DoesNodeExists(root, "sensors") == false) || (!root["sensors"].isArray()))
-						break;
-
-					for (const auto &sensor : root["sensors"])
-					{
-						if ((DoesNodeExists(sensor, "value") == false)
-						    || (DoesNodeExists(sensor, "state") == false))
-							break;
-
-						if (sensor["state"] != 2)
-						{
-							Log(LOG_ERROR, "temp sensor error!");
-							break;
-						}
-
-						std::string temperature = sensor["value"].asString(); // xxxx (xx.xx = temperature)
-						float ftemp = static_cast<float>(std::stoi(temperature.substr(0, 2))
-										 + std::stoi(temperature.substr(2, 2)) / 100.0);
-
-						// TODO - how save IP address ??
-						SendTempSensor(IP, 255, ftemp, DevicesType[device.second].name);
-					}
-
-					break;
-				}
+				signalQuality = RSSIToQuality(rssi);
 			}
-			SetHeartbeatReceived();
+		}
+
+
+		switch (device.bleBoxTypeId)
+		{
+		case 1:
+		{
+			if (DoesNodeExists(root, "shutter") == false)
+				break;
+
+			root = root["shutter"];
+
+			if (DoesNodeExists(root, "state") == false)
+				break;
+
+			const int state = root["state"].asInt();
+
+			if (DoesNodeExists(root, "currentPos", "position") == false)
+				break;
+
+			const int currentPos = root["currentPos"]["position"].asInt();
+			const int pos = currentPos;
+
+			bool opened = true;
+			if ((state == 2 && pos == 100) || (state == 3))
+				opened = false;
+
+			SendSwitch(deviceID, 0, 255, opened, 100 - pos, DevicesType[device.bleBoxTypeId].name, signalQuality);
+			break;
+		}
+		case 2:
+		{
+			if (DoesNodeExists(root, "light", "currentColor") == false)
+				break;
+
+			const std::string currentColor = root["light"]["currentColor"].asString();
+			unsigned int hexNumber;
+			sscanf(currentColor.c_str(), "%x", &hexNumber);
+			auto level = (int)(hexNumber / (255.0 / 100.0));
+
+			SendSwitch(deviceID, 0, 255, level > 0, level, DevicesType[device.bleBoxTypeId].name, signalQuality);
+			break;
+		}
+		case 3:
+		{
+			if (DoesNodeExists(root, "rgbw", "currentColor") == false)
+				break;
+
+			const std::string currentColor = root["rgbw"]["currentColor"].asString();
+			unsigned int hexNumber;
+			sscanf(currentColor.c_str(), "%x", &hexNumber);
+
+			SendRGBWSwitch(deviceID, 0, 255, hexNumber, true, DevicesType[device.bleBoxTypeId].name, m_Name);
+			break;
+		}
+		case 4:
+		{
+			if (DoesNodeExists(root, "currentPos") == false)
+				break;
+
+			const float level = root["currentPos"].asFloat();
+
+			SendPercentageSensor(deviceID, 1, 255, level, DevicesType[device.bleBoxTypeId].name);
+			break;
+		}
+		case 5:
+		{
+			if (DoesNodeExists(root, "dimmer", "currentBrightness") == false)
+				break;
+
+			const int currentPos = root["dimmer"]["currentBrightness"].asInt();
+			auto level = (int)(currentPos / (255.0 / 100.0));
+
+			SendSwitch(deviceID, 0, 255, level > 0, level, DevicesType[device.bleBoxTypeId].name, signalQuality);
+			break;
+		}
+		case 0:
+		case 6:
+		{
+			if ((DoesNodeExists(root, "relays") == false) || (!root["relays"].isArray()))
+				break;
+
+			for (const auto& relay : root["relays"])
+			{
+				if ((DoesNodeExists(relay, "relay") == false) || (DoesNodeExists(relay, "state") == false))
+					break;
+				auto relayNumber = (uint8_t)relay["relay"].asInt(); // 0 or 1
+				bool currentState = relay["state"].asBool(); // 0 or 1
+				// std::string name = DevicesType[device.second].name + " " + relay["state"].asString();
+				SendSwitch(deviceID, relayNumber, 255, currentState, 0, DevicesType[device.bleBoxTypeId].name, signalQuality);
+			}
+
+			break;
+		}
+		case 7:
+		{
+			if (DoesNodeExists(root, "air") == false)
+				break;
+
+			root = root["air"];
+
+			if ((DoesNodeExists(root, "sensors") == false) || (!root["sensors"].isArray()))
+				break;
+
+			Json::Value sensors = root["sensors"];
+			Json::ArrayIndex count = sensors.size();
+			for (Json::ArrayIndex index = 0; index < count; index++)
+			{
+				Json::Value sensor = sensors[index];
+				if ((DoesNodeExists(sensor, "type") == false) || (DoesNodeExists(sensor, "value") == false))
+					break;
+				auto value = (uint8_t)sensor["value"].asInt();
+				std::string type = sensor["type"].asString();
+
+				// TODO - how save IP address ??
+				SendAirQualitySensor(deviceID, index + 1, 255, value, type);
+			}
+
+			break;
+		}
+		case 8:
+		{
+			if (DoesNodeExists(root, "tempSensor") == false)
+				break;
+
+			root = root["tempSensor"];
+
+			if ((DoesNodeExists(root, "sensors") == false) || (!root["sensors"].isArray()))
+				break;
+
+			for (const auto& sensor : root["sensors"])
+			{
+				if ((DoesNodeExists(sensor, "value") == false)
+					|| (DoesNodeExists(sensor, "state") == false))
+					break;
+
+				if (sensor["state"] != 2)
+				{
+					Log(LOG_ERROR, "temp sensor error!");
+					break;
+				}
+
+				std::string temperature = sensor["value"].asString(); // xxxx (xx.xx = temperature)
+				auto ftemp = static_cast<float>(std::stoi(temperature.substr(0, 2))
+					+ std::stoi(temperature.substr(2, 2)) / 100.0);
+
+				// TODO - how save IP address ??
+				SendTempSensor(deviceID, 255, ftemp, DevicesType[device.bleBoxTypeId].name, signalQuality);
+			}
+
+			break;
+		}
 		}
 	}
 }
 
-std::string BleBox::GetDeviceIP(const tRBUF * id)
+std::string BleBox::GetDeviceIP(const tRBUF* id)
 {
 	return std_format("%d.%d.%d.%d", id->LIGHTING2.id1, id->LIGHTING2.id2, id->LIGHTING2.id3, id->LIGHTING2.id4);
 }
 
-std::string BleBox::GetDeviceRevertIP(const tRBUF * id)
+std::string BleBox::GetDeviceRevertIP(const tRBUF* id)
 {
 	return std_format("%d.%d.%d.%d", id->LIGHTING2.id4, id->LIGHTING2.id3, id->LIGHTING2.id2, id->LIGHTING2.id1);
 }
 
-std::string BleBox::GetDeviceIP(const std::string & id)
+uint8_t BleBox::GetDeviceTypeByApiName(const std::string& apiName)
 {
-	BYTE id1, id2, id3, id4;
-	sscanf(id.c_str(), "%2hhx%2hhx%2hhx%2hhx", &id1, &id2, &id3, &id4);
-
-	return std_format("%d.%d.%d.%d", id1, id2, id3, id4);
-}
-
-int BleBox::GetDeviceTypeByApiName(const std::string & apiName)
-{
-	for (const auto &i : DevicesType)
+	for (const auto& i : DevicesType)
 		if (i.api_name == apiName)
-			return i.unit;
+			return i.bleBoxTypeId;
 
 	Log(LOG_ERROR, "unknown device api name(%s)", apiName.c_str());
-	return -1;
-}
-
-std::string BleBox::IPToHex(const std::string & IPAddress, const int type)
-{
-	std::vector<std::string> strarray;
-	StringSplit(IPAddress, ".", strarray);
-	if (strarray.size() != 4)
-		return "";
-
-	// because exists inconsistency when comparing deviceID in method decode_xxx in mainworker(Limitless uses small letter, lighting2 etc uses capital letter)
-	if (type != pTypeColorSwitch)
-	{
-		uint32_t uID = (uint32_t)(atoi(strarray[0].c_str()) << 24) | (uint32_t)(atoi(strarray[1].c_str()) << 16) | (atoi(strarray[2].c_str()) << 8) | atoi(strarray[3].c_str());
-		return std_format("%08X", uID);
-	}
-
-	return std_format("%X%02X%02X%02X", atoi(strarray[0].data()), atoi(strarray[1].data()), atoi(strarray[2].data()), atoi(strarray[3].data()));
+	return 255;
 }
 
 bool BleBox::WriteToHardware(const char* pdata, const unsigned char /*length*/)
 {
-	const tRBUF* output = reinterpret_cast<const tRBUF*>(pdata);
+	const auto output = reinterpret_cast<const tRBUF*>(pdata);
 
 	if (output->ICMND.packettype == pTypeLighting2 && output->LIGHTING2.subtype == sTypeAC)
 	{
@@ -369,7 +327,7 @@ bool BleBox::WriteToHardware(const char* pdata, const unsigned char /*length*/)
 					}
 					else
 					{
-						uint8_t percentage = static_cast<uint8_t>(output->LIGHTING2.level * 255 / 15);
+						auto percentage = static_cast<uint8_t>(output->LIGHTING2.level * 255 / 15);
 						level = std_format("%x", percentage);
 					}
 
@@ -403,7 +361,7 @@ bool BleBox::WriteToHardware(const char* pdata, const unsigned char /*length*/)
 					}
 					else
 					{
-						uint8_t percentage = static_cast<uint8_t>(output->LIGHTING2.level * 255 / 15);
+						auto percentage = static_cast<uint8_t>(output->LIGHTING2.level * 255 / 15);
 						level = std_format("%x", percentage);
 					}
 
@@ -582,8 +540,8 @@ bool BleBox::WriteToHardware(const char* pdata, const unsigned char /*length*/)
 			// No break, fall through to send combined color + brightness command
 		}
 		case Color_SetBrightnessLevel: {
-			int BrightnessBase = (int)pLed->value;
-			int dMax_Send = (int)(round((255.0F / 100.0F) * float(BrightnessBase)));
+			auto BrightnessBase = (int)pLed->value;
+			auto dMax_Send = (int)(round((255.0F / 100.0F) * float(BrightnessBase)));
 
 			m_RGBWbrightnessState = dMax_Send;
 
@@ -631,7 +589,7 @@ bool BleBox::WriteToHardware(const char* pdata, const unsigned char /*length*/)
 	return false;
 }
 
-bool BleBox::DoesNodeExists(const Json::Value & root, const std::string & node)
+bool BleBox::DoesNodeExists(const Json::Value& root, const std::string& node)
 {
 	if (root[node].empty() == true)
 	{
@@ -641,7 +599,7 @@ bool BleBox::DoesNodeExists(const Json::Value & root, const std::string & node)
 	return true;
 }
 
-bool BleBox::DoesNodeExists(const Json::Value & root, const std::string & node, const std::string & value)
+bool BleBox::DoesNodeExists(const Json::Value& root, const std::string& node, const std::string& value)
 {
 	if (DoesNodeExists(root, node) == false)
 		return false;
@@ -654,29 +612,31 @@ bool BleBox::DoesNodeExists(const Json::Value & root, const std::string & node,
 	return true;
 }
 
-void BleBox::SetSettings(const int pollIntervalSec)
+void BleBox::SetSettings(const int pollIntervalSec, const int showRSSI)
 {
-	m_PollInterval = 30;
+	m_PollInterval = 60;
 
 	if (pollIntervalSec > 0)
 		m_PollInterval = pollIntervalSec;
+
+	m_ShowRSSI = showRSSI;
 }
 
-void BleBox::SendSwitch(const int NodeID, const uint8_t ChildID, const int BatteryLevel, const bool bOn, const double Level, const std::string & defaultname)
+void BleBox::SendSwitch(const int NodeID, const uint8_t ChildID, const int BatteryLevel, const bool bOn, const double Level, const std::string& defaultname, const BYTE rssi)
 { //TODO - remove this method, when in DomoticzHardware bug is fix (15 instead 16)
 	double rlevel = (15.0 / 100.0) * Level;
 	uint8_t level = (uint8_t)(rlevel);
 
 	//make device ID
-	unsigned char ID1 = (unsigned char)((NodeID & 0xFF000000) >> 24);
-	unsigned char ID2 = (unsigned char)((NodeID & 0xFF0000) >> 16);
-	unsigned char ID3 = (unsigned char)((NodeID & 0xFF00) >> 8);
-	unsigned char ID4 = (unsigned char)NodeID & 0xFF;
+	auto ID1 = (unsigned char)((NodeID & 0xFF000000) >> 24);
+	auto ID2 = (unsigned char)((NodeID & 0xFF0000) >> 16);
+	auto ID3 = (unsigned char)((NodeID & 0xFF00) >> 8);
+	auto ID4 = (unsigned char)NodeID & 0xFF;
 
 	std::string szIdx = std_format("%X%02X%02X%02X");
 	std::vector<std::vector<std::string> > result;
 	result = m_sql.safe_query("SELECT Name,nValue,sValue FROM DeviceStatus WHERE (HardwareID==%d) AND (DeviceID=='%q') AND (Unit == %d) AND (Type==%d) AND (Subtype==%d)", m_HwdID, szIdx.c_str(),
-				  ChildID, int(pTypeLighting2), int(sTypeAC));
+		ChildID, int(pTypeLighting2), int(sTypeAC));
 	if (!result.empty())
 	{
 		//check if we have a change, if not do not update it
@@ -716,8 +676,8 @@ void BleBox::SendSwitch(const int NodeID, const uint8_t ChildID, const int Batte
 	}
 	lcmd.LIGHTING2.level = level;
 	lcmd.LIGHTING2.filler = 0;
-	lcmd.LIGHTING2.rssi = 12;
-	sDecodeRXMessage(this, (const unsigned char *)&lcmd.LIGHTING2, defaultname.c_str(), BatteryLevel, m_Name.c_str());
+	lcmd.LIGHTING2.rssi = rssi;
+	sDecodeRXMessage(this, (const unsigned char*)&lcmd.LIGHTING2, defaultname.c_str(), BatteryLevel, m_Name.c_str());
 }
 
 
@@ -741,15 +701,13 @@ namespace http {
 			root["title"] = "BleBoxGetNodes";
 
 			std::vector<std::vector<std::string> > result;
-			result = m_sql.safe_query("SELECT ID,Name,DeviceID FROM DeviceStatus WHERE (HardwareID=='%d')", pBaseHardware->m_HwdID);
+			result = m_sql.safe_query("SELECT ID, Name, StrParam1, StrParam2 FROM DeviceStatus WHERE (HardwareID=='%d')", pBaseHardware->m_HwdID);
 			if (!result.empty())
 			{
 				int ii = 0;
-				for (const auto &sd : result)
+				for (const auto& sd : result)
 				{
-					BYTE id1, id2, id3, id4;
-					sscanf(sd[2].c_str(), "%2hhx%2hhx%2hhx%2hhx", &id1, &id2, &id3, &id4);
-					std::string ip = std_format("%d.%d.%d.%d", id1, id2, id3, id4);
+					std::string ip = sd[3];
 
 					root["result"][ii]["idx"] = sd[0];
 					root["result"][ii]["Name"] = sd[1];
@@ -758,10 +716,11 @@ namespace http {
 					root["result"][ii]["Uptime"] = "unknown";
 					root["result"][ii]["hv"] = "unknown";
 					root["result"][ii]["fv"] = "unknown";
+					root["result"][ii]["rssi"] = "unknown";
 
-					BleBox* pHardware = reinterpret_cast<BleBox*>(pBaseHardware);
+					BleBox* pHardware = dynamic_cast<BleBox*>(pBaseHardware);
 
-					int type = pHardware->GetDeviceType(ip);
+					int type = stoi(sd[2]);
 					if (type != -1)
 					{
 						root["result"][ii]["Type"] = DevicesType[type].name;
@@ -777,6 +736,12 @@ namespace http {
 
 							std::string uptime = pHardware->GetUptime(ip);
 							root["result"][ii]["Uptime"] = uptime;
+
+							int rssi = pHardware->GetRSSI(ip);
+							if (rssi != 0)
+							{
+								root["result"][ii]["rssi"] = std::to_string(rssi) + " dBm";
+							}
 						}
 					}
 
@@ -798,10 +763,10 @@ namespace http {
 			std::string mode2 = request::findValue(&req, "mode2");
 			if ((hwid.empty()) || (mode1.empty()) || (mode2.empty()))
 				return;
-			CDomoticzHardwareBase * pBaseHardware = m_mainworker.GetHardwareByIDType(hwid, HTYPE_BleBox);
+			CDomoticzHardwareBase* pBaseHardware = m_mainworker.GetHardwareByIDType(hwid, HTYPE_BleBox);
 			if (pBaseHardware == nullptr)
 				return;
-			BleBox * pHardware = reinterpret_cast<BleBox*>(pBaseHardware);
+			BleBox* pHardware = dynamic_cast<BleBox*>(pBaseHardware);
 
 			root["status"] = "OK";
 			root["title"] = "BleBoxSetMode";
@@ -810,12 +775,12 @@ namespace http {
 			int iMode2 = atoi(mode2.c_str());
 
 			m_sql.safe_query("UPDATE Hardware SET Mode1=%d, Mode2=%d WHERE (ID == '%q')", iMode1, iMode2, hwid.c_str());
-			pHardware->SetSettings(iMode1);
+			pHardware->SetSettings(iMode1, iMode2);
 			pHardware->Restart();
 		}
 
 
-		void CWebServer::Cmd_BleBoxAddNode(WebEmSession & session, const request & req, Json::Value & root)
+		void CWebServer::Cmd_BleBoxAddNode(WebEmSession& session, const request& req, Json::Value& root)
 		{
 			if (session.rights != 2)
 			{
@@ -828,17 +793,17 @@ namespace http {
 			std::string ip = HTMLSanitizer::Sanitize(request::findValue(&req, "ip"));
 			if ((hwid.empty()) || (name.empty()) || (ip.empty()))
 				return;
-			CDomoticzHardwareBase * pBaseHardware = m_mainworker.GetHardwareByIDType(hwid, HTYPE_BleBox);
+			CDomoticzHardwareBase* pBaseHardware = m_mainworker.GetHardwareByIDType(hwid, HTYPE_BleBox);
 			if (pBaseHardware == nullptr)
 				return;
-			BleBox * pHardware = reinterpret_cast<BleBox*>(pBaseHardware);
+			auto pHardware = dynamic_cast<BleBox*>(pBaseHardware);
 
 			root["status"] = "OK";
 			root["title"] = "BleBoxAddNode";
 			pHardware->AddNode(name, ip, true);
 		}
 
-		void CWebServer::Cmd_BleBoxRemoveNode(WebEmSession & session, const request & req, Json::Value & root)
+		void CWebServer::Cmd_BleBoxRemoveNode(WebEmSession& session, const request& req, Json::Value& root)
 		{
 			if (session.rights != 2)
 			{
@@ -850,10 +815,10 @@ namespace http {
 			std::string nodeid = request::findValue(&req, "nodeid");
 			if ((hwid.empty()) || (nodeid.empty()))
 				return;
-			CDomoticzHardwareBase * pBaseHardware = m_mainworker.GetHardwareByIDType(hwid, HTYPE_BleBox);
+			CDomoticzHardwareBase* pBaseHardware = m_mainworker.GetHardwareByIDType(hwid, HTYPE_BleBox);
 			if (pBaseHardware == nullptr)
 				return;
-			BleBox * pHardware = reinterpret_cast<BleBox*>(pBaseHardware);
+			BleBox* pHardware = dynamic_cast<BleBox*>(pBaseHardware);
 
 			root["status"] = "OK";
 			root["title"] = "BleBoxRemoveNode";
@@ -861,7 +826,7 @@ namespace http {
 			pHardware->RemoveNode(ID);
 		}
 
-		void CWebServer::Cmd_BleBoxClearNodes(WebEmSession & session, const request & req, Json::Value & root)
+		void CWebServer::Cmd_BleBoxClearNodes(WebEmSession& session, const request& req, Json::Value& root)
 		{
 			if (session.rights != 2)
 			{
@@ -873,14 +838,14 @@ namespace http {
 			CDomoticzHardwareBase* pBaseHardware = m_mainworker.GetHardwareByIDType(hwid, HTYPE_BleBox);
 			if (pBaseHardware == nullptr)
 				return;
-			BleBox * pHardware = reinterpret_cast<BleBox*>(pBaseHardware);
+			auto pHardware = dynamic_cast<BleBox*>(pBaseHardware);
 
 			root["status"] = "OK";
 			root["title"] = "BleBoxClearNodes";
 			pHardware->RemoveAllNodes();
 		}
 
-		void CWebServer::Cmd_BleBoxAutoSearchingNodes(WebEmSession & session, const request & req, Json::Value & root)
+		void CWebServer::Cmd_BleBoxAutoSearchingNodes(WebEmSession& session, const request& req, Json::Value& root)
 		{
 			if (session.rights != 2)
 			{
@@ -892,17 +857,17 @@ namespace http {
 			std::string ipmask = request::findValue(&req, "ipmask");
 			if ((hwid.empty()) || (ipmask.empty()))
 				return;
-			CDomoticzHardwareBase * pBaseHardware = m_mainworker.GetHardwareByIDType(hwid, HTYPE_BleBox);
+			CDomoticzHardwareBase* pBaseHardware = m_mainworker.GetHardwareByIDType(hwid, HTYPE_BleBox);
 			if (pBaseHardware == nullptr)
 				return;
-			BleBox * pHardware = reinterpret_cast<BleBox*>(pBaseHardware);
+			BleBox* pHardware = dynamic_cast<BleBox*>(pBaseHardware);
 
 			root["status"] = "OK";
 			root["title"] = "BleBoxAutoSearchingNodes";
 			pHardware->SearchNodes(ipmask);
 		}
 
-		void CWebServer::Cmd_BleBoxUpdateFirmware(WebEmSession & session, const request & req, Json::Value & root)
+		void CWebServer::Cmd_BleBoxUpdateFirmware(WebEmSession& session, const request& req, Json::Value& root)
 		{
 			if (session.rights != 2)
 			{
@@ -914,7 +879,7 @@ namespace http {
 			CDomoticzHardwareBase* pBaseHardware = m_mainworker.GetHardwareByIDType(hwid, HTYPE_BleBox);
 			if (pBaseHardware == nullptr)
 				return;
-			BleBox * pHardware = reinterpret_cast<BleBox*>(pBaseHardware);
+			auto pHardware = dynamic_cast<BleBox*>(pBaseHardware);
 
 			root["status"] = "OK";
 			root["title"] = "BleBoxUpdateFirmware";
@@ -924,7 +889,7 @@ namespace http {
 	} // namespace server
 } // namespace http
 
-Json::Value BleBox::SendCommand(const std::string & IPAddress, const std::string & command, const int timeOut)
+Json::Value BleBox::SendCommand(const std::string& IPAddress, const std::string& command, const int timeOut)
 {
 	std::string result;
 	Json::Value root;
@@ -943,13 +908,13 @@ Json::Value BleBox::SendCommand(const std::string & IPAddress, const std::string
 
 	if (!ParseJSon(result, root))
 	{
-		Log(LOG_ERROR, "Invalid json received!");
+		Log(LOG_ERROR, "(IP: %s, Command: %s) Invalid json received!", IPAddress.c_str(), command.c_str());
 		return root;
 	}
 
 	if (root.empty())
 	{
-		Log(LOG_ERROR, "Json is empty!");
+		Log(LOG_ERROR, "(IP: %s, Command: %s) Json is empty!", IPAddress.c_str(), command.c_str());
 		return root;
 	}
 
@@ -959,38 +924,42 @@ Json::Value BleBox::SendCommand(const std::string & IPAddress, const std::string
 	return root;
 }
 
-std::string BleBox::IdentifyDevice(const std::string & IPAddress)
+std::pair<std::string, std::string> BleBox::IdentifyDevice(const std::string& IPAddress)
 {
-	Json::Value root = SendCommand(IPAddress, "/api/device/state", 2);
+	Json::Value root = SendCommand(IPAddress, "/info", 2);
 	if (!root.isObject())
-		return "";
+		return std::make_pair("", "");
 
-	std::string result;
+	std::pair<std::string, std::string> result;
 
 	if (root["device"].empty() == true)
 	{
 		if (!DoesNodeExists(root, "type"))
-			return "";
+			return std::make_pair("", "");
 
-		result = root["type"].asString();
+		auto type = root["type"].asString();
+		auto name = root["device"]["deviceName"].asString();
+		result = std::make_pair(type, name);
 	}
 	else
 	{
 		if (root["device"]["type"].empty() == true)
 		{
 			Log(LOG_ERROR, "Invalid device type received!");
-			return "";
+			return std::make_pair("", "");
 		}
-		result = root["device"]["type"].asString();
+		auto type = root["device"]["type"].asString();
+		auto name = root["device"]["deviceName"].asString();
+		result = std::make_pair(type, name);
 	}
 	return result;
 }
 
-Json::Value BleBox::GetApiDeviceState(const std::string & IPAddress)
+Json::Value BleBox::GetApiDeviceState(const std::string& IPAddress)
 {
 	Json::Value empty;
 
-	Json::Value root = SendCommand(IPAddress, "/api/device/state", 2);
+	Json::Value root = SendCommand(IPAddress, "/info", 2);
 	if (!root.isObject())
 		return empty;
 
@@ -1002,7 +971,7 @@ Json::Value BleBox::GetApiDeviceState(const std::string & IPAddress)
 	return root["device"];
 }
 
-std::string BleBox::GetUptime(const std::string & IPAddress)
+std::string BleBox::GetUptime(const std::string& IPAddress)
 {
 	Json::Value root = SendCommand(IPAddress, "/api/device/uptime", 2);
 	if (root.empty())
@@ -1034,55 +1003,157 @@ std::string BleBox::GetUptime(const std::string & IPAddress)
 	else
 		return "unknown";
 
-	int days = static_cast<int>(total_minutes / (24 * 60));
-	int hours = static_cast<int>(total_minutes / 60 - days * 24);
-	int mins = static_cast<int>(total_minutes - days * 24 * 60 - hours * 60);   //sec / 60 - day * (24 * 60) - hour * 60;
+	auto days = static_cast<int>(total_minutes / (24 * 60));
+	auto hours = static_cast<int>(total_minutes / 60 - days * 24);
+	auto mins = static_cast<int>(total_minutes - days * 24 * 60 - hours * 60);   //sec / 60 - day * (24 * 60) - hour * 60;
 
 	return std_format("%d:%02d:%02d", days, hours, mins);
 }
 
-int BleBox::GetDeviceType(const std::string & IPAddress)
+int BleBox::GetRSSI(const std::string& IPAddress)
 {
-	auto itt = m_devices.find(IPAddress);
+	if (m_ShowRSSI == 0)
+	{
+		return 0;
+	}
+
+	Json::Value root = SendCommand(IPAddress, "/api/device/network", 2);
+	if (root.empty())
+	{
+		return 0;
+	}
+
+	if (root["ssid"].empty())
+	{
+		return 0;
+	}
+
+	auto ssid = root["ssid"].asString();
+
+	root = SendCommand(IPAddress, "/api/wifi/scan", 2);
+	if (root.empty() || DoesNodeExists(root, "ap") == false)
+	{
+		return 0;
+	}
+
+	for (const auto& ap : root["ap"])
+	{
+		if (DoesNodeExists(ap, "ssid") == true)
+		{
+			if (ap["ssid"].asString() == ssid)
+			{
+				if (DoesNodeExists(ap, "rssi") == true)
+				{
+					auto rssi = ap["rssi"].asInt();
+					return rssi;
+				}
+			}
+		}
+	}
+
+	return 0;
+}
+
+int BleBox::GetDeviceType(const std::string& IPAddress)
+{
+	auto itt = std::find_if(m_devices.begin(), m_devices.end(), [&IPAddress](const _tBleBoxDevice& obj) {
+		return obj.addressIP == IPAddress;
+		});
+
 	if (itt == m_devices.end())
 	{
 		Log(LOG_ERROR, "unknown device (%s)", IPAddress.c_str());
 		return -1;
 	}
 
-	return itt->second;
+	return itt->bleBoxTypeId;
 }
 
-void BleBox::AddNode(const std::string & name, const std::string & IPAddress, bool reloadNodes)
+void BleBox::AddNode(const std::string& name, const std::string& IPAddress, bool reloadNodes)
 {
-	std::string deviceApiName = IdentifyDevice(IPAddress);
+	auto itt = std::find_if(m_devices.begin(), m_devices.end(), [&IPAddress](const _tBleBoxDevice& obj) {
+		return obj.addressIP == IPAddress;
+		});
+
+	if (itt != m_devices.end())
+		return;
+
+
+	auto device = IdentifyDevice(IPAddress);
+	std::string deviceApiName = device.first;
 	if (deviceApiName.empty())
 		return;
 
-	int deviceTypeID = GetDeviceTypeByApiName(deviceApiName);
-	if (deviceTypeID == -1)
+	uint8_t deviceTypeID = GetDeviceTypeByApiName(deviceApiName);
+	if (deviceTypeID == 255)
 		return;
 
-	const auto deviceType = DevicesType[deviceTypeID];
-
-	std::string szIdx = IPToHex(IPAddress, deviceType.deviceID);
-
-	if (deviceType.unit == 4) // gatebox
+	if (!m_sql.m_bAcceptNewHardware)
 	{
-		m_sql.InsertDevice(m_HwdID, szIdx.c_str(), 1, (uint8_t)deviceType.deviceID, deviceType.subType, deviceType.switchType, 0, "Unavailable", name);
-		m_sql.InsertDevice(m_HwdID, szIdx.c_str(), 2, pTypeGeneralSwitch, sTypeAC, STYPE_PushOn, 0, "Unavailable", name);
-		m_sql.InsertDevice(m_HwdID, szIdx.c_str(), 3, pTypeGeneralSwitch, sTypeAC, STYPE_PushOn, 0, "Unavailable", name);
+		Log(LOG_NORM, "Accept new hardware disabled. Ignoring new sensor %s", IPAddress.c_str());
+		return;
 	}
-	else
-		if (deviceType.unit == 6) // switchboxd
+
+	auto deviceName = name;
+	if (deviceName == "")
+	{
+		deviceName = device.second;
+	}
+
+	const auto& deviceType = DevicesType[deviceTypeID];
+	auto ip = IPToInt(IPAddress);
+	auto address = CodeID(ip, deviceType.rfxType);
+	auto id = address.first.c_str();
+	auto unit = address.second;
+
+	int signalQuality = 12;
+	if (m_ShowRSSI == 2)
+	{
+		int rssi = GetRSSI(IPAddress);
+		if (rssi != 0)
 		{
-			m_sql.InsertDevice(m_HwdID, szIdx.c_str(), 0, (uint8_t)deviceType.deviceID, deviceType.subType, deviceType.switchType, 0, "Unavailable", name);
-			m_sql.InsertDevice(m_HwdID, szIdx.c_str(), 1, (uint8_t)deviceType.deviceID, deviceType.subType, deviceType.switchType, 0, "Unavailable", name);
-		}
-		else
-		{
-			m_sql.InsertDevice(m_HwdID, szIdx.c_str(), 0, (uint8_t)deviceType.deviceID, deviceType.subType, deviceType.switchType, 0, "Unavailable", name);
+			signalQuality = RSSIToQuality(rssi);
 		}
+	}
+
+	if (deviceType.bleBoxTypeId == 4) // gatebox
+	{
+		//GizMoCuz: Bad coding! Return = uint64_t, please change!
+		int idx = (int)m_sql.InsertDevice(m_HwdID, 0, id, 1, deviceType.rfxType, deviceType.subType, deviceType.switchType, 0, "Unavailable", deviceName, signalQuality, 255, 0);
+		_log.Debug(DEBUG_HARDWARE, "BleBox: new device Id: '%d'", idx);
+		m_sql.safe_query("UPDATE DeviceStatus SET StrParam1='%d', StrParam2='%q' WHERE (ID==%d)", deviceTypeID, IPAddress.c_str(), idx);
+
+		idx = (int)m_sql.InsertDevice(m_HwdID, 0, id, 2, pTypeGeneralSwitch, sTypeAC, STYPE_PushOn, 0, "Unavailable", deviceName, signalQuality, 255, 0);
+		m_sql.safe_query("UPDATE DeviceStatus SET StrParam1='%d', StrParam2='%q' WHERE (ID==%d)", deviceTypeID, IPAddress.c_str(), idx);
+
+		idx = (int)m_sql.InsertDevice(m_HwdID, 0, id, 3, pTypeGeneralSwitch, sTypeAC, STYPE_PushOn, 0, "Unavailable", deviceName, signalQuality, 255, 0);
+		m_sql.safe_query("UPDATE DeviceStatus SET StrParam1='%d', StrParam2='%q' WHERE (ID==%d)", deviceTypeID, IPAddress.c_str(), idx);
+	}
+	else if (deviceType.bleBoxTypeId == 6) // switchboxd
+	{
+		int idx = (int)m_sql.InsertDevice(m_HwdID, 0, id, 0, deviceType.rfxType, deviceType.subType, deviceType.switchType, 0, "Unavailable", deviceName, signalQuality, 255, 0);
+		_log.Debug(DEBUG_HARDWARE, "BleBox: new device Id: '%d'", idx);
+		m_sql.safe_query("UPDATE DeviceStatus SET StrParam1='%d', StrParam2='%q' WHERE (ID==%d)", deviceTypeID, IPAddress.c_str(), idx);
+
+		idx = (int)m_sql.InsertDevice(m_HwdID, 0, id, 1, deviceType.rfxType, deviceType.subType, deviceType.switchType, 0, "Unavailable", deviceName, signalQuality, 255, 0);
+		m_sql.safe_query("UPDATE DeviceStatus SET StrParam1='%d', StrParam2='%q' WHERE (ID==%d)", deviceTypeID, IPAddress.c_str(), idx);
+	}
+	else if (deviceType.bleBoxTypeId == 7) // airbox
+	{
+		int idx = (int)m_sql.InsertDevice(m_HwdID, 0, id, 1, deviceType.rfxType, deviceType.subType, deviceType.switchType, 0, "Unavailable", "Unknown", signalQuality, 255, 0);
+		_log.Debug(DEBUG_HARDWARE, "BleBox: new device Id: '%d'", idx);
+		m_sql.safe_query("UPDATE DeviceStatus SET StrParam1='%d', StrParam2='%q' WHERE (ID==%d)", deviceTypeID, IPAddress.c_str(), idx);
+
+		idx = (int)m_sql.InsertDevice(m_HwdID, 0, id, 2, deviceType.rfxType, deviceType.subType, deviceType.switchType, 0, "Unavailable", "Unknown", signalQuality, 255, 0);
+		m_sql.safe_query("UPDATE DeviceStatus SET StrParam1='%d', StrParam2='%q' WHERE (ID==%d)", deviceTypeID, IPAddress.c_str(), idx);
+
+		idx = (int)m_sql.InsertDevice(m_HwdID, 0, id, 3, deviceType.rfxType, deviceType.subType, deviceType.switchType, 0, "Unavailable", "Unknown", signalQuality, 255, 0);
+		m_sql.safe_query("UPDATE DeviceStatus SET StrParam1='%d', StrParam2='%q' WHERE (ID==%d)", deviceTypeID, IPAddress.c_str(), idx);
+	} else {
+		int idx = (int)m_sql.InsertDevice(m_HwdID, 0, id, unit, deviceType.rfxType, deviceType.subType, deviceType.switchType, 0, "Unavailable", deviceName, signalQuality, 255, 0);
+		_log.Debug(DEBUG_HARDWARE, "BleBox: new device Id: '%d'", idx);
+		m_sql.safe_query("UPDATE DeviceStatus SET StrParam1='%d', StrParam2='%q' WHERE (ID==%d)", deviceTypeID, IPAddress.c_str(), idx);
+	}
 
 	if (reloadNodes)
 	{
@@ -1092,16 +1163,27 @@ void BleBox::AddNode(const std::string & name, const std::string & IPAddress, bo
 
 void BleBox::RemoveNode(const int id)
 {
-	m_sql.safe_query("DELETE FROM DeviceStatus WHERE (HardwareID==%d) AND (ID=='%d')", m_HwdID, id);
+	m_sql.DeleteDevices(std::to_string(id));
 
 	ReloadNodes();
 }
 
 void BleBox::RemoveAllNodes()
 {
-	m_sql.safe_query("DELETE FROM DeviceStatus WHERE (HardwareID==%d)", m_HwdID);
+	auto result = m_sql.safe_query("SELECT ID FROM DeviceStatus WHERE (HardwareID==%d)", m_HwdID);
+	if (!result.empty())
+	{
+		std::string devices;
+		for (const auto& sd : result)
+		{
+			if (!devices.empty())
+				devices += ";";
+			devices += sd[0];
+		}
+		m_sql.DeleteDevices(devices);
 
-	UnloadNodes();
+		UnloadNodes();
+	}
 }
 
 void BleBox::UnloadNodes()
@@ -1111,27 +1193,21 @@ void BleBox::UnloadNodes()
 	m_devices.clear();
 }
 
+
 bool BleBox::LoadNodes()
 {
 	std::lock_guard<std::mutex> l(m_mutex);
 
 	std::vector<std::vector<std::string> > result;
-	result = m_sql.safe_query("SELECT ID,DeviceID FROM DeviceStatus WHERE (HardwareID==%d)", m_HwdID);
+	result = m_sql.safe_query("SELECT StrParam1, StrParam2 FROM DeviceStatus WHERE (HardwareID==%d)", m_HwdID);
 	if (!result.empty())
 	{
-		for (const auto &sd : result)
+		for (const auto& sd : result)
 		{
-			std::string addressIP = GetDeviceIP(sd[1]);
+			std::string addressIP = sd[1];
+			uint8_t bleBoxTypeID = std::stoi(sd[0]);
 
-			std::string deviceApiName = IdentifyDevice(addressIP);
-			if (deviceApiName.empty())
-				continue;
-
-			int deviceTypeID = GetDeviceTypeByApiName(deviceApiName);
-			if (deviceTypeID == -1)
-				continue;
-
-			m_devices.insert(std::pair<const std::string, const int>(addressIP, deviceTypeID));
+			m_devices.push_back({ bleBoxTypeID, addressIP });
 		}
 		return true;
 	}
@@ -1148,25 +1224,31 @@ void BleBox::ReloadNodes()
 
 void BleBox::UpdateFirmware()
 {
-	for (const auto &device : m_devices)
+	for (const auto& device : m_devices)
 	{
-		Json::Value root = SendCommand(device.first, "/api/ota/update", 2);
+		Json::Value root = SendCommand(device.addressIP, "/api/ota/update", 2);
 	}
 }
 
-void BleBox::SearchNodes(const std::string & pattern)
+void BleBox::SearchNodes(const std::string& pattern)
 {
 	std::vector<std::string> hosts;
-	if(!PrepareHostList(pattern, hosts))
+	if (!PrepareHostList(pattern, hosts))
 	{
 		Log(LOG_ERROR, "Invalid or unsupported IP pattern : %s (expected e.g. 192.168.1.*)", pattern.c_str());
 		return;
 	}
 
 	std::vector<std::thread> searchingThreads;
-	for(auto&& host : hosts)
-		if (m_devices.find(host) == m_devices.end())
-			searchingThreads.emplace_back([this, &host] { AddNode("unknown", host, false); });
+	for (auto&& host : hosts)
+	{
+		auto itt = std::find_if(m_devices.begin(), m_devices.end(), [&host](const _tBleBoxDevice& obj) {
+			return obj.addressIP == host;
+			});
+
+		if (itt == m_devices.end())
+			searchingThreads.emplace_back([this, &host] { AddNode("", host, false); });
+	}
 
 	for (auto&& thread : searchingThreads)
 	{
@@ -1202,3 +1284,89 @@ bool BleBox::PrepareHostList(const std::string& pattern, std::vector<std::string
 
 	return !hosts.empty();
 }
+
+std::pair<std::string, uint8_t> BleBox::CodeID(const int id, const uint8_t type)
+{
+	// because exists inconsistency when comparing deviceID in method decode_xxx in mainworker(Limitless uses small letter, lighting2 etc uses capital letter)
+
+	if (type == pTypeGeneral)
+	{
+		auto deviceId = std_format("%08X", id);
+		auto result = std::make_pair(deviceId, 0);
+		return result;
+	}
+
+	if (type == pTypeTEMP)
+	{
+		auto ID3 = (id & 0xFF00) >> 8;
+		auto ID4 = id & 0xFF;
+
+		char szTmp[10];
+		sprintf(szTmp, "%d", (ID3 * 256) + ID4);
+		std::string deviceId = szTmp;
+		uint8_t unit = ID4;
+
+		auto result = std::make_pair(deviceId, unit);
+		return result;
+	}
+
+	if (type == pTypeAirQuality)
+	{
+		auto ID1 = id & 0xFF;
+
+		char szTmp[10];
+		sprintf(szTmp, "%d", ID1);
+		std::string deviceId = szTmp;
+		uint8_t unit = 0;
+
+		auto result = std::make_pair(deviceId, unit);
+		return result;
+	}
+
+	if (type == pTypeLighting2)
+	{
+		auto ID1 = (unsigned char)((id & 0xFF000000) >> 24);
+		auto ID2 = (unsigned char)((id & 0xFF0000) >> 16);
+		auto ID3 = (unsigned char)((id & 0xFF00) >> 8);
+		auto ID4 = (unsigned char)id & 0xFF;
+
+		auto deviceId = std_format("%X%02X%02X%02X", ID1, ID2, ID3, ID4);
+		auto result = std::make_pair(deviceId, 0);
+		return result;
+	}
+
+	auto deviceId = std_format("%d", id);
+	auto result = std::make_pair(deviceId, 0);
+	return result;
+}
+
+int BleBox::IPToInt(const std::string& IPAddress)
+{
+	std::vector<std::string> strarray;
+	StringSplit(IPAddress, ".", strarray);
+	if (strarray.size() != 4)
+		return 0;
+
+	auto ip = (atoi(strarray[0].data()) << 24) | (atoi(strarray[1].data()) << 16) | (atoi(strarray[2].data()) << 8) | atoi(strarray[3].data());
+
+	return ip;
+}
+
+int BleBox::RSSIToQuality(const int rssi)
+{
+	int quality;
+	if (rssi <= -100)
+	{
+		quality = 0;
+	}
+	else if (rssi >= -50)
+	{
+		quality = 100;
+	}
+	else
+	{
+		quality = 2 * (rssi + 100);
+	}
+
+	return quality / 10;
+}
\ No newline at end of file
