@@ -1,7 +1,6 @@
 #include "stdafx.h"
 #include "Comm5SMTCP.h"
 #include "../main/Helper.h"
-#include "../main/localtime_r.h"
 #include "../main/Logger.h"
 #include "../main/mainworker.h"
 #include "../httpclient/HTTPClient.h"
@@ -15,11 +14,6 @@
 	https://www.comm5.com.br/en/sm-1200/
 */
 
-static inline std::string &rtrim(std::string &s) {
-	s.erase(std::find_if(s.rbegin(), s.rend(), std::not1(std::ptr_fun<int, int>(std::isspace))).base(), s.end());
-	return s;
-}
-
 static inline std::vector<std::string> tokenize(const std::string &s) {
 	std::vector<std::string> tokens;
 	std::istringstream iss(s);
@@ -75,7 +69,7 @@ bool Comm5SMTCP::StopHardware()
 
 void Comm5SMTCP::OnConnect()
 {
-	Log(LOG_STATUS, "connected to: %s:%d", m_szIPAddress.c_str(), m_usIPPort);
+	Log(LOG_STATUS, "Connected to: %s:%d", m_szIPAddress.c_str(), m_usIPPort);
 	m_bIsStarted = true;
 
 	sOnConnected(this);
@@ -84,7 +78,7 @@ void Comm5SMTCP::OnConnect()
 
 void Comm5SMTCP::OnDisconnect()
 {
-	Log(LOG_ERROR, "disconected");
+	Log(LOG_ERROR, "Disconected");
 }
 
 void Comm5SMTCP::Do_Work()
@@ -104,7 +98,7 @@ void Comm5SMTCP::Do_Work()
 	}
 	terminate();
 
-	Log(LOG_STATUS, "TCP/IP Worker stopped...");
+	Log(LOG_STATUS, "Worker stopped...");
 }
 
 void Comm5SMTCP::ParseData(const unsigned char* data, const size_t len)
@@ -118,7 +112,7 @@ void Comm5SMTCP::ParseData(const unsigned char* data, const size_t len)
 	std::string line;
 
 	while (std::getline(stream, line, '\n')) {
-		line = rtrim(line);
+		line = stdstring_rtrim(line);
 		if (startsWith(line, "280")) {
 			std::vector<std::string> tokens = tokenize(line);
 			if (tokens.size() < 2)
