@@ -7,23 +7,26 @@
 
 class Comm5SMTCP : public CDomoticzHardwareBase, ASyncTCP
 {
-public:
-	Comm5SMTCP(const int ID, const std::string &IPAddress, const unsigned short usIPPort);
-	bool WriteToHardware(const char *pdata, const unsigned char length) override;
-	boost::signals2::signal<void()>	sDisconnected;
-private:
+      public:
+	Comm5SMTCP(int ID, const std::string &IPAddress, unsigned short usIPPort);
+	bool WriteToHardware(const char *pdata, unsigned char length) override;
+	boost::signals2::signal<void()> sDisconnected;
+
+      private:
 	bool StartHardware() override;
 	bool StopHardware() override;
-protected:
+
+      protected:
 	void OnConnect() override;
 	void OnDisconnect() override;
 	void OnData(const unsigned char *pData, size_t length) override;
-	void OnError(const boost::system::error_code& error) override;
+	void OnError(const boost::system::error_code &error) override;
 
 	void Do_Work();
-	void ParseData(const unsigned char *data, const size_t len);
+	void ParseData(const unsigned char *data, size_t len);
 	void querySensorState();
-private:
+
+      private:
 	std::string m_szIPAddress;
 	unsigned short m_usIPPort;
 	std::string buffer;
@@ -31,4 +34,3 @@ private:
 	bool m_bReceiverStarted;
 	std::shared_ptr<std::thread> m_thread;
 };
-
