@@ -26,5 +26,5 @@ class CurrentCostMeterTCP : public CurrentCostMeterBase
 	unsigned short m_usIPPort;
 	std::shared_ptr<std::thread> m_thread;
 	sockaddr_in m_addr;
-	int m_socket;
+	SOCKET m_socket;
 };
