@@ -4,14 +4,11 @@
 #include "../main/Logger.h"
 #include "../httpclient/UrlEncode.h"
 #include "hardwaretypes.h"
-#include "../main/localtime_r.h"
 #include "../httpclient/HTTPClient.h"
 #include "../main/json_helper.h"
 #include "../main/RFXtrx.h"
 #include "../main/mainworker.h"
 
-#define round(a) ( int ) ( a + .5 )
-
 #ifdef _DEBUG
 //#define DEBUG_DarkSkyR
 //#define DEBUG_DarkSkyW
@@ -20,7 +17,7 @@
 #ifdef DEBUG_DarkSkyW
 void SaveString2Disk(std::string str, std::string filename)
 {
-	FILE *fOut = fopen(filename.c_str(), "wb+");
+	FILE* fOut = fopen(filename.c_str(), "wb+");
 	if (fOut)
 	{
 		fwrite(str.c_str(), 1, str.size(), fOut);
@@ -47,11 +44,11 @@ std::string ReadFile(std::string filename)
 }
 #endif
 
-CDarkSky::CDarkSky(const int ID, const std::string &APIKey, const std::string &Location) :
-m_APIKey(APIKey),
-m_Location(Location)
+CDarkSky::CDarkSky(const int ID, const std::string& APIKey, const std::string& Location) :
+	m_APIKey(APIKey),
+	m_Location(Location)
 {
-	m_HwdID=ID;
+	m_HwdID = ID;
 	Init();
 }
 
@@ -67,7 +64,7 @@ bool CDarkSky::StartHardware()
 	//Start worker thread
 	m_thread = std::make_shared<std::thread>([this] { Do_Work(); });
 	SetThreadNameInt(m_thread->native_handle());
-	m_bIsStarted=true;
+	m_bIsStarted = true;
 	sOnConnected(this);
 	return (m_thread != nullptr);
 }
@@ -80,8 +77,8 @@ bool CDarkSky::StopHardware()
 		m_thread->join();
 		m_thread.reset();
 	}
-    m_bIsStarted=false;
-    return true;
+	m_bIsStarted = false;
+	return true;
 }
 
 void CDarkSky::Do_Work()
@@ -100,7 +97,7 @@ void CDarkSky::Do_Work()
 			GetMeterDetails();
 		}
 	}
-	Log(LOG_STATUS,"Worker stopped...");
+	Log(LOG_STATUS, "Worker stopped...");
 }
 
 bool CDarkSky::WriteToHardware(const char* /*pdata*/, const unsigned char /*length*/)
@@ -120,7 +117,7 @@ void CDarkSky::GetMeterDetails()
 {
 	std::string sResult;
 #ifdef DEBUG_DarkSkyR
-	sResult=ReadFile("E:\\DarkSky.json");
+	sResult = ReadFile("E:\\DarkSky.json");
 #else
 	std::stringstream sURL;
 	std::string szLoc = m_Location;
@@ -149,12 +146,12 @@ void CDarkSky::GetMeterDetails()
 	bool ret = ParseJSon(sResult, root);
 	if ((!ret) || (!root.isObject()))
 	{
-		Log(LOG_ERROR,"Invalid data received! Check Location, use a City or GPS Coordinates (xx.yyyy,xx.yyyyy)");
+		Log(LOG_ERROR, "Invalid data received! Check Location, use a City or GPS Coordinates (xx.yyyy,xx.yyyyy)");
 		return;
 	}
-	if (root["currently"].empty()==true)
+	if (root["currently"].empty() == true)
 	{
-		Log(LOG_ERROR,"Invalid data received, or unknown location!");
+		Log(LOG_ERROR, "Invalid data received, or unknown location!");
 		return;
 	}
 	/*
@@ -165,58 +162,58 @@ void CDarkSky::GetMeterDetails()
 	*/
 
 	float temp;
-	int humidity=0;
-	int barometric=0;
-	int barometric_forcast=baroForecastNoInfo;
+	int humidity = 0;
+	int barometric = 0;
+	int barometric_forcast = baroForecastNoInfo;
 
-	temp=root["currently"]["temperature"].asFloat();
+	temp = root["currently"]["temperature"].asFloat();
 	//Convert to celcius
-	temp=float((temp-32)*(5.0/9.0));
+	temp = float((temp - 32) * (5.0 / 9.0));
 
-	if (root["currently"]["humidity"].empty()==false)
+	if (root["currently"]["humidity"].empty() == false)
 	{
-		humidity = round(root["currently"]["humidity"].asFloat() * 100.0F);
+		humidity = ground(root["currently"]["humidity"].asFloat() * 100.0F);
 	}
-	if (root["currently"]["pressure"].empty()==false)
+	if (root["currently"]["pressure"].empty() == false)
 	{
-		barometric=atoi(root["currently"]["pressure"].asString().c_str());
-		if (barometric<1000)
-			barometric_forcast=baroForecastRain;
-		else if (barometric<1020)
-			barometric_forcast=baroForecastCloudy;
-		else if (barometric<1030)
-			barometric_forcast=baroForecastPartlyCloudy;
+		barometric = atoi(root["currently"]["pressure"].asString().c_str());
+		if (barometric < 1000)
+			barometric_forcast = baroForecastRain;
+		else if (barometric < 1020)
+			barometric_forcast = baroForecastCloudy;
+		else if (barometric < 1030)
+			barometric_forcast = baroForecastPartlyCloudy;
 		else
-			barometric_forcast=baroForecastSunny;
+			barometric_forcast = baroForecastSunny;
 
-		if (root["currently"]["icon"].empty()==false)
+		if (root["currently"]["icon"].empty() == false)
 		{
-			std::string forcasticon=root["currently"]["icon"].asString();
-			if ((forcasticon=="partly-cloudy-day")||(forcasticon=="partly-cloudy-night"))
+			std::string forcasticon = root["currently"]["icon"].asString();
+			if ((forcasticon == "partly-cloudy-day") || (forcasticon == "partly-cloudy-night"))
 			{
-				barometric_forcast=baroForecastPartlyCloudy;
+				barometric_forcast = baroForecastPartlyCloudy;
 			}
-			else if (forcasticon=="cloudy")
+			else if (forcasticon == "cloudy")
 			{
-				barometric_forcast=baroForecastCloudy;
+				barometric_forcast = baroForecastCloudy;
 			}
-			else if ((forcasticon=="clear-day")||(forcasticon=="clear-night"))
+			else if ((forcasticon == "clear-day") || (forcasticon == "clear-night"))
 			{
-				barometric_forcast=baroForecastSunny;
+				barometric_forcast = baroForecastSunny;
 			}
-			else if ((forcasticon=="rain")||(forcasticon=="snow"))
+			else if ((forcasticon == "rain") || (forcasticon == "snow"))
 			{
-				barometric_forcast=baroForecastRain;
+				barometric_forcast = baroForecastRain;
 			}
 		}
 	}
 
-	if (barometric!=0)
+	if (barometric != 0)
 	{
 		//Add temp+hum+baro device
 		SendTempHumBaroSensor(1, 255, temp, humidity, static_cast<float>(barometric), barometric_forcast, "THB");
 	}
-	else if (humidity!=0)
+	else if (humidity != 0)
 	{
 		//add temp+hum device
 		SendTempHumSensor(1, 255, temp, humidity, "TempHum");
@@ -228,19 +225,19 @@ void CDarkSky::GetMeterDetails()
 	}
 
 	//Wind
-	int wind_degrees=-1;
-	float windspeed_ms=0;
-	float windgust_ms=0;
-	float wind_temp=temp;
-	float wind_chill=temp;
+	int wind_degrees = -1;
+	float windspeed_ms = 0;
+	float windgust_ms = 0;
+	float wind_temp = temp;
+	float wind_chill = temp;
 	//int windgust=1;
 	//float windchill=-1;
 
-	if (root["currently"]["windBearing"].empty()==false)
+	if (root["currently"]["windBearing"].empty() == false)
 	{
-		wind_degrees=atoi(root["currently"]["windBearing"].asString().c_str());
+		wind_degrees = atoi(root["currently"]["windBearing"].asString().c_str());
 	}
-	if (root["currently"]["windSpeed"].empty()==false)
+	if (root["currently"]["windSpeed"].empty() == false)
 	{
 		if ((root["currently"]["windSpeed"] != "N/A") && (root["currently"]["windSpeed"] != "--"))
 		{
@@ -252,7 +249,7 @@ void CDarkSky::GetMeterDetails()
 			}
 		}
 	}
-	if (root["currently"]["windGust"].empty()==false)
+	if (root["currently"]["windGust"].empty() == false)
 	{
 		if ((root["currently"]["windGust"] != "N/A") && (root["currently"]["windGust"] != "--"))
 		{
@@ -264,66 +261,66 @@ void CDarkSky::GetMeterDetails()
 			}
 		}
 	}
-	if (root["currently"]["apparentTemperature"].empty()==false)
+	if (root["currently"]["apparentTemperature"].empty() == false)
 	{
 		if ((root["currently"]["apparentTemperature"] != "N/A") && (root["currently"]["apparentTemperature"] != "--"))
 		{
 			wind_chill = static_cast<float>(atof(root["currently"]["apparentTemperature"].asString().c_str()));
 			//Convert to celcius
-			wind_chill=float((wind_chill-32)*(5.0/9.0));
+			wind_chill = float((wind_chill - 32) * (5.0 / 9.0));
 		}
 	}
-	if (wind_degrees!=-1)
+	if (wind_degrees != -1)
 	{
 		RBUF tsen;
-		memset(&tsen,0,sizeof(RBUF));
-		tsen.WIND.packetlength=sizeof(tsen.WIND)-1;
-		tsen.WIND.packettype=pTypeWIND;
-		tsen.WIND.subtype=sTypeWIND4;
-		tsen.WIND.battery_level=9;
-		tsen.WIND.rssi=12;
-		tsen.WIND.id1=0;
-		tsen.WIND.id2=1;
+		memset(&tsen, 0, sizeof(RBUF));
+		tsen.WIND.packetlength = sizeof(tsen.WIND) - 1;
+		tsen.WIND.packettype = pTypeWIND;
+		tsen.WIND.subtype = sTypeWIND4;
+		tsen.WIND.battery_level = 9;
+		tsen.WIND.rssi = 12;
+		tsen.WIND.id1 = 0;
+		tsen.WIND.id2 = 1;
 
-		float winddir=float(wind_degrees);
-		int aw=round(winddir);
-		tsen.WIND.directionh=(BYTE)(aw/256);
-		aw-=(tsen.WIND.directionh*256);
-		tsen.WIND.directionl=(BYTE)(aw);
+		float winddir = float(wind_degrees);
+		int aw = ground(winddir);
+		tsen.WIND.directionh = (BYTE)(aw / 256);
+		aw -= (tsen.WIND.directionh * 256);
+		tsen.WIND.directionl = (BYTE)(aw);
 
-		tsen.WIND.av_speedh=0;
-		tsen.WIND.av_speedl=0;
-		int sw = round(windspeed_ms * 10.0F);
-		tsen.WIND.av_speedh=(BYTE)(sw/256);
-		sw-=(tsen.WIND.av_speedh*256);
-		tsen.WIND.av_speedl=(BYTE)(sw);
+		tsen.WIND.av_speedh = 0;
+		tsen.WIND.av_speedl = 0;
+		int sw = ground(windspeed_ms * 10.0F);
+		tsen.WIND.av_speedh = (BYTE)(sw / 256);
+		sw -= (tsen.WIND.av_speedh * 256);
+		tsen.WIND.av_speedl = (BYTE)(sw);
 
-		tsen.WIND.gusth=0;
-		tsen.WIND.gustl=0;
-		int gw = round(windgust_ms * 10.0F);
-		tsen.WIND.gusth=(BYTE)(gw/256);
-		gw-=(tsen.WIND.gusth*256);
-		tsen.WIND.gustl=(BYTE)(gw);
+		tsen.WIND.gusth = 0;
+		tsen.WIND.gustl = 0;
+		int gw = ground(windgust_ms * 10.0F);
+		tsen.WIND.gusth = (BYTE)(gw / 256);
+		gw -= (tsen.WIND.gusth * 256);
+		tsen.WIND.gustl = (BYTE)(gw);
 
 		//this is not correct, why no wind temperature? and only chill?
-		tsen.WIND.chillh=0;
-		tsen.WIND.chilll=0;
-		tsen.WIND.temperatureh=0;
-		tsen.WIND.temperaturel=0;
+		tsen.WIND.chillh = 0;
+		tsen.WIND.chilll = 0;
+		tsen.WIND.temperatureh = 0;
+		tsen.WIND.temperaturel = 0;
 
-		tsen.WIND.tempsign=(wind_temp>=0)?0:1;
-		int at10 = round(std::abs(wind_temp * 10.0F));
-		tsen.WIND.temperatureh=(BYTE)(at10/256);
-		at10-=(tsen.WIND.temperatureh*256);
-		tsen.WIND.temperaturel=(BYTE)(at10);
+		tsen.WIND.tempsign = (wind_temp >= 0) ? 0 : 1;
+		int at10 = ground(std::abs(wind_temp * 10.0F));
+		tsen.WIND.temperatureh = (BYTE)(at10 / 256);
+		at10 -= (tsen.WIND.temperatureh * 256);
+		tsen.WIND.temperaturel = (BYTE)(at10);
 
-		tsen.WIND.chillsign=(wind_chill>=0)?0:1;
-		at10 = round(std::abs(wind_chill * 10.0F));
-		tsen.WIND.chillh=(BYTE)(at10/256);
-		at10-=(tsen.WIND.chillh*256);
-		tsen.WIND.chilll=(BYTE)(at10);
+		tsen.WIND.chillsign = (wind_chill >= 0) ? 0 : 1;
+		at10 = ground(std::abs(wind_chill * 10.0F));
+		tsen.WIND.chillh = (BYTE)(at10 / 256);
+		at10 -= (tsen.WIND.chillh * 256);
+		tsen.WIND.chilll = (BYTE)(at10);
 
-		sDecodeRXMessage(this, (const unsigned char *)&tsen.WIND, nullptr, 255, nullptr);
+		sDecodeRXMessage(this, (const unsigned char*)&tsen.WIND, nullptr, 255, nullptr);
 	}
 
 	//UV
@@ -340,7 +337,7 @@ void CDarkSky::GetMeterDetails()
 	}
 
 	//Rain
-	if (root["currently"]["precipIntensity"].empty()==false)
+	if (root["currently"]["precipIntensity"].empty() == false)
 	{
 		if ((root["currently"]["precipIntensity"] != "N/A") && (root["currently"]["precipIntensity"] != "--"))
 		{
@@ -353,22 +350,22 @@ void CDarkSky::GetMeterDetails()
 	}
 
 	//Visibility
-	if (root["currently"]["visibility"].empty()==false)
+	if (root["currently"]["visibility"].empty() == false)
 	{
 		if ((root["currently"]["visibility"] != "N/A") && (root["currently"]["visibility"] != "--"))
 		{
 			float visibility = static_cast<float>(atof(root["currently"]["visibility"].asString().c_str())) * 1.60934F; // miles to km
-			if (visibility>=0)
+			if (visibility >= 0)
 			{
 				_tGeneralDevice gdevice;
-				gdevice.subtype=sTypeVisibility;
-				gdevice.floatval1=visibility;
-				sDecodeRXMessage(this, (const unsigned char *)&gdevice, nullptr, 255, nullptr);
+				gdevice.subtype = sTypeVisibility;
+				gdevice.floatval1 = visibility;
+				sDecodeRXMessage(this, (const unsigned char*)&gdevice, nullptr, 255, nullptr);
 			}
 		}
 	}
 	//Solar Radiation
-	if (root["currently"]["ozone"].empty()==false)
+	if (root["currently"]["ozone"].empty() == false)
 	{
 		if ((root["currently"]["ozone"] != "N/A") && (root["currently"]["ozone"] != "--"))
 		{
