@@ -4,13 +4,13 @@
 
 class CDummy : public CDomoticzHardwareBase
 {
-public:
-	explicit CDummy(const int ID);
-	~CDummy(void);
-	bool WriteToHardware(const char *pdata, const unsigned char length) override;
-private:
+      public:
+	explicit CDummy(int ID);
+	~CDummy() override;
+	bool WriteToHardware(const char *pdata, unsigned char length) override;
+
+      private:
 	void Init();
 	bool StartHardware() override;
 	bool StopHardware() override;
 };
-
