@@ -4,7 +4,6 @@
 #include "hardwaretypes.h"
 #include "../main/Helper.h"
 #include "../main/SQLHelper.h"
-#include "../main/localtime_r.h"
 
 CEvohomeTCP::CEvohomeTCP(const int ID, const std::string &IPAddress, const unsigned short usIPPort, const std::string &UserContID) :
 
@@ -40,14 +39,14 @@ bool CEvohomeTCP::StopHardware()
 void CEvohomeTCP::OnConnect()
 {
     CEvohomeRadio::OnConnect();
-	_log.Log(LOG_STATUS,"evohome TCP/IP: connected to: %s:%d", m_szIPAddress.c_str(), m_usIPPort);
+	Log(LOG_STATUS,"Connected to: %s:%d", m_szIPAddress.c_str(), m_usIPPort);
 	m_bIsStarted=true;
 	sOnConnected(this);
 }
 
 void CEvohomeTCP::OnDisconnect()
 {
-	_log.Log(LOG_STATUS,"evohome TCP/IP: disconnected");
+	Log(LOG_STATUS,"Disconnected");
 }
 
 void CEvohomeTCP::Do_Work()
@@ -59,7 +58,7 @@ void CEvohomeTCP::Do_Work()
 
 	int sec_counter = 0;
 
-	_log.Log(LOG_STATUS, "evohome TCP/IP: trying to connect to %s:%d", m_szIPAddress.c_str(), m_usIPPort);
+	Log(LOG_STATUS, "Trying to connect to %s:%d", m_szIPAddress.c_str(), m_usIPPort);
 	connect(m_szIPAddress,m_usIPPort);
 	while (!IsStopRequested(1000))
 	{
@@ -74,14 +73,14 @@ void CEvohomeTCP::Do_Work()
 
 	terminate();
 
-	_log.Log(LOG_STATUS,"evohome TCP/IP: TCP/IP Worker stopped...");
+	Log(LOG_STATUS,"Worker stopped...");
 }
 
 void CEvohomeTCP::OnData(const unsigned char *pData, size_t length)
 {
 	try
 	{
-		//_log.Log(LOG_NORM,"evohome: received %ld bytes",len);
+		//Log(LOG_NORM,"Received %ld bytes",len);
 		HandleLoopData((const char *)pData, length);
 	}
 	catch (...)
@@ -105,15 +104,15 @@ void CEvohomeTCP::OnError(const boost::system::error_code& error)
 		(error == boost::asio::error::timed_out)
 		)
 	{
-		_log.Log(LOG_ERROR, "evohome TCP/IP: Can not connect to: %s:%d", m_szIPAddress.c_str(), m_usIPPort);
+		Log(LOG_ERROR, "Can't connect to: %s:%d", m_szIPAddress.c_str(), m_usIPPort);
 	}
 	else if (
 		(error == boost::asio::error::eof) ||
 		(error == boost::asio::error::connection_reset)
 		)
 	{
-		_log.Log(LOG_STATUS, "evohome TCP/IP: Connection reset!");
+		Log(LOG_STATUS, "Connection reset!");
 	}
 	else
-		_log.Log(LOG_ERROR, "evohome TCP/IP: %s", error.message().c_str());
+		Log(LOG_ERROR, "Error: %s", error.message().c_str());
 }
