@@ -51,7 +51,6 @@ Connection information:
 #include "../main/Logger.h"
 #include "hardwaretypes.h"
 #include "../main/RFXtrx.h"
-#include "../main/localtime_r.h"
 #include "../main/mainworker.h"
 #include "../main/SQLHelper.h"
 #include <sys/syscall.h>
@@ -407,9 +406,9 @@ bool CGpio::CreateDomoticzDevices()
 		}
 		if (createNewDevice)
 			m_sql.safe_query(
-				"INSERT INTO DeviceStatus (HardwareID, DeviceID, Unit, Type, SubType, SwitchType, Used, SignalLevel, BatteryLevel, Name, nValue, sValue, Options) "
-				"VALUES (%d, 0, %d, %d, %d, %d, 0, 12, 255, '%q', %d, '', %d)",
-				m_HwdID, it->GetPin(), pTypeLighting1, sTypeIMPULS, int(STYPE_OnOff), it->GetIsInput() ? "Input" : "Output", GPIORead(it->GetPin(), "value"), it->GetIsInput() ? GPIO_IN
+				"INSERT INTO DeviceStatus (HardwareID, OrgHardwareID, DeviceID, Unit, Type, SubType, SwitchType, Used, SignalLevel, BatteryLevel, Name, nValue, sValue, Options) "
+				"VALUES (%d, %d, 0, %d, %d, %d, %d, 0, 12, 255, '%q', %d, '', %d)",
+				m_HwdID, 0, it->GetPin(), pTypeLighting1, sTypeIMPULS, int(STYPE_OnOff), it->GetIsInput() ? "Input" : "Output", GPIORead(it->GetPin(), "value"), it->GetIsInput() ? GPIO_IN
 : GPIO_OUT);
 
 		result = m_sql.safe_query("SELECT Name,nValue,Options FROM DeviceStatus WHERE (HardwareID==%d) AND (Unit==%d)",	m_HwdID, it->GetPin());
