@@ -3,15 +3,12 @@
 #include "../main/Helper.h"
 #include "../main/Logger.h"
 #include "hardwaretypes.h"
-#include "../main/localtime_r.h"
 #include "../main/RFXtrx.h"
 #include "../main/SQLHelper.h"
 #include "../httpclient/HTTPClient.h"
 #include "../main/mainworker.h"
 #include "../main/json_helper.h"
 
-#define round(a) (int)(a + .5)
-
 //#define DEBUG_ICYThermostat
 
 #define ICY_LOGIN_URL "https://portal.icy.nl/login"
@@ -89,21 +86,6 @@ bool CICYThermostat::WriteToHardware(const char * /*pdata*/, const unsigned char
 	return false;
 }
 
-void CICYThermostat::SendSetPointSensor(const unsigned char Idx, const float Temp, const std::string &defaultname)
-{
-	_tThermostat thermos;
-	thermos.subtype = sTypeThermSetpoint;
-	thermos.id1 = 0;
-	thermos.id2 = 0;
-	thermos.id3 = 0;
-	thermos.id4 = Idx;
-	thermos.dunit = 0;
-
-	thermos.temp = Temp;
-
-	sDecodeRXMessage(this, (const unsigned char *)&thermos, defaultname.c_str(), 255, nullptr);
-}
-
 bool CICYThermostat::GetSerialAndToken()
 {
 	std::stringstream sstr;
@@ -246,7 +228,7 @@ void CICYThermostat::GetMeterDetails()
 		Log(LOG_ERROR, "Invalid data received!");
 		return;
 	}
-	SendSetPointSensor(1, root["temperature1"].asFloat(), "Room Setpoint");
+	SendSetPointSensor(0, 0, 0, 1, 0, 255, root["temperature1"].asFloat(), "Room Setpoint");
 	if (root["temperature2"].empty() == true)
 	{
 		Log(LOG_ERROR, "Invalid data received!");
