@@ -4,7 +4,6 @@
 #include "../main/Helper.h"
 #include "../main/RFXtrx.h"
 #include "../main/SQLHelper.h"
-#include "../main/localtime_r.h"
 #include "../main/mainworker.h"
 #include "../main/WebServerHelper.h"
 #include "../webserver/cWebem.h"
@@ -16,8 +15,6 @@
 
 #include <ctime>
 
-#define round(a) ( int ) ( a + .5 )
-
 // Mapping to device idx for backwards compatibility
 #define MsgID0		101
 #define MsgID1		1
@@ -144,15 +141,14 @@ void OTGWBase::UpdateSwitch(const unsigned char Idx, const bool bOn, const std::
 
 void OTGWBase::UpdateSetPointSensor(const unsigned char Idx, const float Temp, const std::string &defaultname)
 {
-	_tThermostat thermos;
-	thermos.subtype=sTypeThermSetpoint;
+	_tSetpoint thermos;
+	thermos.subtype=sTypeSetpoint;
 	thermos.id1=0;
 	thermos.id2=0;
 	thermos.id3=0;
 	thermos.id4=Idx;
 	thermos.dunit=0;
-	thermos.temp=Temp;
-
+	thermos.value=Temp;
 	sDecodeRXMessage(this, (const unsigned char *)&thermos, defaultname.c_str(), 255, nullptr);
 }
 
@@ -246,10 +242,10 @@ bool OTGWBase::WriteToHardware(const char *pdata, const unsigned char /*length*/
 		}
 		SwitchLight(nodeID, LCmd, svalue);
 	}
-	else if ((packettype == pTypeThermostat) && (subtype == sTypeThermSetpoint))
+	else if ((packettype == pTypeSetpoint) && (subtype == sTypeSetpoint))
 	{
-		const _tThermostat *pMeter = reinterpret_cast<const _tThermostat *>(pdata);
-		float temp = pMeter->temp;
+		const _tSetpoint* pMeter = reinterpret_cast<const _tSetpoint*>(pdata);
+		float temp = pMeter->value;
 		unsigned char idx = pMeter->id4;
 		SetSetpoint(idx, temp);
 	}
@@ -611,7 +607,7 @@ namespace http {
 			stdupper(rcmnd);
 			cmnd = rcmnd + rdata;
 
-			OTGWBase *pOTGW = reinterpret_cast<OTGWBase*>(m_mainworker.GetHardware(atoi(idx.c_str())));
+			OTGWBase *pOTGW = dynamic_cast<OTGWBase*>(m_mainworker.GetHardware(atoi(idx.c_str())));
 			if (pOTGW == nullptr)
 				return;
 
