@@ -5,13 +5,14 @@
 
 class OnkyoAVTCP : public CDomoticzHardwareBase, ASyncTCP
 {
-public:
-	OnkyoAVTCP(const int ID, const std::string &IPAddress, const unsigned short usIPPort);
-	~OnkyoAVTCP(void);
-	bool WriteToHardware(const char *pdata, const unsigned char length) override;
-	boost::signals2::signal<void()>	sDisconnected;
+      public:
+	OnkyoAVTCP(int ID, const std::string &IPAddress, unsigned short usIPPort);
+	~OnkyoAVTCP() override;
+	bool WriteToHardware(const char *pdata, unsigned char length) override;
+	boost::signals2::signal<void()> sDisconnected;
 	bool SendPacket(const char *pdata);
-private:
+
+      private:
 	bool SendPacket(const char *pCmd, const char *pArg);
 	bool StartHardware() override;
 	bool StopHardware() override;
@@ -19,17 +20,18 @@ private:
 	void ReceiveMessage(const char *pData, int Len);
 	void ReceiveSwitchMsg(const char *pData, int Len, bool muting, int ID);
 	bool ReceiveXML(const char *pData, int Len);
-	void EnsureSwitchDevice(int Unit, const char *options = NULL);
-	std::string BuildSelectorOptions(const std::string & names, const std::string & ids);
+	void EnsureSwitchDevice(int Unit, const char *options = nullptr);
+	std::string BuildSelectorOptions(const std::string &names, const std::string &ids);
 	void Do_Work();
 
 	void OnConnect() override;
 	void OnDisconnect() override;
 	void OnData(const unsigned char *pData, size_t length) override;
-	void OnError(const boost::system::error_code& error) override;
+	void OnError(const boost::system::error_code &error) override;
 
 	void ParseData(const unsigned char *pData, int Len);
-private:
+
+      private:
 	int m_retrycntr;
 	unsigned char *m_pPartialPkt;
 	int m_PPktLen;
