@@ -4,7 +4,6 @@
 #include "../main/Logger.h"
 #include "../httpclient/UrlEncode.h"
 #include "hardwaretypes.h"
-#include "../main/localtime_r.h"
 #include "../httpclient/HTTPClient.h"
 #include "../main/json_helper.h"
 #include "../main/RFXtrx.h"
@@ -46,19 +45,29 @@ std::string ReadFile(std::string filename)
 }
 #endif
 
-#define OWM_onecall_URL "https://api.openweathermap.org/data/2.5/onecall?"
+#define OWM_v2_onecall_URL "https://api.openweathermap.org/data/2.5/onecall?"
+#define OWM_v3_onecall_URL "https://api.openweathermap.org/data/3.0/onecall?"
 #define OWM_Get_City_Details "https://api.openweathermap.org/data/2.5/weather?"
 #define OWM_icon_URL "https://openweathermap.org/img/wn/"	// for example 10d@4x.png
 #define OWM_forecast_URL "https://openweathermap.org/city/"
 
-COpenWeatherMap::COpenWeatherMap(const int ID, const std::string &APIKey, const std::string &Location, const int adddayforecast, const int addhourforecast, const int adddescdev, const int owmforecastscreen) :
+COpenWeatherMap::COpenWeatherMap(
+	const int ID,
+	const std::string &APIKey,
+	const std::string &Location,
+	const int adddayforecast,
+	const int addhourforecast,
+	const int adddescdev,
+	const int owmforecastscreen,
+	const bool bUseAPIv3) :
 	m_APIKey(APIKey),
 	m_Location(Location),
 	m_Language("en"),
 	m_add_dayforecast(adddayforecast),
 	m_add_hourforecast(addhourforecast),
 	m_add_descriptiondevices(adddescdev),
-	m_use_owminforecastscreen(owmforecastscreen)
+	m_use_owminforecastscreen(owmforecastscreen),
+	m_bUseAPIv3(bUseAPIv3)
 {
 	m_HwdID=ID;
 
@@ -106,8 +115,6 @@ bool COpenWeatherMap::ResolveOWMCityLonLat(const std::string sURL, double& latit
 {
 	std::string sResult;
 
-	Debug(DEBUG_NORM, "Get data from %s", sURL.c_str());
-
 	try
 	{
 		if (!HTTPClient::GET(sURL, sResult))
@@ -165,8 +172,8 @@ bool COpenWeatherMap::StartHardware()
 	std::string sValue, sLatitude, sLongitude;
 	std::vector<std::string> strarray;
 	uint32_t cityid;
-	Debug(DEBUG_NORM, "Got location parameter %s", m_Location.c_str());
-	Debug(DEBUG_NORM, "Starting with setting %d, %d, %d, %d", m_add_dayforecast, m_add_hourforecast, m_add_descriptiondevices, m_use_owminforecastscreen);
+	Debug(DEBUG_HARDWARE, "Got location parameter %s", m_Location.c_str());
+	Debug(DEBUG_HARDWARE, "Starting with setting %d, %d, %d, %d", m_add_dayforecast, m_add_hourforecast, m_add_descriptiondevices, m_use_owminforecastscreen);
 
 	if (m_Location.empty())
 	{
@@ -404,7 +411,7 @@ Json::Value COpenWeatherMap::GetForecastData()
 	root["appid"] = m_APIKey;
 	root["cityid"] = m_CityID;
 
-	Debug(DEBUG_NORM, "GetForecastData: \n%s", root.toStyledString().c_str());
+	Debug(DEBUG_HARDWARE, "GetForecastData: \n%s", root.toStyledString().c_str());
 	return root;
 }
 
@@ -435,7 +442,7 @@ std::string COpenWeatherMap::GetHourFromUTCtimestamp(const uint8_t hournr, const
 	}
 
 	sHour = strarray[0];
-	Debug(DEBUG_NORM, "Determining hour for hour %d from timestamp %s (string %s)", hournr, UTCtimestamp.c_str(), sHour.c_str());
+	Debug(DEBUG_HARDWARE, "Determining hour for hour %d from timestamp %s (string %s)", hournr, UTCtimestamp.c_str(), sHour.c_str());
 
 	return sHour;
 }
@@ -518,27 +525,36 @@ bool COpenWeatherMap::ProcessForecast(Json::Value &forecast, const std::string &
 				uvi = forecast["uvi"].asFloat();
 			}
 
-			//Rain (only present if there is rain (or snow))
-			if (!forecast["rain"].empty())
+			//Set Rain to 0 when PoP = 0 (Probability of precipitation)
+			if (pop == 0)
 			{
-				if (!forecast["rain"].isObject())
-				{
-					rainmm = forecast["rain"].asFloat();
-				}
-				else if (!forecast["rain"]["1h"].empty())
-				{
-					rainmm = forecast["rain"]["1h"].asFloat();
-				}
+				rainmm = 0;
 			}
-			if (!forecast["snow"].empty())
+			else
 			{
-				if (!forecast["snow"].isArray())
+				//Rain (only present if there is rain (or snow))
+				rainmm = 0; // feels weird, but sometimes it seems to happen that PoP > 0 but no rain/snow data
+				if (!forecast["rain"].empty())
 				{
-					rainmm = rainmm + forecast["snow"].asFloat();
+					if (!forecast["rain"].isObject())
+					{
+						rainmm = forecast["rain"].asFloat();
+					}
+					else if (!forecast["rain"]["1h"].empty())
+					{
+						rainmm = forecast["rain"]["1h"].asFloat();
+					}
 				}
-				else if (!forecast["snow"]["1h"].empty())
+				if (!forecast["snow"].empty())
 				{
-					rainmm = rainmm + forecast["snow"]["1h"].asFloat();
+					if (!forecast["snow"].isObject())
+					{
+						rainmm = rainmm + forecast["snow"].asFloat();
+					}
+					else if (!forecast["snow"]["1h"].empty())
+					{
+						rainmm = rainmm + forecast["snow"]["1h"].asFloat();
+					}
 				}
 			}
 
@@ -548,7 +564,7 @@ bool COpenWeatherMap::ProcessForecast(Json::Value &forecast, const std::string &
 			sName << "TempHumBaro " << period << " " << (count + 0);
 			SendTempHumBaroSensorFloat(NodeID, 255, maxtemp, humidity, barometric, barometric_forecast, sName.str());
 
-			NodeID++;;
+			NodeID++;
 			sName.str("");
 			sName.clear();
 			sName << "Weather Description " << period << " " << (count + 0);
@@ -565,7 +581,7 @@ bool COpenWeatherMap::ProcessForecast(Json::Value &forecast, const std::string &
 			if(m_add_descriptiondevices)
 				SendTextSensor(NodeID, 3, 255, periodname, sName.str());
 
-			NodeID++;;
+			NodeID++;
 			sName.str("");
 			sName.clear();
 			sName << "Minumum Temperature " << period << " " << (count + 0);
@@ -574,13 +590,13 @@ bool COpenWeatherMap::ProcessForecast(Json::Value &forecast, const std::string &
 				SendTempSensor(NodeID, 255, mintemp, sName.str());
 			}
 
-			NodeID++;;
+			NodeID++;
 			sName.str("");
 			sName.clear();
 			sName << "Wind " << period << " " << (count + 0);
 			SendWind(NodeID, 255, wind_degrees, windspeed_ms, 0, 0, 0, false, false, sName.str());
 
-			NodeID++;;
+			NodeID++;
 			sName.str("");
 			sName.clear();
 			sName << "UV Index " << period << " " << (count + 0);
@@ -592,14 +608,14 @@ bool COpenWeatherMap::ProcessForecast(Json::Value &forecast, const std::string &
 			NodeID++;
 			// We do not have visibility forecasts
 
-			NodeID++;;
+			NodeID++;
 			sName.str("");
 			sName.clear();
 			sName << "Clouds % " << period << " " << (count + 0);
 			SendPercentageSensor(NodeID, 1, 255, clouds, sName.str());
 
-			NodeID++;;
-			if ((rainmm != 9999.00F) && (rainmm >= 0.00F))
+			NodeID++;
+			if (rainmm != 9999.00F)
 			{
 				sName.str("");
 				sName.clear();
@@ -607,18 +623,18 @@ bool COpenWeatherMap::ProcessForecast(Json::Value &forecast, const std::string &
 				SendRainRateSensor(NodeID, 255, rainmm, sName.str());
 			}
 
-			NodeID++;;
+			NodeID++;
 			sName.str("");
 			sName.clear();
 			sName << "Precipitation " << period << " " << (count + 0);
 			SendPercentageSensor(NodeID, 1, 255, (pop * 100), sName.str());
 
 			bResult = true;
-			Debug(DEBUG_NORM, "Processed forecast for period %d: %s - %f - %f - %f",count, wdesc.c_str(), maxtemp, mintemp, pop);
+			Debug(DEBUG_HARDWARE, "Processed forecast for period %d: %s - %f - %f - %f",count, wdesc.c_str(), maxtemp, mintemp, pop);
 		}
 		catch(const std::exception& e)
 		{
-			Debug(DEBUG_NORM, "Processing forecast crashed for period %d on %s",count, e.what());
+			Debug(DEBUG_HARDWARE, "Processing forecast crashed for period %d on %s",count, e.what());
 		}
 	}
 
@@ -655,13 +671,16 @@ void COpenWeatherMap::GetMeterDetails()
 	std::string sResult;
 	std::stringstream sURL;
 
-	sURL << OWM_onecall_URL;
+	if (!m_bUseAPIv3)
+		sURL << OWM_v2_onecall_URL;
+	else
+		sURL << OWM_v3_onecall_URL;
 	sURL << "lat=" << m_Lat << "&lon=" << m_Lon;
 	sURL << "&exclude=minutely";
 	sURL << "&appid=" << m_APIKey;
 	sURL << "&units=metric" << "&lang=" << m_Language;
 
-	Debug(DEBUG_NORM, "Get data from %s", sURL.str().c_str());
+	Debug(DEBUG_HARDWARE, "Get data from %s", sURL.str().c_str());
 
 	try
 	{
@@ -865,7 +884,7 @@ void COpenWeatherMap::GetMeterDetails()
 				break;
 			}
 			std::string sDay = GetDayFromUTCtimestamp(iDay, dailyfc[iDay]["dt"].asString());
-			Debug(DEBUG_NORM, "Processing daily forecast for %s (%s)", dailyfc[iDay]["dt"].asString().c_str(), sDay.c_str());
+			Debug(DEBUG_HARDWARE, "Processing daily forecast for %s (%s)", dailyfc[iDay]["dt"].asString().c_str(), sDay.c_str());
 
 			Json::Value curday = dailyfc[iDay];
 
@@ -876,7 +895,7 @@ void COpenWeatherMap::GetMeterDetails()
 			iDay++;
 		}
 		while (!dailyfc[iDay].empty());
-		Debug(DEBUG_NORM, "Processed %d daily forecasts",iDay);
+		Debug(DEBUG_HARDWARE, "Processed %d daily forecasts",iDay);
 	}
 
 	// Process hourly forecast data if available
@@ -899,7 +918,7 @@ void COpenWeatherMap::GetMeterDetails()
 				break;
 			}
 			std::string sHour = GetHourFromUTCtimestamp(iHour, hourlyfc[iHour]["dt"].asString());
-			Debug(DEBUG_NORM, "Processing hourly forecast for %s (%s)", hourlyfc[iHour]["dt"].asString().c_str(), sHour.c_str());
+			Debug(DEBUG_HARDWARE, "Processing hourly forecast for %s (%s)", hourlyfc[iHour]["dt"].asString().c_str(), sHour.c_str());
 
 			Json::Value curhour = hourlyfc[iHour];
 
@@ -910,6 +929,6 @@ void COpenWeatherMap::GetMeterDetails()
 			iHour++;
 		}
 		while (!hourlyfc[iHour].empty());
-		Debug(DEBUG_NORM, "Processed %d hourly forecasts",iHour);
+		Debug(DEBUG_HARDWARE, "Processed %d hourly forecasts",iHour);
 	}
 }
