@@ -21,6 +21,8 @@ namespace Json
 	class Value;
 }
 
+extern const char* ZWave_Thermostat_Fan_Modes[];
+
 class COpenZWave : public ZWaveBase
 {
       public:
@@ -65,9 +67,6 @@ class COpenZWave : public ZWaveBase
 		time_t LastSeen;
 
 		// Thermostat settings
-		uint8_t tClockDay;
-		uint8_t tClockHour;
-		uint8_t tClockMinute;
 		int tMode;
 		int tFanMode;
 		std::vector<std::string> tModes;
@@ -154,7 +153,6 @@ class COpenZWave : public ZWaveBase
 	bool SwitchLight(_tZWaveDevice *pDevice, const int instanceID, const int value);
 	bool SwitchColor(const uint8_t nodeID, const uint8_t instanceID, const std::string &ColorStr);
 	void SetThermostatSetPoint(const uint8_t nodeID, const uint8_t instanceID, const uint8_t commandClass, const float value);
-	void SetClock(const uint8_t nodeID, const uint8_t instanceID, const uint8_t commandClass, const uint8_t day, const uint8_t hour, const uint8_t minute);
 	void SetThermostatMode(const uint8_t nodeID, const uint8_t instanceID, const uint8_t commandClass, const int tMode);
 	void SetThermostatFanMode(const uint8_t nodeID, const uint8_t instanceID, const uint8_t commandClass, const int fMode);
 	void UpdateDeviceBatteryStatus(const uint8_t nodeID, const int value);
