@@ -1,7 +1,6 @@
 #include "stdafx.h"
 #include "P1MeterSerial.h"
 #include "../main/Logger.h"
-#include "../main/localtime_r.h"
 #include "../main/Helper.h"
 #include "../main/SQLHelper.h"
 #include "../main/mainworker.h"
@@ -16,37 +15,6 @@
 #include <iostream>
 #include <ctime>
 
-#ifdef _DEBUG
-//#define DEBUG_P1_R
-#endif
-
-#ifdef DEBUG_P1_R
-//Belgium
-const char *szP1Test=R"p1_test(/FLU5\253770234_A
-
-0-0:96.1.4(50213)
-0-0:96.1.1(3153414731313030303037313930)
-0-0:1.0.0(190905142315S)
-1-0:1.8.1(000244.844*kWh)
-1-0:1.8.2(000226.027*kWh)
-1-0:2.8.1(000139.553*kWh)
-1-0:2.8.2(000045.390*kWh)
-0-0:96.14.0(0001)
-1-0:1.7.0(00.000*kW)
-1-0:2.7.0(00.198*kW)
-1-0:32.7.0(240.0*V)
-1-0:31.7.0(002*A)
-0-0:96.3.10(1)
-0-0:17.0.0(999.9*kW)
-1-0:31.4.0(999*A)
-0-0:96.13.0()
-0-1:24.1.0(003)
-0-1:96.1.1(37464C4F32313139303137303532)
-0-1:24.4.0(1)
-0-1:24.2.3(190905142001S)(00071.724*m3)
-!0F77)p1_test";
-#endif
-
 //
 //Class P1MeterSerial
 //
@@ -147,10 +115,6 @@ bool P1MeterSerial::StartHardware()
 	setReadCallback([this](auto d, auto l) { readCallback(d, l); });
 	sOnConnected(this);
 
-#ifdef DEBUG_P1_R
-	ParseP1Data((const uint8_t*)szP1Test, static_cast<int>(strlen(szP1Test)), m_bDisableCRC, m_ratelimit);
-#endif
-
 	return true;
 }
 
