@@ -5,7 +5,6 @@
 #include "../main/Logger.h"
 #include "../main/SQLHelper.h"
 #include "../main/RFXtrx.h"
-#include "../main/localtime_r.h"
 #include "../main/Noncopyable.h"
 #include "../main/WebServer.h"
 #include "../main/mainworker.h"
@@ -13,6 +12,7 @@
 #include <json/json.h>
 
 #include <boost/asio.hpp>
+#include <boost/asio/deadline_timer.hpp>
 
 #include "pinger/icmp_header.h"
 #include "pinger/ipv4_header.h"
@@ -22,23 +22,23 @@
 #if BOOST_VERSION >= 107000
 #define GET_IO_SERVICE(s) ((boost::asio::io_context&)(s).get_executor().context())
 #else
-#define GET_IO_SERVICE(s) ((s).get_io_service())
+#define GET_IO_SERVICE(s) ((s).get_io_context())
 #endif
 
 class pinger
 	: private domoticz::noncopyable
 {
 public:
-  pinger(boost::asio::io_service &io_service, const char *destination, const int iPingTimeoutms)
+  pinger(boost::asio::io_context &io_context, const char *destination, const int iPingTimeoutms)
 	  : num_replies_(0)
 	  , m_PingState(false)
-	  , resolver_(io_service)
-	  , socket_(io_service, boost::asio::ip::icmp::v4())
-	  , timer_(io_service)
+	  , resolver_(io_context)
+	  , socket_(io_context, boost::asio::ip::icmp::v4())
+	  , timer_(io_context)
 	  , sequence_number_(0)
   {
-	  boost::asio::ip::icmp::resolver::query query(boost::asio::ip::icmp::v4(), destination, "");
-	  destination_ = *resolver_.resolve(query);
+	  auto endpoints = resolver_.resolve(boost::asio::ip::icmp::v4(), destination, "");
+	  destination_ = endpoints.begin()->endpoint();
 
 	  num_tries_ = 1;
 	  PingTimeoutms_ = iPingTimeoutms;
@@ -333,11 +333,11 @@ void CPinger::ReloadNodes()
 void CPinger::Do_Ping_Worker(const PingNode &Node)
 {
 	bool bPingOK = false;
-	boost::asio::io_service io_service;
+	boost::asio::io_context io_context;
 	try
 	{
-		pinger p(io_service, Node.IP.c_str(), m_iPingTimeoutms);
-		io_service.run();
+		pinger p(io_context, Node.IP.c_str(), m_iPingTimeoutms);
+		io_context.run();
 		if (p.m_PingState == true)
 		{
 			bPingOK = true;
@@ -505,7 +505,7 @@ namespace http {
 				return;
 			if (pBaseHardware->HwdType != HTYPE_Pinger)
 				return;
-			CPinger *pHardware = reinterpret_cast<CPinger*>(pBaseHardware);
+			CPinger *pHardware = dynamic_cast<CPinger*>(pBaseHardware);
 
 			root["status"] = "OK";
 			root["title"] = "PingerSetMode";
@@ -543,7 +543,7 @@ namespace http {
 				return;
 			if (pBaseHardware->HwdType != HTYPE_Pinger)
 				return;
-			CPinger *pHardware = reinterpret_cast<CPinger*>(pBaseHardware);
+			CPinger *pHardware = dynamic_cast<CPinger*>(pBaseHardware);
 
 			root["status"] = "OK";
 			root["title"] = "PingerAddNode";
@@ -571,7 +571,7 @@ namespace http {
 				return;
 			if (pBaseHardware->HwdType != HTYPE_Pinger)
 				return;
-			CPinger *pHardware = reinterpret_cast<CPinger*>(pBaseHardware);
+			CPinger *pHardware = dynamic_cast<CPinger*>(pBaseHardware);
 
 			int NodeID = atoi(nodeid.c_str());
 			root["status"] = "OK";
@@ -597,7 +597,7 @@ namespace http {
 				return;
 			if (pBaseHardware->HwdType != HTYPE_Pinger)
 				return;
-			CPinger *pHardware = reinterpret_cast<CPinger*>(pBaseHardware);
+			CPinger *pHardware = dynamic_cast<CPinger*>(pBaseHardware);
 
 			int NodeID = atoi(nodeid.c_str());
 			root["status"] = "OK";
@@ -622,7 +622,7 @@ namespace http {
 				return;
 			if (pBaseHardware->HwdType != HTYPE_Pinger)
 				return;
-			CPinger *pHardware = reinterpret_cast<CPinger*>(pBaseHardware);
+			CPinger *pHardware = dynamic_cast<CPinger*>(pBaseHardware);
 
 			root["status"] = "OK";
 			root["title"] = "PingerClearNodes";
