@@ -4,7 +4,7 @@
 #include "DomoticzHardware.h"
 #include "P1MeterBase.h"
 
-#define RX_BUFFER_SIZE 256
+#define RX_BUFFER_SIZE 512
 
 class CRFXBase : public P1MeterBase
 {
@@ -41,11 +41,9 @@ class CRFXBase : public P1MeterBase
 	bool StartHardware() override = 0;
 	bool StopHardware() override = 0;
 
-	time_t m_LastP1Received = 0;
-
 	std::mutex readQueueMutex;
 	unsigned char m_rxbuffer[RX_BUFFER_SIZE] = { 0 };
-	unsigned char m_rxbufferpos = { 0 };
+	uint16_t m_rxbufferpos = { 0 };
 
       private:
 	static bool CheckValidRFXData(const uint8_t *pData);
