@@ -3,7 +3,6 @@
 #include "../main/Logger.h"
 #include "../main/RFXtrx.h"
 #include "../main/Helper.h"
-#include "../main/localtime_r.h"
 #include "../main/mainworker.h"
 #include "../main/SQLHelper.h"
 #include "../main/json_helper.h"
@@ -25,17 +24,18 @@ CRtl433::CRtl433(const int ID, const std::string& cmdline) :
 	m_cmdline(cmdline)
 {
 	// Basic protection from malicious command line
-	removeCharsFromString(m_cmdline, ":;/$()`<>|&");
+	removeCharsFromString(m_cmdline, ";/$()`<>|&");
 	m_HwdID = ID;
 	/*
-		#ifdef _DEBUG
-			std::string line = "{\"time\" : \"2020-05-21 12:24:06.740469\", \"protocol\" : 12, \"model\" : \"Oregon-UVR128\", \"id\" : 155, \"uv\" : 5, \"battery_ok\" : 1, \"mod\" : \"ASK\", \"freq\" : 433.864, \"rssi\" : -0.100, \"snr\" : 15.669, \"noise\" : -15.769}";
-			if (!ParseJsonLine(line))
-			{
-				// this is also logged when parsed data is invalid
-				Log(LOG_STATUS, "Unhandled sensor reading, please report: (%s)", line.c_str());
-			}
-		#endif
+const char* szRTLTest = R"rtl_test(
+{"time" : "2025-03-12 09:59:23", "model" : "Generic-Remote", "id" : 37418, "cmd" : 10, "tristate" : "XZ0X0XXX00XX", "mod" : "ASK", "freq" : 433.976, "rssi" : -0.124, "snr" : 17.206, "noise" : -17.330}
+)rtl_test";
+
+	if (!ParseJsonLine(szRTLTest))
+	{
+		// this is also logged when parsed data is invalid
+		Log(LOG_STATUS, "Unhandled sensor reading, please report: (%s)", szRTLTest);
+	}
 	*/
 }
 
@@ -67,7 +67,7 @@ bool CRtl433::StopHardware()
 
 bool CRtl433::ParseJsonLine(const std::string& sLine)
 {
-	std::map<std::string, std::string> _Field;
+	std::map<std::string, std::string> _Fields;
 	Json::Value root;
 
 	std::string errstr;
@@ -83,10 +83,10 @@ bool CRtl433::ParseJsonLine(const std::string& sLine)
 			{
 				std::string vname = root.getMemberNames()[ii];
 				std::string vvalue = root[root.getMemberNames()[ii]].asString();
-				_Field[vname] = vvalue;
+				_Fields[vname] = vvalue;
 			}
 		}
-		return ParseData(_Field);
+		return ParseData(_Fields);
 	}
 	return false;
 }
@@ -154,10 +154,19 @@ bool CRtl433::ParseData(std::map<std::string, std::string>& data)
 	bool haveLux = false;
 	float lux = 0;
 
+	bool haveMeter = false;
+	float meter = 0;
+
 	int snr = 12;  // Set to show "-" if no snr is received. rtl_433 uses automatic gain, better to use SNR instead of RSSI to report received RF Signal quality
 
 	int code = 0;
 
+	if (FindField(data, "center_frequency"))
+	{
+		// Frequency hoping
+		return true;
+	}
+
 	if (FindField(data, "id"))
 	{
 		id = atoi(data["id"].c_str());
@@ -283,7 +292,7 @@ bool CRtl433::ParseData(std::map<std::string, std::string>& data)
 	}
 	if (FindField(data, "light_klx"))
 	{
-		lux = ( (float)atof(data["light_klx"].c_str()) ) * 1000;
+		lux = ((float)atof(data["light_klx"].c_str())) * 1000;
 		haveLux = true;
 	}
 	if (FindField(data, "light_lux"))
@@ -291,6 +300,11 @@ bool CRtl433::ParseData(std::map<std::string, std::string>& data)
 		lux = (float)atof(data["light_lux"].c_str());
 		haveLux = true;
 	}
+	if (FindField(data, "volume_m3"))
+	{
+		meter = (float)atof(data["volume_m3"].c_str());
+		haveMeter = true;
+	}
 	if (FindField(data, "snr"))
 	{
 		/* Map the received Signal to Noise Ratio to the domoticz RSSI 4-bit field that has range of 0-11 (12-15 display '-' in device tab).
@@ -327,7 +341,7 @@ bool CRtl433::ParseData(std::map<std::string, std::string>& data)
 			0, model, m_Name, snr);
 		bDone = true;
 	}
-	if (FindField(data, "switch1") && FindField(data, "id"))
+	else if (FindField(data, "switch1") && FindField(data, "id"))
 	{
 		std::stringstream sstr;
 		sstr << std::hex << data["id"];
@@ -350,6 +364,24 @@ bool CRtl433::ParseData(std::map<std::string, std::string>& data)
 			bDone = true;
 		}
 	}
+	else if (!strcmp(model.c_str(), "Generic-Remote"))
+	{
+		//This could be anything, for now I only received the cmd's of a door opener
+		//10 = open, 14 = closed
+
+		if (FindField(data, "cmd"))
+		{
+			int cmd = atoi(data["cmd"].c_str());
+			bool bOn = (cmd != 10);
+			unsigned int switchidx = (id & 0xfffffff) | ((channel & 0xf) << 28);
+			SendSwitch(switchidx,
+				(const uint8_t)unit,
+				batterylevel,
+				bOn,
+				0, model, m_Name, snr);
+			bDone = true;
+		}
+	}
 
 	if (bDone)
 		return true;
@@ -450,6 +482,11 @@ bool CRtl433::ParseData(std::map<std::string, std::string>& data)
 		SendLuxSensor((uint8_t)sensoridx, (uint8_t)unit, batterylevel, lux, model);
 		bHandled = true;
 	}
+	if (haveMeter)
+	{
+		SendMeterSensor((uint8_t)sensoridx, (uint8_t)unit, batterylevel, meter, model);
+		bHandled = true;
+	}
 
 	if (!strcmp(model.c_str(), "X10-Security"))
 	{
@@ -647,7 +684,7 @@ void CRtl433::Do_Work()
 			}
 #else
 			line[line_offset] = 0;
-			if (fgets(line + line_offset, sizeof(line) - 1 - line_offset, _hPipe) != nullptr)
+			if (fgets(line + line_offset, static_cast<int>(sizeof(line) - 1 - line_offset), _hPipe) != nullptr)
 			{
 				if ((line[strlen(line) - 1] != '\n') && (line[strlen(line) - 1] != '\r'))
 				{
