@@ -71,7 +71,7 @@ class SatelIntegra : public CDomoticzHardwareBase
 	int m_modelIndex;
 	bool m_data32;
 	sockaddr_in m_addr;
-	int m_socket;
+	SOCKET m_socket;
 	const unsigned short m_IPPort;
 	const std::string m_IPAddress;
 	int m_pollInterval;
