@@ -3,7 +3,6 @@
 #include "../main/Logger.h"
 #include "../main/Helper.h"
 #include <iostream>
-#include "../main/localtime_r.h"
 #include "../main/mainworker.h"
 
 #include "../main/SQLHelper.h"
@@ -205,14 +204,14 @@ void SolarMaxTCP::Do_Work()
 	}
 	disconnect();
 
-	Log(LOG_STATUS, "TCP/IP Worker stopped...");
+	Log(LOG_STATUS, "Worker stopped...");
 }
 
 void SolarMaxTCP::write(const char *data, size_t size)
 {
 	if (m_socket == INVALID_SOCKET)
 		return; //not connected!
-	send(m_socket, data, size, 0);
+	send(m_socket, data, (int)size, 0);
 }
 
 bool SolarMaxTCP::WriteToHardware(const char *pdata, const unsigned char length)
