@@ -35,7 +35,7 @@ class SolarMaxTCP : public CDomoticzHardwareBase
 	int m_bufferpos;
 	std::shared_ptr<std::thread> m_thread;
 	sockaddr_in m_addr;
-	int m_socket;
+	SOCKET m_socket;
 	std::string m_endpoint;
 	unsigned char m_buffer[512];
 };
