@@ -6,19 +6,21 @@
 
 class CVolcraftCO20 : public CDomoticzHardwareBase
 {
-public:
-	explicit CVolcraftCO20(const int ID);
-	~CVolcraftCO20(void);
+      public:
+	explicit CVolcraftCO20(int ID);
+	~CVolcraftCO20() override = default;
 
-	bool WriteToHardware(const char *pdata, const unsigned char length) override;
-private:
+	bool WriteToHardware(const char *pdata, unsigned char length) override;
+
+      private:
 	bool StartHardware() override;
 	bool StopHardware() override;
 	void Do_Work();
 	void GetSensorDetails();
-private:
+
+      private:
 	std::shared_ptr<std::thread> m_thread;
 };
 
-#endif //WITH_LIBUSB
-#endif //WIN32
+#endif // WITH_LIBUSB
+#endif // WIN32
