@@ -1,5 +1,4 @@
 #include "stdafx.h"
-#include "../main/localtime_r.h"
 #include "../main/Logger.h"
 #include "../main/mainworker.h"
 #include "../main/Helper.h"
@@ -9,7 +8,7 @@
 #include "../main/json_helper.h"
 #include "hardwaretypes.h"
 #include "XiaomiGateway.h"
-#include <openssl/aes.h>
+#include <openssl/evp.h>
 #include <boost/asio.hpp>
 #include "XiaomiDeviceSupport.h"
 
@@ -26,7 +25,6 @@ Protocol is Zigbee and WiFi, and the gateway and
 Domoticz need to be in the same network/subnet with multicast working
 */
 
-#define round(a) (int)(a + .5)
 // Removing this vector and use unitcode to tell what kind of device each is
 // std::vector<std::string> arrAqara_Wired_ID;
 
@@ -80,6 +78,7 @@ typedef enum
 #define MODEL_SELECTOR_WIRED_WALL_SINGLE_1 "ctrl_neutral1"
 #define MODEL_SELECTOR_WIRED_WALL_SINGLE_2 "ctrl_ln1"
 #define MODEL_SELECTOR_WIRED_WALL_SINGLE_3 "ctrl_ln1.aq1"
+#define MODEL_SELECTOR_WIRED_WALL_SINGLE_4 "switch_b1lacn02"
 #define NAME_SELECTOR_WIRED_WALL_SINGLE "Xiaomi Wired Single Wall Switch"
 
 // Xiaomi Wired Dual Wall Switch | QBKG12LM (QBKG26LM)
@@ -539,12 +538,12 @@ bool XiaomiGateway::SendMessageToGateway(const std::string &controlmessage)
 {
 	std::string message = controlmessage;
 	bool result = true;
-	boost::asio::io_service io_service;
-	boost::asio::ip::udp::socket socket_(io_service, boost::asio::ip::udp::endpoint(boost::asio::ip::udp::v4(), 0));
+	boost::asio::io_context io_context;
+	boost::asio::ip::udp::socket socket_(io_context, boost::asio::ip::udp::endpoint(boost::asio::ip::udp::v4(), 0));
 	stdreplace(message, "@gatewaykey", GetGatewayKey());
 	std::shared_ptr<std::string> message1(new std::string(message));
 	boost::asio::ip::udp::endpoint remote_endpoint_;
-	remote_endpoint_ = boost::asio::ip::udp::endpoint(boost::asio::ip::address::from_string(m_GatewayIp), 9898);
+	remote_endpoint_ = boost::asio::ip::udp::endpoint(boost::asio::ip::make_address_v4(m_GatewayIp), 9898);
 	socket_.send_to(boost::asio::buffer(*message1), remote_endpoint_);
 	sleep_milliseconds(150); // TODO: reduce or remove sleep
 	std::array<char, 512> recv_buffer_;
@@ -681,7 +680,7 @@ void XiaomiGateway::InsertUpdateRGBGateway(const std::string &nodeid, const std:
 		ycmd.value = brightness;
 		ycmd.command = cmd;
 		m_mainworker.PushAndWaitRxMessage(this, (const unsigned char *)&ycmd, nullptr, -1, m_Name.c_str());
-		m_sql.safe_query("UPDATE DeviceStatus SET Name='%q', SwitchType=%d, LastLevel=%d WHERE(HardwareID == %d) AND (DeviceID == '%s') AND (Type == %d)", Name.c_str(), (STYPE_Dimmer),
+		m_sql.safe_query("UPDATE DeviceStatus SET Name='%q', SwitchType=%d, LastLevel=%d WHERE (HardwareID == %d) AND (DeviceID == '%s') AND (Type == %d)", Name.c_str(), (STYPE_Dimmer),
 				 brightness, m_HwdID, szDeviceID, pTypeColorSwitch);
 	}
 	else
@@ -788,7 +787,7 @@ void XiaomiGateway::InsertUpdateSwitch(const std::string &nodeid, const std::str
 			}
 		}
 
-		m_sql.safe_query("UPDATE DeviceStatus SET Name='%q', SwitchType=%d, CustomImage=%i WHERE(HardwareID == %d) AND (DeviceID == '%q') AND (Unit == '%d')", Name.c_str(), (switchtype),
+		m_sql.safe_query("UPDATE DeviceStatus SET Name='%q', SwitchType=%d, CustomImage=%i WHERE (HardwareID == %d) AND (DeviceID == '%q') AND (Unit == '%d')", Name.c_str(), (switchtype),
 				 customimage, m_HwdID, ID.c_str(), xcmd.unitcode);
 
 		if (switchtype == STYPE_Selector)
@@ -878,7 +877,7 @@ void XiaomiGateway::InsertUpdateSwitch(const std::string &nodeid, const std::str
 			if (battery != 255)
 			{
 				BatteryLevel = battery;
-				m_sql.safe_query("UPDATE DeviceStatus SET BatteryLevel=%d WHERE(HardwareID == %d) AND (DeviceID == '%q') AND (Unit == '%d')", BatteryLevel, m_HwdID, ID.c_str(),
+				m_sql.safe_query("UPDATE DeviceStatus SET BatteryLevel=%d WHERE (HardwareID == %d) AND (DeviceID == '%q') AND (Unit == '%d')", BatteryLevel, m_HwdID, ID.c_str(),
 						 xcmd.unitcode);
 			}
 		}
@@ -1016,15 +1015,14 @@ bool XiaomiGateway::StopHardware()
 void XiaomiGateway::Do_Work()
 {
 	Log(LOG_STATUS, "XiaomiGateway (ID=%d): Worker started...", m_HwdID);
-	boost::asio::io_service io_service;
+	boost::asio::io_context io_context;
 	// Find the local ip address that is similar to the xiaomi gateway
 	try
 	{
-		boost::asio::ip::udp::resolver resolver(io_service);
-		boost::asio::ip::udp::resolver::query query(boost::asio::ip::udp::v4(), m_GatewayIp, "");
-		auto endpoints = resolver.resolve(query);
-		boost::asio::ip::udp::endpoint ep = *endpoints;
-		boost::asio::ip::udp::socket socket(io_service);
+		boost::asio::ip::udp::resolver resolver(io_context);
+		auto endpoints = resolver.resolve(boost::asio::ip::udp::v4(), m_GatewayIp, "");
+		boost::asio::ip::udp::endpoint ep = *endpoints.begin();
+		boost::asio::ip::udp::socket socket(io_context);
 		socket.connect(ep);
 		boost::asio::ip::address addr = socket.local_endpoint().address();
 		std::string compareIp = m_GatewayIp.substr(0, (m_GatewayIp.length() - 3));
@@ -1074,11 +1072,11 @@ void XiaomiGateway::Do_Work()
 		}
 	}
 
-	XiaomiGateway::xiaomi_udp_server udp_server(io_service, m_HwdID, m_GatewayIp, m_LocalIp, m_ListenPort9898, m_OutputMessage, m_IncludeVoltage, this);
+	XiaomiGateway::xiaomi_udp_server udp_server(io_context, m_HwdID, m_GatewayIp, m_LocalIp, m_ListenPort9898, m_OutputMessage, m_IncludeVoltage, this);
 	boost::thread bt;
 	if (m_ListenPort9898)
 	{
-		bt = boost::thread([p = &io_service] { p->run(); });
+		bt = boost::thread([p = &io_context] { p->run(); });
 		SetThreadName(bt.native_handle(), "XiaomiGatewayIO");
 	}
 
@@ -1095,7 +1093,7 @@ void XiaomiGateway::Do_Work()
 			// Log(LOG_STATUS, "sec_counter %d", sec_counter);
 		}
 	}
-	io_service.stop();
+	io_context.stop();
 	if (bt.joinable())
 	{
 		bt.join();
@@ -1107,26 +1105,47 @@ void XiaomiGateway::Do_Work()
 std::string XiaomiGateway::GetGatewayKey()
 {
 #ifdef WWW_ENABLE_SSL
-	const unsigned char *key = (unsigned char *)m_GatewayPassword.c_str();
-	unsigned char iv[AES_BLOCK_SIZE] = { 0x17, 0x99, 0x6d, 0x09, 0x3d, 0x28, 0xdd, 0xb3, 0xba, 0x69, 0x5a, 0x2e, 0x6f, 0x58, 0x56, 0x2e };
-	std::string token = XiaomiGatewayTokenManager::GetInstance().GetToken(m_GatewayIp);
-	unsigned char *plaintext = (unsigned char *)token.c_str();
-	unsigned char ciphertext[128];
+	unsigned char iv[EVP_MAX_IV_LENGTH] = { 0x17, 0x99, 0x6d, 0x09, 0x3d, 0x28, 0xdd, 0xb3, 0xba, 0x69, 0x5a, 0x2e, 0x6f, 0x58, 0x56, 0x2e };
 
-	AES_KEY encryption_key;
-	AES_set_encrypt_key(key, 128, &(encryption_key));
-	AES_cbc_encrypt((unsigned char *)plaintext, ciphertext, sizeof(plaintext) * 8, &encryption_key, iv, AES_ENCRYPT);
+	unsigned char key[EVP_MAX_KEY_LENGTH];
+	memset(&key, 0, sizeof(key));
+	memcpy(&key, m_GatewayPassword.c_str(), std::max((int)m_GatewayPassword.size(), EVP_MAX_KEY_LENGTH));
 
-	char gatewaykey[128];
-	for (int i = 0; i < 16; i++)
+	unsigned char token[EVP_MAX_KEY_LENGTH];
+	memset(&token, 0, sizeof(token));
+	std::string sToken = XiaomiGatewayTokenManager::GetInstance().GetToken(m_GatewayIp);
+	memcpy(&token, sToken.c_str(), std::max((int)sToken.size(), EVP_MAX_KEY_LENGTH));
+
+	std::vector<unsigned char> encrypted;
+	encrypted.resize(32);
+
+	auto ctx = std::unique_ptr<EVP_CIPHER_CTX, decltype(&EVP_CIPHER_CTX_free)>(EVP_CIPHER_CTX_new(), EVP_CIPHER_CTX_free);
+
+	EVP_CipherInit_ex(ctx.get(), EVP_aes_128_cbc(), nullptr, key, iv, 1);
+
+	int actual_size = 0;
+	EVP_CipherUpdate(ctx.get(),
+		&encrypted[0], &actual_size,
+		reinterpret_cast<unsigned char*>(&token[0]), 16);
+
+	//int final_size;
+	//EVP_CipherFinal_ex(ctx.get(), &encrypted[actual_size], &final_size);
+	//actual_size += final_size;
+
+	encrypted.resize(actual_size);
+
+	std::stringstream sstr;
+	for (size_t index = 0; index < encrypted.size(); ++index)
 	{
-		sprintf(&gatewaykey[i * 2], "%02X", ciphertext[i]);
+		sstr << std::hex << std::setw(2) << std::setfill('0') << std::uppercase <<
+			static_cast<unsigned int>(encrypted[index]);
 	}
+
 #ifdef _DEBUG
 	Log(LOG_STATUS, "GetGatewayKey Password - %s", m_GatewayPassword.c_str());
-	Log(LOG_STATUS, "GetGatewayKey key - %s", gatewaykey);
+	Log(LOG_STATUS, "GetGatewayKey key - %s", sstr.str());
 #endif
-	return gatewaykey;
+	return sstr.str();
 #else
 	Log(LOG_ERROR, "GetGatewayKey NO SSL AVAILABLE");
 	return std::string("");
@@ -1158,9 +1177,9 @@ unsigned int XiaomiGateway::GetShortID(const std::string &nodeid)
 	return sID;
 }
 
-XiaomiGateway::xiaomi_udp_server::xiaomi_udp_server(boost::asio::io_service &io_service, int m_HwdID, const std::string &gatewayIp, const std::string &localIp, const bool listenPort9898,
+XiaomiGateway::xiaomi_udp_server::xiaomi_udp_server(boost::asio::io_context &io_context, int m_HwdID, const std::string &gatewayIp, const std::string &localIp, const bool listenPort9898,
 						    const bool outputMessage, const bool includeVoltage, XiaomiGateway *parent)
-	: socket_(io_service, boost::asio::ip::udp::v4())
+	: socket_(io_context, boost::asio::ip::udp::v4())
 {
 	m_HardwareID = m_HwdID;
 	m_XiaomiGateway = parent;
@@ -1176,8 +1195,8 @@ XiaomiGateway::xiaomi_udp_server::xiaomi_udp_server(boost::asio::io_service &io_
 			if (!m_localip.empty())
 			{
 				boost::system::error_code ec;
-				boost::asio::ip::address listen_addr = boost::asio::ip::address::from_string(m_localip, ec);
-				boost::asio::ip::address mcast_addr = boost::asio::ip::address::from_string("224.0.0.50", ec);
+				boost::asio::ip::address listen_addr = boost::asio::ip::make_address_v4(m_localip, ec);
+				boost::asio::ip::address mcast_addr = boost::asio::ip::make_address_v4("224.0.0.50", ec);
 				boost::asio::ip::udp::endpoint listen_endpoint(mcast_addr, 9898);
 
 				socket_.bind(boost::asio::ip::udp::endpoint(boost::asio::ip::udp::v4(), 9898));
@@ -1193,9 +1212,9 @@ XiaomiGateway::xiaomi_udp_server::xiaomi_udp_server(boost::asio::io_service &io_
 				socket_.bind(boost::asio::ip::udp::endpoint(boost::asio::ip::udp::v4(), 9898));
 				std::shared_ptr<std::string> message(new std::string(R"({"cmd":"whois"})"));
 				boost::asio::ip::udp::endpoint remote_endpoint;
-				remote_endpoint = boost::asio::ip::udp::endpoint(boost::asio::ip::address::from_string("224.0.0.50"), 4321);
+				remote_endpoint = boost::asio::ip::udp::endpoint(boost::asio::ip::make_address_v4("224.0.0.50"), 4321);
 				socket_.send_to(boost::asio::buffer(*message), remote_endpoint);
-				socket_.set_option(boost::asio::ip::multicast::join_group(boost::asio::ip::address::from_string("224.0.0.50")));
+				socket_.set_option(boost::asio::ip::multicast::join_group(boost::asio::ip::make_address_v4("224.0.0.50")));
 			}
 		}
 		catch (const boost::system::system_error &ex)
@@ -1340,7 +1359,8 @@ void XiaomiGateway::xiaomi_udp_server::handle_receive(const boost::system::error
 				{
 					name = NAME_GATEWAY;
 				}
-				else if (model == MODEL_SELECTOR_WIRED_WALL_SINGLE_1 || model == MODEL_SELECTOR_WIRED_WALL_SINGLE_2 || model == MODEL_SELECTOR_WIRED_WALL_SINGLE_3)
+				else if (model == MODEL_SELECTOR_WIRED_WALL_SINGLE_1 || model == MODEL_SELECTOR_WIRED_WALL_SINGLE_2 || model == MODEL_SELECTOR_WIRED_WALL_SINGLE_3 ||
+					model == MODEL_SELECTOR_WIRED_WALL_SINGLE_4)
 				{
 					type = STYPE_END; // type = STYPE_OnOff; // TODO: fix this hack
 					name = NAME_SELECTOR_WIRED_WALL_SINGLE;
@@ -1699,7 +1719,7 @@ void XiaomiGateway::xiaomi_udp_server::handle_receive(const boost::system::error
 					message.append("\"}");
 					std::shared_ptr<std::string> message1(new std::string(message));
 					boost::asio::ip::udp::endpoint remote_endpoint;
-					remote_endpoint = boost::asio::ip::udp::endpoint(boost::asio::ip::address::from_string(TrueGateway->GetGatewayIp().c_str()), 9898);
+					remote_endpoint = boost::asio::ip::udp::endpoint(boost::asio::ip::make_address_v4(TrueGateway->GetGatewayIp().c_str()), 9898);
 					socket_.send_to(boost::asio::buffer(*message1), remote_endpoint);
 				}
 			}
@@ -1725,7 +1745,7 @@ void XiaomiGateway::xiaomi_udp_server::handle_receive(const boost::system::error
 					std::string message = R"({"cmd" : "get_id_list"})";
 					std::shared_ptr<std::string> message2(new std::string(message));
 					boost::asio::ip::udp::endpoint remote_endpoint;
-					remote_endpoint = boost::asio::ip::udp::endpoint(boost::asio::ip::address::from_string(TrueGateway->GetGatewayIp().c_str()), 9898);
+					remote_endpoint = boost::asio::ip::udp::endpoint(boost::asio::ip::make_address_v4(TrueGateway->GetGatewayIp().c_str()), 9898);
 					socket_.send_to(boost::asio::buffer(*message2), remote_endpoint);
 				}
 			}
