@@ -1,4 +1,7 @@
 #include "stdafx.h"
+
+#ifdef WITH_OPENZWAVE
+
 #include "ZWaveBase.h"
 #include "ZWaveCommands.h"
 
@@ -11,7 +14,6 @@
 #include "../main/mainworker.h"
 #include "hardwaretypes.h"
 
-#include "../main/localtime_r.h"
 #include "../main/Logger.h"
 #include "../main/SQLHelper.h"
 
@@ -21,8 +23,6 @@
 
 #pragma warning(disable: 4996)
 
-#define round(a) ( int ) ( a + .5 )
-
 ZWaveBase::ZWaveBase()
 {
 	m_bNodeReplaced=true;
@@ -71,6 +71,7 @@ bool ZWaveBase::StopHardware()
 
 void ZWaveBase::Do_Work()
 {
+	Log(LOG_STATUS, "ZWave: This hardware type is Deprecated! Please try to move to MQTT Auto Discovery and ZWave JS UI");
 #ifdef WIN32
 	//prevent OpenZWave locale from taking over
 	_configthreadlocale(_ENABLE_PER_THREAD_LOCALE);
@@ -540,7 +541,7 @@ void ZWaveBase::SendDevice2Domoticz(_tZWaveDevice* pDevice)
 		tsen.CURRENT.packetlength = sizeof(tsen.CURRENT) - 1;
 		tsen.CURRENT.id1 = pDevice->nodeID;
 		tsen.CURRENT.id2 = pDevice->instanceID;
-		int amps = round(pDevice->floatValue * 10.0F);
+		int amps = ground(pDevice->floatValue * 10.0F);
 		tsen.CURRENT.ch1h = amps / 256;
 		amps -= (tsen.CURRENT.ch1h * 256);
 		tsen.CURRENT.ch1l = (BYTE)amps;
@@ -628,12 +629,12 @@ void ZWaveBase::SendDevice2Domoticz(_tZWaveDevice* pDevice)
 		tsen.WIND.id2 = pDevice->instanceID;
 
 		float winddir = 0;
-		int aw = round(winddir);
+		int aw = ground(winddir);
 		tsen.WIND.directionh = (BYTE)(aw / 256);
 		aw -= (tsen.WIND.directionh * 256);
 		tsen.WIND.directionl = (BYTE)(aw);
 
-		int sw = round(pDevice->floatValue * 10.0F);
+		int sw = ground(pDevice->floatValue * 10.0F);
 		tsen.WIND.av_speedh = (BYTE)(sw / 256);
 		sw -= (tsen.WIND.av_speedh * 256);
 		tsen.WIND.av_speedl = (BYTE)(sw);
@@ -653,7 +654,7 @@ void ZWaveBase::SendDevice2Domoticz(_tZWaveDevice* pDevice)
 				return;
 			tsen.WIND.tempsign = (pTempDevice->floatValue >= 0) ? 0 : 1;
 			tsen.WIND.chillsign = (pTempDevice->floatValue >= 0) ? 0 : 1;
-			int at10 = round(std::abs(pTempDevice->floatValue * 10.0F));
+			int at10 = ground(std::abs(pTempDevice->floatValue * 10.0F));
 			tsen.WIND.temperatureh = (BYTE)(at10 / 256);
 			tsen.WIND.chillh = (BYTE)(at10 / 256);
 			at10 -= (tsen.WIND.chillh * 256);
@@ -726,29 +727,24 @@ void ZWaveBase::SendDevice2Domoticz(_tZWaveDevice* pDevice)
 	}
 	else if (pDevice->devType == ZDTYPE_SENSOR_LOUDNESS)
 	{
-		SendSoundSensor(pDevice->nodeID, BatLevel, round(pDevice->floatValue), (!pDevice->label.empty()) ? pDevice->label.c_str() : "Loudness");
+		SendSoundSensor(pDevice->nodeID, BatLevel, ground(pDevice->floatValue), (!pDevice->label.empty()) ? pDevice->label.c_str() : "Loudness");
 	}
 	else if (pDevice->devType == ZDTYPE_SENSOR_SETPOINT)
 	{
-		_tThermostat tmeter;
-		tmeter.subtype = sTypeThermSetpoint;
+		_tSetpoint tmeter;
+		tmeter.subtype = sTypeSetPoint;
 		tmeter.id1 = ID1;
 		tmeter.id2 = ID2;
 		tmeter.id3 = ID3;
 		tmeter.id4 = ID4;
 		tmeter.dunit = 1;
 		tmeter.battery_level = BatLevel;
-		tmeter.temp = pDevice->floatValue;
+		tmeter.value = pDevice->floatValue;
 		sDecodeRXMessage(this, (const unsigned char *)&tmeter, (!pDevice->label.empty()) ? pDevice->label.c_str() : "Setpoint", BatLevel, nullptr);
 	}
 	else if (pDevice->devType == ZDTYPE_SENSOR_THERMOSTAT_CLOCK)
 	{
-		_tGeneralDevice gDevice;
-		gDevice.subtype = sTypeZWaveClock;
-		gDevice.id = ID4;
-		gDevice.intval1 = lID;
-		gDevice.intval2 = pDevice->intvalue;
-		sDecodeRXMessage(this, (const unsigned char *)&gDevice, "Thermostat Clock", BatLevel, nullptr);
+		//Clock not supported anymore
 	}
 	else if (pDevice->devType == ZDTYPE_SENSOR_THERMOSTAT_MODE)
 	{
@@ -900,10 +896,10 @@ bool ZWaveBase::WriteToHardware(const char* pdata, const unsigned char length)
 		Log(LOG_ERROR, "ZWave: Node not found! (NodeID: %d, 0x%02x)", nodeID, nodeID);
 		return false;
 	}
-	if ((packettype == pTypeThermostat) && (subtype == sTypeThermSetpoint))
+	if ((packettype == pTypeSetpoint) && (subtype == sTypeSetPoint))
 	{
 		//Set Point
-		const _tThermostat* pMeter = reinterpret_cast<const _tThermostat*>(pdata);
+		const _tSetpoint* pMeter = reinterpret_cast<const _tSetpoint*>(pdata);
 		uint8_t nodeID = pMeter->id3;
 		uint8_t instanceID = pMeter->id4;
 		int indexID = pMeter->id1;
@@ -912,33 +908,7 @@ bool ZWaveBase::WriteToHardware(const char* pdata, const unsigned char length)
 		pDevice = FindDevice(nodeID, instanceID, ZDTYPE_SENSOR_SETPOINT);
 		if (pDevice)
 		{
-			SetThermostatSetPoint(nodeID, instanceID, pDevice->commandClassID, pMeter->temp);
-			return true;
-		}
-		Log(LOG_ERROR, "ZWave: Node not found! (NodeID: %d, 0x%02x)", nodeID, nodeID);
-		return false;
-	}
-	if ((packettype == pTypeGeneral) && (subtype == sTypeZWaveClock))
-	{
-		const _tGeneralDevice* pMeter = reinterpret_cast<const _tGeneralDevice*>(pdata);
-		uint8_t ID1 = (uint8_t)((pMeter->intval1 & 0xFF000000) >> 24);
-		uint8_t ID2 = (uint8_t)((pMeter->intval1 & 0x00FF0000) >> 16);
-		uint8_t ID3 = (uint8_t)((pMeter->intval1 & 0x0000FF00) >> 8);
-		uint8_t ID4 = (uint8_t)((pMeter->intval1 & 0x000000FF));
-
-		uint8_t nodeID = ID3;
-		uint8_t instanceID = ID4;
-		int indexID = ID1;
-
-		pDevice = FindDevice(nodeID, instanceID, ZDTYPE_SENSOR_THERMOSTAT_CLOCK);
-		if (pDevice)
-		{
-			int tintval = pMeter->intval2;
-			int day = tintval / (24 * 60); tintval -= (day * 24 * 60);
-			int hour = tintval / (60); tintval -= (hour * 60);
-			int minute = tintval;
-
-			SetClock(nodeID, instanceID, pDevice->commandClassID, day, hour, minute);
+			SetThermostatSetPoint(nodeID, instanceID, pDevice->commandClassID, pMeter->value);
 			return true;
 		}
 		Log(LOG_ERROR, "ZWave: Node not found! (NodeID: %d, 0x%02x)", nodeID, nodeID);
@@ -1126,7 +1096,7 @@ bool ZWaveBase::WriteToHardware(const char* pdata, const unsigned char length)
 				if (pLed->command == Color_SetColorToWhite)
 				{
 					int Brightness = 100;
-					int wWhite = round((255.0F / 100.0F) * float(Brightness));
+					int wWhite = ground((255.0F / 100.0F) * float(Brightness));
 					int cWhite = 0;
 					sstr << "#000000"
 						<< std::setw(2) << std::uppercase << std::hex << std::setfill('0') << std::hex << wWhite
@@ -1200,4 +1170,4 @@ bool ZWaveBase::WriteToHardware(const char* pdata, const unsigned char length)
 	}
 	return true;
 }
-
+#endif
