@@ -1,4 +1,5 @@
 #pragma once
+#ifdef WITH_OPENZWAVE
 #define COMMAND_CLASS_NO_OPERATION 0x00
 
 #define COMMAND_CLASS_BASIC 0x20
@@ -94,3 +95,5 @@
 #define COMMAND_CLASS_SILENCE_ALARM 0x9D
 #define COMMAND_CLASS_SENSOR_CONFIGURATION 0x9E
 #define COMMAND_CLASS_NON_INTEROPERABLE 0xF0
+#endif // WITH_OPENZWAVE
+
