@@ -5,7 +5,6 @@
 #include "../main/Helper.h"
 #include "../main/RFXtrx.h"
 #include "hardwaretypes.h"
-#include "../main/localtime_r.h"
 
 #include "../main/mainworker.h"
 #include "../main/WebServer.h"
@@ -343,8 +342,6 @@ void CZiBlueBase::OnDisconnected()
 	Init();
 }
 
-#define round(a) (int)(a + .5)
-
 bool CZiBlueBase::WriteToHardware(const char *pdata, const unsigned char length)
 {
 	const _tGeneralSwitch *pSwitch = reinterpret_cast<const _tGeneralSwitch *>(pdata);
@@ -354,7 +351,7 @@ bool CZiBlueBase::WriteToHardware(const char *pdata, const unsigned char length)
 	std::string protocol = GetGeneralZiBlueFromInt(ziblue_switches, pSwitch->subtype);
 	if (protocol.empty())
 	{
-		Log(LOG_ERROR, "trying to send unknown switch type: %d", pSwitch->subtype);
+		Log(LOG_ERROR, "Trying to send unknown switch type: %d", pSwitch->subtype);
 		return false;
 	}
 	else if (protocol == "JAMMING")
@@ -368,7 +365,7 @@ bool CZiBlueBase::WriteToHardware(const char *pdata, const unsigned char length)
 		std::string switchcmnd = GetGeneralZiBlueFromInt(ziBlueswitchcommands, pSwitch->cmnd);
 		if (switchcmnd.empty())
 		{
-			Log(LOG_ERROR, "trying to send unknown switch command: %d", pSwitch->cmnd);
+			Log(LOG_ERROR, "Trying to send unknown switch command: %d", pSwitch->cmnd);
 			return false;
 		}
 		// check setlevel command
@@ -378,7 +375,7 @@ bool CZiBlueBase::WriteToHardware(const char *pdata, const unsigned char length)
 			float fvalue = (15.0F / 100.0F) * float(pSwitch->level);
 			if (fvalue > 15.0F)
 				fvalue = 15.0F; // 99 is fully on
-			int svalue = round(fvalue);
+			int svalue = ground(fvalue);
 			char buffer[50] = { 0 };
 			sprintf(buffer, "%d", svalue);
 			switchcmnd = buffer;
@@ -725,7 +722,7 @@ bool CZiBlueBase::ParseBinary(const uint8_t SDQ, const uint8_t *data, size_t len
 	else if (FrameType == 0)
 	{
 		// Normal RF
-		int dlen = len - 8;
+		size_t dlen = len - 8;
 		REGULAR_INCOMING_RF_TO_BINARY_USB_FRAME_HEADER *pIncomming = (REGULAR_INCOMING_RF_TO_BINARY_USB_FRAME_HEADER *)data;
 #ifdef DEBUG_ZIBLUE
 		Log(LOG_NORM, "frameType: %d, cluster: %d, dataFlag: %d (%s MHz)", pIncomming->frameType, pIncomming->cluster, pIncomming->dataFlag, (pIncomming->dataFlag == 0) ? "433" : "868");
@@ -972,14 +969,14 @@ bool CZiBlueBase::ParseBinary(const uint8_t SDQ, const uint8_t *data, size_t len
 					Log(LOG_NORM, "subtype: %d, idPHY: %04X, idChannel: %04X, qualifier: %04X, power: %d, p1: %d, p2: %d, p3: %d", pSen->subtype, pSen->idPHY, pSen->idChannel,
 					    pSen->qualifier, pSen->power, pSen->powerI1, pSen->powerI2, pSen->powerI3);
 #endif
-					SendWattMeter(pSen->idPHY ^ pSen->idChannel, 0, (pSen->qualifier & 0x01) ? 0 : 100, float(pSen->power) / 10, "Power");
+					SendWattMeter((uint8_t)(pSen->idPHY ^ pSen->idChannel), 0, (pSen->qualifier & 0x01) ? 0 : 100, float(pSen->power) / 10, "Power");
 					int energy = (pSen->energyMsb << 16) + pSen->energyLsb;
 					SendKwhMeter(pSen->idPHY ^ pSen->idChannel, 1, (pSen->qualifier & 0x01) ? 0 : 100, float(pSen->power), float(energy) / 1000, "Energy");
 					if ((pSen->qualifier & 0x02) != 0)
 					{
-						SendWattMeter(pSen->idPHY ^ pSen->idChannel, 2, (pSen->qualifier & 0x01) ? 0 : 100, float(pSen->power) / 10, "Power I1");
-						SendWattMeter(pSen->idPHY ^ pSen->idChannel, 3, (pSen->qualifier & 0x01) ? 0 : 100, float(pSen->power) / 10, "Power I2");
-						SendWattMeter(pSen->idPHY ^ pSen->idChannel, 4, (pSen->qualifier & 0x01) ? 0 : 100, float(pSen->power) / 10, "Power I3");
+						SendWattMeter((uint8_t)(pSen->idPHY ^ pSen->idChannel), 2, (pSen->qualifier & 0x01) ? 0 : 100, float(pSen->power) / 10, "Power I1");
+						SendWattMeter((uint8_t)(pSen->idPHY ^ pSen->idChannel), 3, (pSen->qualifier & 0x01) ? 0 : 100, float(pSen->power) / 10, "Power I2");
+						SendWattMeter((uint8_t)(pSen->idPHY ^ pSen->idChannel), 4, (pSen->qualifier & 0x01) ? 0 : 100, float(pSen->power) / 10, "Power I3");
 					}
 				}
 				break;
@@ -1080,12 +1077,12 @@ bool CZiBlueBase::ParseBinary(const uint8_t SDQ, const uint8_t *data, size_t len
 							 ((m_LastReceivedTime - m_LastReceivedKWhMeterTime[pSen->idLsb ^ pSen->idMsb ^ 1]) / 3600.0);
 						power2 = (total2 - m_LastReceivedKWhMeterValue[pSen->idLsb ^ pSen->idMsb ^ 2]) /
 							 ((m_LastReceivedTime - m_LastReceivedKWhMeterTime[pSen->idLsb ^ pSen->idMsb ^ 2]) / 3600.0);
-						power1 = round(power1);
-						power2 = round(power2);
+						power1 = ground(power1);
+						power2 = ground(power2);
 					}
 					SendKwhMeter(pSen->idLsb ^ pSen->idMsb, 1, (pSen->qualifier & 0x01) ? 0 : 100, power1, total1 / 1000.0, "HC");
 					SendKwhMeter(pSen->idLsb ^ pSen->idMsb, 2, (pSen->qualifier & 0x01) ? 0 : 100, power2, total2 / 1000.0, "HP");
-					SendWattMeter(pSen->idLsb ^ pSen->idMsb, 3, (pSen->qualifier & 0x01) ? 0 : 100, (float)pSen->apparentPower, "Apparent Power");
+					SendWattMeter((uint8_t)(pSen->idLsb ^ pSen->idMsb), 3, (pSen->qualifier & 0x01) ? 0 : 100, (float)pSen->apparentPower, "Apparent Power");
 					m_LastReceivedKWhMeterTime[pSen->idLsb ^ pSen->idMsb ^ 1] = m_LastReceivedTime;
 					m_LastReceivedKWhMeterValue[pSen->idLsb ^ pSen->idMsb ^ 1] = total1;
 					m_LastReceivedKWhMeterTime[pSen->idLsb ^ pSen->idMsb ^ 2] = m_LastReceivedTime;
