@@ -20,18 +20,20 @@ class CZiBlueBase : public CDomoticzHardwareBase
 		ZIBLUE_STATE_DATA_ASCII
 	};
 
-      public:
+	public:
 	CZiBlueBase();
 	~CZiBlueBase() override = default;
+	virtual std::string GetManualSwitchesJsonConfiguration() const override;
+	virtual void GetManualSwitchParameters(const std::multimap<std::string, std::string> &Parameters, _eSwitchType & SwitchTypeInOut, int &LightTypeInOut,
+					int & dTypeOut, int &dSubTypeOut,std::string &devIDOut, std::string &sUnitOut) const override;
 	bool WriteToHardware(const char *pdata, unsigned char length) override;
-
-      private:
+	private:
 	void Init();
 	void OnConnected();
 	void OnDisconnected();
 	void ParseData(const char *data, size_t len);
 	bool ParseBinary(uint8_t SDQ, const uint8_t *data, size_t len);
-	bool SendSwitchInt(int ID, int switchunit, int BatteryLevel, const std::string &switchType, const std::string &switchcmd, int level);
+	bool SendSwitchInt(int ID, int switchunit, int BatteryLevel, const std::string &switchType, const std::string &switchcmd, int level, const std::string &defaultName);
 
 	virtual bool WriteInt(const std::string &sendString) = 0;
 	virtual bool WriteInt(const uint8_t *pData, size_t length) = 0;
