@@ -1,5 +1,7 @@
 #pragma once
 
+#ifdef ENABLE_PYTHON
+
 #include "../DomoticzHardware.h"
 #include "../hardwaretypes.h"
 #include "../../notifications/NotificationBase.h"
@@ -62,8 +64,6 @@ namespace Plugins {
 
 		void Do_Work();
 
-		void LogPythonException(const std::string &);
-
 	public:
 	  CPlugin(int HwdID, const std::string &Name, const std::string &PluginKey);
 	  ~CPlugin() override;
@@ -75,7 +75,7 @@ namespace Plugins {
 	  bool StopHardware() override;
 
 	  void LogPythonException();
-	  void LogTraceback(PyTracebackObject *pTraceback);
+	  void LogPythonException(const std::string&);
 
 	  int PollInterval(int Interval = -1);
 	  PyObject*	PythonModule() { return m_PyModule; };
@@ -94,7 +94,8 @@ namespace Plugins {
 	  void ConnectionWrite(CDirectiveBase *);
 	  void ConnectionDisconnect(CDirectiveBase *);
 	  void DisconnectEvent(CEventBase *);
-	  void Callback(PyObject* pTarget, const std::string &sHandler, PyObject *pParams);
+	  void Callback(PyBorrowedRef& pTarget, const std::string &sHandler, PyObject *pParams);
+	  long PythonThreadCount();
 	  void RestoreThread();
 	  void ReleaseThread();
 	  void Stop();
@@ -119,9 +120,9 @@ namespace Plugins {
 	  PyBorrowedRef	FindUnitInDevice(const std::string &deviceKey, const int unitKey);
 
 	  std::string m_PluginKey;
-	  PyDictObject*	m_DeviceDict;
-	  PyDictObject* m_ImageDict;
-	  PyDictObject* m_SettingsDict;
+	  PyObject*	m_DeviceDict;
+	  PyObject* m_ImageDict;
+	  PyObject* m_SettingsDict;
 	  std::string m_HomeFolder;
 	  PluginDebugMask m_bDebug;
 	  bool m_bTracing;
@@ -147,16 +148,31 @@ namespace Plugins {
 	//
 	class PyBorrowedRef
 	{
-	      protected:
+	protected:
 		PyObject *m_pObject;
+		bool		TypeCheck(long);
 
-	      public:
+	public:
 		PyBorrowedRef()
-			: m_pObject(NULL){};
+			: m_pObject(NULL) {};
 		PyBorrowedRef(PyObject *pObject)
 		{
 			m_pObject = pObject;
 		};
+		std::string	Attribute(const char* name);
+		std::string	Attribute(std::string& name) { return Attribute(name.c_str()); };
+		std::string	Type();
+		bool		IsDict() { return TypeCheck(Py_TPFLAGS_DICT_SUBCLASS); };
+		bool		IsList() { return TypeCheck(Py_TPFLAGS_LIST_SUBCLASS); };
+		bool		IsLong() { return TypeCheck(Py_TPFLAGS_LONG_SUBCLASS); };
+		bool		IsTuple() { return TypeCheck(Py_TPFLAGS_TUPLE_SUBCLASS); };
+		bool		IsString() { return TypeCheck(Py_TPFLAGS_UNICODE_SUBCLASS); };
+		bool		IsBytes() { return TypeCheck(Py_TPFLAGS_BYTES_SUBCLASS); };
+		bool		IsByteArray() { return Type() == "bytearray"; };
+		bool		IsFloat() { return Type() == "float"; };
+		bool		IsBool() { return Type() == "bool"; };
+		bool		IsNone() { return m_pObject && (m_pObject == Py_None); };
+		bool		IsTrue() { return m_pObject && PyObject_IsTrue(m_pObject); };
 		operator PyObject *() const
 		{
 			return m_pObject;
@@ -165,10 +181,6 @@ namespace Plugins {
 		{
 			return (PyTypeObject *)m_pObject;
 		}
-		operator PyBytesObject *() const
-		{
-			return (PyBytesObject *)m_pObject;
-		}
 		operator bool() const
 		{
 			return (m_pObject != NULL);
@@ -235,13 +247,66 @@ namespace Plugins {
 			: PyBorrowedRef(){};
 		PyNewRef(PyObject *pObject)
 			: PyBorrowedRef(pObject){};
-		void operator=(PyObject *pObject)
+		PyNewRef(const std::vector<byte>& value)
+			: PyBorrowedRef() {
+			m_pObject = PyBytes_FromStringAndSize((const char*)value.data(), value.size());
+		};
+		PyNewRef(const byte* value, const size_t size)
+			: PyBorrowedRef() {
+			m_pObject = PyBytes_FromStringAndSize((const char*)value, size);
+		};
+		PyNewRef(const std::string& value)
+			: PyBorrowedRef() {
+			m_pObject = PyUnicode_FromString(value.c_str());
+		};
+		PyNewRef(const char* value)
+			: PyBorrowedRef() {
+			m_pObject = PyUnicode_FromString(value);
+		};
+		PyNewRef(const long value)
+			: PyBorrowedRef() {
+			m_pObject = PyLong_FromLong(value);
+		};
+		PyNewRef(const long long value)
+			: PyBorrowedRef() {
+			m_pObject = Py_BuildValue("L", value);
+		};
+		PyNewRef(const int value)
+			: PyBorrowedRef() {
+			m_pObject = Py_BuildValue("i", value);
+		};
+		PyNewRef(const unsigned int value)
+			: PyBorrowedRef() {
+			m_pObject = Py_BuildValue("I", value);
+		};
+		PyNewRef(const float value)
+			: PyBorrowedRef() {
+			m_pObject = Py_BuildValue("f", value);
+		};
+		PyNewRef(const double value)
+			: PyBorrowedRef() {
+			m_pObject = Py_BuildValue("d", value);
+		};
+		PyNewRef(const bool value)
+			: PyBorrowedRef() {
+			m_pObject = PyBool_FromLong(value);
+		};
+		void operator=(const PyNewRef& pNewRef)
 		{
 			if (m_pObject)
 			{
 				Py_XDECREF(m_pObject);
 			}
-			m_pObject = pObject;
+			m_pObject = pNewRef.m_pObject;
+			Py_XINCREF(m_pObject);
+		}
+		void operator=(PyObject* pObject)
+		{
+			if (m_pObject)
+			{
+				Py_XDECREF(m_pObject);
+			}
+			PyBorrowedRef::operator=(pObject);
 		}
 		void operator+=(PyObject *pObject)
 		{
@@ -283,12 +348,8 @@ namespace Plugins {
 	class AccessPython
 	{
 	private:
-		static	std::mutex			PythonMutex;
-		static  volatile bool		m_bHasThreadState;
-		std::unique_lock<std::mutex>* m_Lock;
-		PyThreadState* m_Python;
 		CPlugin* m_pPlugin;
-		const char* m_Text;
+		std::string m_Text;
 
 	public:
 		AccessPython(CPlugin* pPlugin, const char* sWhat);
@@ -296,3 +357,5 @@ namespace Plugins {
 	};
 
 } // namespace Plugins
+
+#endif //#ifdef ENABLE_PYTHON
