@@ -42,6 +42,8 @@
 #include <sstream>
 #include <exception>
 #include <stdexcept>
+#include <utility>
+#include <utility>
 #include "v8stdint.h"
 
 #define THROW(exceptionClass, message) throw exceptionClass(__FILE__, \
@@ -317,8 +319,7 @@ public:
    * \throw serial::PortNotOpenedException
    * \throw serial::SerialException
    */
-  size_t
-  readline (std::string &buffer, size_t size = 65536, std::string eol = "\n");
+  size_t readline(std::string &buffer, size_t size = 65536, const std::string &eol = "\n");
 
   /*! Reads in a line or until a given delimiter has been processed.
    *
@@ -332,8 +333,7 @@ public:
    * \throw serial::PortNotOpenedException
    * \throw serial::SerialException
    */
-  std::string
-  readline (size_t size = 65536, std::string eol = "\n");
+  std::string readline(size_t size = 65536, const std::string &eol = "\n");
 
   /*! Reads in multiple lines until the serial port times out.
    *
@@ -349,8 +349,7 @@ public:
    * \throw serial::PortNotOpenedException
    * \throw serial::SerialException
    */
-  std::vector<std::string>
-  readlines (size_t size = 65536, std::string eol = "\n");
+  std::vector<std::string> readlines(size_t size = 65536, const std::string &eol = "\n");
 
   /*! Write a string to the serial port.
    *
@@ -644,11 +643,11 @@ public:
   bool
   getCD ();
 
-private:
   // Disable copy constructors
-  Serial(const Serial&);
-  Serial& operator=(const Serial&);
+  Serial(const Serial &) = delete;
+  Serial &operator=(const Serial &) = delete;
 
+private:
   // Pimpl idiom, d_pointer
   class SerialImpl;
   SerialImpl *pimpl_;
@@ -668,34 +667,40 @@ private:
 
 class SerialException : public std::exception
 {
-  // Disable copy constructors
-  SerialException& operator=(const SerialException&);
   std::string e_what_;
 public:
+  // Disable copy constructors
+  SerialException &operator=(const SerialException &) = delete;
+
   explicit SerialException (const char *description) {
       std::stringstream ss;
       ss << "SerialException " << description << " failed.";
       e_what_ = ss.str();
   }
   SerialException (const SerialException& other) : e_what_(other.e_what_) {}
-  virtual ~SerialException() throw() {}
-  virtual const char* what () const throw () {
-    return e_what_.c_str();
+  ~SerialException() noexcept override = default;
+  const char *what() const noexcept override
+  {
+	  return e_what_.c_str();
   }
 };
 
 class IOException : public std::exception
 {
-  // Disable copy constructors
-  IOException& operator=(const IOException&);
   std::string file_;
   int line_;
   std::string e_what_;
   int errno_;
 public:
-  explicit IOException (std::string file, int line, int errnum)
-    : file_(file), line_(line), errno_(errnum) {
-      std::stringstream ss;
+  // Disable copy constructors
+  IOException &operator=(const IOException &) = delete;
+
+  explicit IOException(std::string file, int line, int errnum)
+	  : file_(std::move(std::move(file)))
+	  , line_(line)
+	  , errno_(errnum)
+  {
+	  std::stringstream ss;
 #if defined(_WIN32) && !defined(__MINGW32__)
       char error_str [1024];
       strerror_s(error_str, 1024, errnum);
@@ -706,38 +711,44 @@ public:
       ss << ", file " << file_ << ", line " << line_ << ".";
       e_what_ = ss.str();
   }
-  explicit IOException (std::string file, int line, const char * description)
-    : file_(file), line_(line), errno_(0) {
-      std::stringstream ss;
-      ss << "IO Exception: " << description;
-      ss << ", file " << file_ << ", line " << line_ << ".";
-      e_what_ = ss.str();
+  explicit IOException(std::string file, int line, const char *description)
+	  : file_(std::move(std::move(file)))
+	  , line_(line)
+	  , errno_(0)
+  {
+	  std::stringstream ss;
+	  ss << "IO Exception: " << description;
+	  ss << ", file " << file_ << ", line " << line_ << ".";
+	  e_what_ = ss.str();
   }
-  virtual ~IOException() throw() {}
+  ~IOException() noexcept override = default;
   IOException (const IOException& other) : line_(other.line_), e_what_(other.e_what_), errno_(other.errno_) {}
 
   int getErrorNumber () { return errno_; }
 
-  virtual const char* what () const throw () {
-    return e_what_.c_str();
+  const char *what() const noexcept override
+  {
+	  return e_what_.c_str();
   }
 };
 
 class PortNotOpenedException : public std::exception
 {
-  // Disable copy constructors
-  const PortNotOpenedException& operator=(PortNotOpenedException);
   std::string e_what_;
 public:
+  // Disable copy constructors
+  const PortNotOpenedException &operator=(PortNotOpenedException) = delete;
+
   explicit PortNotOpenedException (const char * description)  {
       std::stringstream ss;
       ss << "PortNotOpenedException " << description << " failed.";
       e_what_ = ss.str();
   }
   PortNotOpenedException (const PortNotOpenedException& other) : e_what_(other.e_what_) {}
-  virtual ~PortNotOpenedException() throw() {}
-  virtual const char* what () const throw () {
-    return e_what_.c_str();
+  ~PortNotOpenedException() noexcept override = default;
+  const char *what() const noexcept override
+  {
+	  return e_what_.c_str();
   }
 };
 
