@@ -4,7 +4,6 @@
 #include <stdarg.h>
 #include <time.h>
 #include <algorithm>
-#include "localtime_r.h"
 #include "Helper.h"
 #include "mainworker.h"
 
@@ -18,12 +17,17 @@
 #define MAX_LOG_LINE_BUFFER 100
 #define MAX_LOG_LINE_LENGTH (2048 * 3)
 
+#define MAX_ACLFLOG_LINES 100000
+
 extern bool g_bRunAsDaemon;
 extern bool g_bUseSyslog;
 
+static uint64_t m_line_counter = 1;
+
 CLogger::_tLogLineStruct::_tLogLineStruct(const _eLogLevel nlevel, const std::string &nlogmessage)
 {
 	logtime = mytime(nullptr);
+	line_counter = m_line_counter ++;
 	level = nlevel;
 	logmessage = nlogmessage;
 }
@@ -61,8 +65,8 @@ bool CLogger::SetLogFlags(const std::string &sFlags)
 		if (is_number(wflag))
 		{
 			// Flags are set provided (bitwise)
-			SetLogFlags(strtoul(wflag.c_str(), nullptr, 10));
-			return true;
+			iFlags = strtoul(wflag.c_str(), nullptr, 10);
+			break;
 		}
 		if (wflag == "all")
 			iFlags |= LOG_ALL;
@@ -75,8 +79,10 @@ bool CLogger::SetLogFlags(const std::string &sFlags)
 		else if (wflag == "debug")
 			iFlags |= LOG_DEBUG_INT;
 		else
-			return false; // invalid flag
+			continue; // invalid flag, skip but continue processing the other flags
 	}
+	if (iFlags == 0)
+		iFlags = LOG_STATUS + LOG_ERROR;
 	SetLogFlags(iFlags);
 	return true;
 }
@@ -86,7 +92,7 @@ void CLogger::SetLogFlags(const uint32_t iFlags)
 	m_log_flags = iFlags;
 }
 
-// Supported flags: all,normal,hardware,received,webserver,eventsystem,python,thread_id,sql
+// Supported flags: all,normal,hardware,received,webserver,eventsystem,python,thread_id,sql,auth
 bool CLogger::SetDebugFlags(const std::string &sFlags)
 {
 	std::vector<std::string> flags;
@@ -102,8 +108,8 @@ bool CLogger::SetDebugFlags(const std::string &sFlags)
 		if (is_number(wflag))
 		{
 			// Flags are set provided (bitwise)
-			SetDebugFlags(strtoul(wflag.c_str(), nullptr, 10));
-			return true;
+			iFlags = strtoul(wflag.c_str(), nullptr, 10);
+			break;
 		}
 		if (wflag == "all")
 			iFlags |= DEBUG_ALL;
@@ -123,10 +129,19 @@ bool CLogger::SetDebugFlags(const std::string &sFlags)
 			iFlags |= DEBUG_THREADIDS;
 		else if (wflag == "sql")
 			iFlags |= DEBUG_SQL;
+		else if (wflag == "auth")
+			iFlags |= DEBUG_AUTH;
 		else
-			return false; // invalid flag
+			continue; // invalid flag, skip but continue processing the other flags
 	}
 	SetDebugFlags(iFlags);
+	if (iFlags && !IsLogLevelEnabled(LOG_DEBUG_INT))
+	{
+		m_log_flags |= LOG_DEBUG_INT;
+		Log(LOG_STATUS, "Enabling Debug logging!");
+	}
+	if(IsDebugLevelEnabled(DEBUG_WEBSERVER))
+		SetACLFlogFlags(LOG_ACLF_ENABLED);
 	return true;
 }
 
@@ -135,6 +150,11 @@ void CLogger::SetDebugFlags(const uint32_t iFlags)
 	m_debug_flags = iFlags;
 }
 
+void CLogger::SetACLFlogFlags(const uint8_t iFlags)
+{
+	m_aclf_flags |= iFlags;
+}
+
 bool CLogger::IsLogLevelEnabled(const _eLogLevel level)
 {
 	return (m_log_flags & level);
@@ -147,6 +167,13 @@ bool CLogger::IsDebugLevelEnabled(const _eDebugLevel level)
 	return (m_debug_flags & level);
 }
 
+bool CLogger::IsACLFlogEnabled()
+{
+	if (!(m_aclf_flags & LOG_ACLF_ENABLED))
+		return false;
+	return true;
+}
+
 void CLogger::SetOutputFile(const char *OutputFile)
 {
 	std::unique_lock<std::mutex> lock(m_mutex);
@@ -172,6 +199,48 @@ void CLogger::SetOutputFile(const char *OutputFile)
 	}
 }
 
+void CLogger::SetACLFOutputFile(const char *OutputFile)
+{
+	std::string sLogFile = OutputFile;
+
+	if(sLogFile.find("syslog:") != std::string::npos)
+	{
+		Log(LOG_STATUS, "Weblogs are send to SYSLOG!");
+		SetACLFlogFlags(LOG_ACLF_SYSLOG);
+	}
+	else
+	{
+		m_aclflogfile = OutputFile;
+		SetACLFlogFlags(LOG_ACLF_FILE);
+	}
+	SetACLFlogFlags(LOG_ACLF_ENABLED);
+}
+
+void CLogger::OpenACLFOutputFile()
+{
+	std::unique_lock<std::mutex> lock(m_mutex);
+	if (m_aclfoutputfile.is_open())
+		m_aclfoutputfile.close();
+
+	if (m_aclflogfile == nullptr)
+		return;
+	if (*m_aclflogfile == 0)
+		return;
+
+	try
+	{
+#ifdef _DEBUG
+		m_aclfoutputfile.open(m_aclflogfile, std::ios::out | std::ios::trunc);
+#else
+		m_aclfoutputfile.open(m_aclflogfile, std::ios::out | std::ios::app);
+#endif
+	}
+	catch (...)
+	{
+		std::cerr << "Error opening Apache Combined LogFormat webserver log file..." << std::endl;
+	}
+}
+
 void CLogger::ForwardErrorsToNotificationSystem(const bool bDoForward)
 {
 	m_bEnableErrorsToNotificationSystem = bDoForward;
@@ -232,6 +301,8 @@ void CLogger::Log(const _eLogLevel level, const char *logline, ...)
 
 	std::string szIntLog = sstr.str();
 
+	sOnLogMessage(level, szIntLog);
+
 	{
 		// Locked region to allow multiple threads to print at the same time
 		std::unique_lock<std::mutex> lock(m_mutex);
@@ -296,6 +367,47 @@ void CLogger::Debug(const _eDebugLevel level, const std::string &sLogline)
 	Log(LOG_DEBUG_INT, sLogline);
 }
 
+void CLogger::ACLFlog(const char *logline, ...)
+{
+	if (!IsACLFlogEnabled())
+		return;
+	va_list argList;
+	char cbuffer[MAX_LOG_LINE_LENGTH];
+	va_start(argList, logline);
+	vsnprintf(cbuffer, sizeof(cbuffer), logline, argList);
+	va_end(argList);
+
+	if(IsDebugLevelEnabled(DEBUG_WEBSERVER))
+	{
+		//std::cout << std::string(cbuffer) << std::endl;
+		Debug(DEBUG_WEBSERVER,"Web ACLF: %s", cbuffer);
+	}
+
+	if(m_aclf_flags & LOG_ACLF_FILE)
+	{
+		if(m_aclf_loggedlinescnt++ >= MAX_ACLFLOG_LINES || (!m_aclfoutputfile.is_open()))
+		{
+			if(m_aclfoutputfile.is_open())
+				m_aclfoutputfile.close();
+			OpenACLFOutputFile();
+			m_aclf_loggedlinescnt = 1;
+		}
+		if (m_aclfoutputfile.is_open())
+		{
+			// output to file
+			m_aclfoutputfile << std::string(cbuffer) << std::endl;
+			m_aclfoutputfile.flush();
+		}
+	}
+
+#ifndef WIN32
+	if(g_bUseSyslog && (m_aclf_flags & LOG_ACLF_SYSLOG))
+	{
+		syslog(LOG_INFO|LOG_LOCAL1,"%s", cbuffer);
+	}
+#endif
+}
+
 bool strhasEnding(std::string const &fullString, std::string const &ending)
 {
 	return fullString.size() >= ending.size() && !fullString.compare(fullString.size() - ending.size(), ending.size(), ending);
@@ -316,7 +428,7 @@ void CLogger::LogSequenceEnd(const _eLogLevel level)
 	std::string message = m_sequencestring.str();
 	if (strhasEnding(message, "\n"))
 	{
-		message = message.substr(0, message.size() - 1);
+		message.resize(message.size() - 1);
 	}
 
 	Log(level, message);
@@ -352,9 +464,13 @@ bool CLogger::IsLogTimestampsEnabled()
 	return (m_bEnableLogTimestamps && !g_bUseSyslog);
 }
 
-bool compareLogByTime(const CLogger::_tLogLineStruct &a, CLogger::_tLogLineStruct &b)
+bool compareLogByTime(const CLogger::_tLogLineStruct &a, const CLogger::_tLogLineStruct &b)
 {
-	return a.logtime < b.logtime;
+	if (a.logtime < b.logtime)
+		return true;
+	if (a.logtime > b.logtime)
+		return false;
+	return (a.line_counter < b.line_counter);
 }
 
 std::list<CLogger::_tLogLineStruct> CLogger::GetLog(const _eLogLevel level, const time_t lastlogtime)
@@ -367,13 +483,15 @@ std::list<CLogger::_tLogLineStruct> CLogger::GetLog(const _eLogLevel level, cons
 		if (m_lastlog.find(level) == m_lastlog.end())
 			return mlist;
 
-		std::copy_if(std::begin(m_lastlog[level]), std::end(m_lastlog[level]), std::back_inserter(mlist), [lastlogtime](const _tLogLineStruct &l) { return l.logtime > lastlogtime; });
+		std::copy_if(std::begin(m_lastlog[level]), std::end(m_lastlog[level]), std::back_inserter(mlist), [lastlogtime](const _tLogLineStruct& l) { return l.logtime > lastlogtime; });
 	}
 	else
-		for (const auto &l : m_lastlog)
-			std::copy_if(l.second.begin(), l.second.end(), std::back_inserter(mlist), [lastlogtime](const _tLogLineStruct &l2) { return l2.logtime > lastlogtime; });
+		for (const auto& l : m_lastlog)
+			std::copy_if(l.second.begin(), l.second.end(), std::back_inserter(mlist), [lastlogtime](const _tLogLineStruct& l2)
+				{
+					return l2.logtime > lastlogtime;
+				});
 
-	// Sort by time
 	mlist.sort(compareLogByTime);
 	return mlist;
 }
