@@ -30,9 +30,10 @@
 #include "SQLHelper.h"
 #include "../notifications/NotificationHelper.h"
 #include "appversion.h"
-#include "localtime_r.h"
 #include "SignalHandler.h"
 
+#include "../mdns/mdns.hpp"
+
 #if defined WIN32
 	#include "../msbuild/WindowsHelper.h"
 	#include <Shlobj.h>
@@ -53,13 +54,14 @@ namespace
 		"\t-version display version number\n"
 		"\t-www port (for example -www 8080, or -www 0 to disable http)\n"
 		"\t-wwwbind address (for example -wwwbind 0.0.0.0 or -wwwbind 192.168.0.20)\n"
+		"\t-vhostname virtualhostname (for example -vhostname internal.mydomain.name or -vhostname localhost)\n"
 #ifdef WWW_ENABLE_SSL
 		"\t-sslwww port (for example -sslwww 443, or -sslwww 0 to disable https)\n"
 		"\t-sslcert file_path (for example /opt/domoticz/server_cert.pem)\n"
 		"\t-sslkey file_path (if different from certificate file)\n"
 		"\t-sslpass passphrase (to access to server private key in certificate)\n"
-		"\t-sslmethod method (supported methods: tlsv1, tlsv1_server, sslv23, sslv23_server, tlsv11, tlsv11_server, tlsv12, tlsv12_server)\n"
-		"\t-ssloptions options (for SSL options, default is 'default_workarounds,no_sslv2,no_sslv3,no_tlsv1,no_tlsv1_1,single_dh_use')\n"
+		"\t-sslmethod method (supported methods: tls [default], tls_server, tlsv1, tlsv1_server, sslv23, sslv23_server, tlsv11, tlsv11_server, tlsv12, tlsv12_server, tlsv13, tlsv13_server)\n"
+		"\t-ssloptions options (for SSL options, default is 'single_dh_use')\n"
 		"\t-ssldhparam file_path (for SSL DH parameters)\n"
 #endif
 #if defined WIN32
@@ -74,9 +76,10 @@ namespace
 		"\t-approot file_path (for example /opt/domoticz)\n"
 #endif
 		"\t-webroot additional web root, useful with proxy servers (for example domoticz)\n"
+		"\t-nocache ask browser not to cache pages\n"
+		"\t-nomdns do not enable mDNS broadcast and listening\n"
 		"\t-startupdelay seconds (default=0)\n"
 		"\t-nowwwpwd (in case you forgot the web server username/password)\n"
-		"\t-nocache (do not return appcache, use only when developing the web pages)\n"
 		"\t-wwwcompress mode (on = always compress [default], off = always decompress, static = no processing but try precompressed first)\n"
 #if defined WIN32
 		"\t-nobrowser (do not start web browser (Windows Only)\n"
@@ -85,11 +88,13 @@ namespace
 		"\t-dbase_disable_wal_mode\n"
 #if defined WIN32
 		"\t-log file_path (for example D:\\domoticz.log)\n"
+		"\t-weblog file_path (for example D:\\domoticz_access.log)\n"
 #else
 		"\t-log file_path (for example /var/log/domoticz.log)\n"
+		"\t-weblog file_path (for example /var/log/domoticz_access.log)\n"
 #endif
 		"\t-loglevel (combination of: all,normal,status,error,debug)\n"
-		"\t-debuglevel (combination of: all,normal,hardware,received,webserver,eventsystem,python,thread_id,sql)\n"
+		"\t-debuglevel (combination of: all,normal,hardware,received,webserver,eventsystem,python,thread_id,sql,auth)\n"
 		"\t-notimestamps (do not prepend timestamps to logs; useful with syslog, etc.)\n"
 		"\t-php_cgi_path (for example /usr/bin/php-cgi)\n"
 #ifndef WIN32
@@ -119,32 +124,16 @@ namespace
 	std::string logfacname = "user";
 #endif
 } // namespace
+
 std::string szStartupFolder;
 std::string szUserDataFolder;
 std::string szWWWFolder;
 std::string szWebRoot;
 std::string dbasefile;
-
-/*
-#define VCGENCMDTEMPCOMMAND "vcgencmd measure_temp"
-#define VCGENCMDARMSPEEDCOMMAND "vcgencmd measure_clock arm"
-#define VCGENCMDV3DSPEEDCOMMAND "vcgencmd measure_clock v3d"
-#define VCGENCMDCORESPEEDCOMMAND "vcgencmd measure_clock core"
-
-bool bHasInternalTemperature=false;
-std::string szInternalTemperatureCommand = "";
-
-bool bHasInternalClockSpeeds=false;
-std::string szInternalARMSpeedCommand = "";
-std::string szInternalV3DSpeedCommand = "";
-std::string szInternalCoreSpeedCommand = "";
-
-bool bHasInternalVoltage=false;
-std::string szInternalVoltageCommand = "";
-
-bool bHasInternalCurrent=false;
-std::string szInternalCurrentCommand = "";
-*/
+std::string szCertFile = "./server_cert.pem";
+bool bDoCachePages = true;
+bool bNoCleanupDev = false;
+bool bEnableMDNS = true;
 
 std::string szAppVersion="???";
 int iAppRevision=0;
@@ -160,18 +149,21 @@ CLogger _log;
 http::server::CWebServerHelper m_webservers;
 CSQLHelper m_sql;
 CNotificationHelper m_notifications;
+domoticz_mdns::mDNS m_mdns;
 
 std::string logfile;
+std::string weblogfile;
 bool g_bStopApplication = false;
 bool g_bUseSyslog = false;
 bool g_bRunAsDaemon = false;
-bool g_bDontCacheWWW = false;
 http::server::_eWebCompressionMode g_wwwCompressMode = http::server::WWW_USE_GZIP;
 bool g_bUseUpdater = true;
 http::server::server_settings webserver_settings;
 #ifdef WWW_ENABLE_SSL
 http::server::ssl_server_settings secure_webserver_settings;
 #endif
+iamserver::iam_settings iamserver_settings;
+
 bool bStartWebBrowser = true;
 bool g_bUseWatchdog = true;
 
@@ -180,8 +172,11 @@ bool g_bUseWatchdog = true;
 
 std::string daemonname = DAEMON_NAME;
 std::string pidfile = PID_FILE;
+std::string m_sz_std_out_err_log_file="";
 int pidFilehandle = 0;
 
+time_t m_LastHeartbeat = 0;
+
 #ifndef WIN32
 void daemonShutdown()
 {
@@ -288,7 +283,10 @@ void daemonize(const char *rundir, const char *pidfile)
 	/* Route I/O connections */
 
 	/* Open STDIN */
-	i = open("/dev/null", O_RDWR);
+	if (m_sz_std_out_err_log_file.empty())	
+		i = open("/dev/null", O_RDWR);
+	else
+		i = open(m_sz_std_out_err_log_file.c_str(), O_RDWR | O_APPEND | O_CREAT, S_IRUSR | S_IWUSR | S_IRGRP | S_IROTH);
 
 	/* STDOUT */
 	int dret = dup(i);
@@ -470,6 +468,27 @@ void GetAppVersion()
 	szAppDate = szTmp;
 }
 
+bool AreWeRunningInDocker()
+{
+	std::ifstream dockerenv("/.dockerenv");
+	if (dockerenv.good())
+		return true;
+
+	std::ifstream cgroup("/proc/self/cgroup");
+	std::string line;
+	while (std::getline(cgroup, line))
+	{
+		if (
+			line.find("docker") != std::string::npos
+			|| line.find("containerd") != std::string::npos
+			)
+		{
+			return true;
+		}
+	}
+	return false;
+}
+
 bool GetConfigBool(std::string szValue)
 {
 	stdlower(szValue);
@@ -555,15 +574,15 @@ bool ParseConfigFile(const std::string &szConfigFile)
 				return false;
 			}
 		}
-		else if (szFlag == "cache") {
-			g_bDontCacheWWW = !GetConfigBool(sLine);
-		}
 		else if (szFlag == "reset_password") {
 			m_mainworker.m_bIgnoreUsernamePassword = GetConfigBool(sLine);
 		}
 		else if (szFlag == "log_file") {
 			logfile = sLine;
 		}
+		else if (szFlag == "weblog_file") {
+			weblogfile = sLine;
+		}
 		else if (szFlag == "loglevel") {
 			_log.SetLogFlags(sLine);
 		}
@@ -598,6 +617,12 @@ bool ParseConfigFile(const std::string &szConfigFile)
 			webserver_settings.php_cgi_path = sLine;
 #ifdef WWW_ENABLE_SSL
 			secure_webserver_settings.php_cgi_path = sLine;
+#endif
+		}
+		else if (szFlag == "vhostname") {
+			webserver_settings.vhostname = sLine;
+#ifdef WWW_ENABLE_SSL
+			secure_webserver_settings.vhostname = sLine;
 #endif
 		}
 		else if (szFlag == "app_path") {
@@ -611,6 +636,9 @@ bool ParseConfigFile(const std::string &szConfigFile)
 		else if (szFlag == "daemon_name") {
 			daemonname = sLine;
 		}
+		else if (szFlag == "std_out_err_log_file") {	
+			m_sz_std_out_err_log_file = sLine;
+		}
 		else if (szFlag == "daemon") {
 			g_bRunAsDaemon = GetConfigBool(sLine);
 		}
@@ -632,8 +660,6 @@ void DisplayAppVersion()
 	_log.Log(LOG_STATUS, "Build Hash: %s, Date: %s", szAppHash.c_str(), szAppDate.c_str());
 }
 
-time_t m_LastHeartbeat = 0;
-
 #if defined WIN32
 int WINAPI WinMain(_In_ HINSTANCE hInstance,_In_opt_ HINSTANCE hPrevInstance,_In_ LPSTR lpCmdLine,_In_ int nShowCmd)
 #else
@@ -653,6 +679,10 @@ int main(int argc, char**argv)
 
 	CCmdLine cmdLine;
 
+	RBUF tsen;
+	memset(&tsen, 0, sizeof(RBUF));
+	int packetlength = sizeof(tsen.LIGHTNING) - 1;
+
 	// parse argc,argv 
 #if defined WIN32
 	cmdLine.SplitLine(__argc, __argv);
@@ -696,6 +726,15 @@ int main(int argc, char**argv)
 			}
 			logfile = cmdLine.GetSafeArgument("-log", 0, "domoticz.log");
 		}
+		if (cmdLine.HasSwitch("-weblog"))
+		{
+			if (cmdLine.GetArgumentCount("-weblog") != 1)
+			{
+				_log.Log(LOG_ERROR, "Please specify an output weblog file (or syslog:<facility>)");
+				return 1;
+			}
+			weblogfile = cmdLine.GetSafeArgument("-weblog", 0, "domoticz_access.log");
+		}
 		if (cmdLine.HasSwitch("-approot"))
 		{
 			if (cmdLine.GetArgumentCount("-approot") != 1)
@@ -715,6 +754,9 @@ int main(int argc, char**argv)
 	if (!logfile.empty())
 		_log.SetOutputFile(logfile.c_str());
 
+	if (!weblogfile.empty())
+		_log.SetACLFOutputFile(weblogfile.c_str());
+
 	if (szStartupFolder.empty())
 	{
 #if !defined WIN32
@@ -748,6 +790,15 @@ int main(int argc, char**argv)
 	/* call srand once for the entire app */
 	std::srand((unsigned int)std::time(nullptr));
 
+#ifdef DISABLE_UPDATER
+	g_bUseUpdater = false;
+#endif
+
+	if (AreWeRunningInDocker())
+	{
+		g_bUseUpdater = false;
+	}
+
 	GetAppVersion();
 	DisplayAppVersion();
 
@@ -821,6 +872,15 @@ int main(int argc, char**argv)
 			}
 			webserver_settings.listening_port = wwwport;
 		}
+		if (cmdLine.HasSwitch("-vhostname"))
+		{
+			if (cmdLine.GetArgumentCount("-vhostname") != 1)
+			{
+				_log.Log(LOG_ERROR, "Please specify a (FQDN) Virtual Hostname");
+				return 1;
+			}
+			webserver_settings.vhostname = cmdLine.GetSafeArgument("-vhostname", 0, "");
+		}
 		if (cmdLine.HasSwitch("-php_cgi_path"))
 		{
 			if (cmdLine.GetArgumentCount("-php_cgi_path") != 1)
@@ -866,6 +926,14 @@ int main(int argc, char**argv)
 			// Secure listening address has to be equal
 			secure_webserver_settings.listening_address = webserver_settings.listening_address;
 		}
+		if (!webserver_settings.vhostname.empty()) {
+			// vhostname has to be equal
+			secure_webserver_settings.vhostname = webserver_settings.vhostname;
+		}
+		if (!webserver_settings.php_cgi_path.empty()) {
+			// php_cgi_path has to be equal
+			secure_webserver_settings.php_cgi_path = webserver_settings.php_cgi_path;
+		}
 		if (cmdLine.HasSwitch("-sslcert"))
 		{
 			if (cmdLine.GetArgumentCount("-sslcert") != 1)
@@ -873,8 +941,9 @@ int main(int argc, char**argv)
 				_log.Log(LOG_ERROR, "Please specify a file path for your server certificate file");
 				return 1;
 			}
-			secure_webserver_settings.cert_file_path = cmdLine.GetSafeArgument("-sslcert", 0, "");
-			secure_webserver_settings.private_key_file_path = secure_webserver_settings.cert_file_path;
+			szCertFile = cmdLine.GetSafeArgument("-sslcert", 0, "");
+			secure_webserver_settings.cert_file_path = szCertFile;
+			secure_webserver_settings.private_key_file_path = szCertFile;
 		}
 		if (cmdLine.HasSwitch("-sslkey"))
 		{
@@ -921,15 +990,6 @@ int main(int argc, char**argv)
 			}
 			secure_webserver_settings.tmp_dh_file_path = cmdLine.GetSafeArgument("-ssldhparam", 0, "");
 		}
-		if (cmdLine.HasSwitch("-php_cgi_path"))
-		{
-			if (cmdLine.GetArgumentCount("-php_cgi_path") != 1)
-			{
-				_log.Log(LOG_ERROR, "Please specify the path to the php-cgi command");
-				return 1;
-			}
-			secure_webserver_settings.php_cgi_path = cmdLine.GetSafeArgument("-php_cgi_path", 0, "");
-		}
 	}
 	secure_webserver_settings.www_root = szWWWFolder;
 	m_mainworker.SetSecureWebserverSettings(secure_webserver_settings);
@@ -939,10 +999,6 @@ int main(int argc, char**argv)
 		{
 			m_mainworker.m_bIgnoreUsernamePassword = true;
 		}
-		if (cmdLine.HasSwitch("-nocache"))
-		{
-			g_bDontCacheWWW = true;
-		}
 		if (cmdLine.HasSwitch("-wwwcompress"))
 		{
 			if (cmdLine.GetArgumentCount("-wwwcompress") != 1)
@@ -1025,6 +1081,19 @@ int main(int argc, char**argv)
 		}
 	}
 
+	if (cmdLine.HasSwitch("-nocache"))
+	{
+		bDoCachePages = false;
+	}
+	if (cmdLine.HasSwitch("-nodevcleanup"))
+	{
+		bNoCleanupDev = true;
+	}
+	if (cmdLine.HasSwitch("-nomdns"))
+	{
+		bEnableMDNS = false;
+	}
+
 #if defined WIN32
 	if (!bUseConfigFile) {
 		if (cmdLine.HasSwitch("-nobrowser"))
@@ -1053,6 +1122,10 @@ int main(int argc, char**argv)
 
 #ifndef WIN32
 	if (!bUseConfigFile) {
+		if (cmdLine.HasSwitch("-std_out_err_log_file"))		
+		{
+			m_sz_std_out_err_log_file = cmdLine.GetSafeArgument("-std_out_err_log_file", 0, "");
+		}
 		if (cmdLine.HasSwitch("-daemon"))
 		{
 			g_bRunAsDaemon = true;
@@ -1108,12 +1181,14 @@ int main(int argc, char**argv)
 		/* Deamonize */
 		daemonize(szStartupFolder.c_str(), pidfile.c_str());
 	}
-	if ((g_bRunAsDaemon) || (g_bUseSyslog))
+	if ((g_bRunAsDaemon) && (g_bUseSyslog))
 	{
 		syslog(LOG_INFO, "Domoticz running...");
 	}
 #endif
 
+	m_mainworker.SetIamserverSettings(iamserver_settings);
+
 	if (!g_bRunAsDaemon)
 	{
 #ifndef WIN32
@@ -1138,15 +1213,16 @@ int main(int argc, char**argv)
 #endif
 	}
 
+	if (!m_mainworker.Start())
+	{
+		return 1;
+	}
+
 	// start Watchdog thread after daemonization
 	m_LastHeartbeat = mytime(nullptr);
 	std::thread thread_watchdog(Do_Watchdog_Work);
 	SetThreadName(thread_watchdog.native_handle(), "Watchdog");
 
-	if (!m_mainworker.Start())
-	{
-		return 1;
-	}
 	m_StartTime = time(nullptr);
 
 	/* now, lets get into an infinite loop of doing nothing. */
@@ -1192,8 +1268,9 @@ int main(int argc, char**argv)
 #ifndef WIN32
 	if (g_bRunAsDaemon)
 	{
-		syslog(LOG_INFO, "Domoticz stopped...");
 		daemonShutdown();
+		if (g_bUseSyslog)
+			syslog(LOG_INFO, "Domoticz stopped...");
 
 		// Delete PID file
 		remove(pidfile.c_str());
