@@ -9,10 +9,9 @@
 #include <deque>
 #include "WindCalculation.h"
 #include "TrendCalculator.h"
-#include "StoppableTask.h"
 #include "../tcpserver/TCPServer.h"
-#include "concurrent_queue.h"
 #include "../webserver/server_settings.hpp"
+#include "../iamserver/iam_settings.hpp"
 #ifdef ENABLE_PYTHON
 #	include "../hardware/plugins/PluginManager.h"
 #endif
@@ -43,6 +42,7 @@ public:
 	void HeartbeatCheck();
 
 	void SetWebserverSettings(const http::server::server_settings & settings);
+	void SetIamserverSettings(const iamserver::iam_settings& iam_settings);
 	std::string GetWebserverAddress();
 	std::string GetWebserverPort();
 #ifdef WWW_ENABLE_SSL
@@ -52,9 +52,16 @@ public:
 	void DecodeRXMessage(const CDomoticzHardwareBase *pHardware, const uint8_t *pRXCommand, const char *defaultName, int BatteryLevel, const char *userName);
 	void PushAndWaitRxMessage(const CDomoticzHardwareBase *pHardware, const uint8_t *pRXCommand, const char *defaultName, int BatteryLevel, const char *userName);
 
-	bool SwitchLight(const std::string &idx, const std::string &switchcmd, const std::string &level, const std::string &color, const std::string &ooc, int ExtraDelay, const std::string &User);
-	bool SwitchLight(uint64_t idx, const std::string &switchcmd, int level, _tColor color, bool ooc, int ExtraDelay, const std::string &User);
-	bool SwitchLightInt(const std::vector<std::string> &sd, std::string switchcmd, int level, _tColor color, bool IsTesting, const std::string &User);
+	enum eSwitchLightReturnCode
+	{
+		SL_ERROR = 0,			//there was a problem switching the light
+		SL_OK = 1,				//the light was switched
+		SL_OK_NO_ACTION = 2,	//the light was not switched because it was already in the requested state
+	};
+
+	eSwitchLightReturnCode SwitchLight(const std::string &idx, const std::string &switchcmd, const std::string &level, const std::string &color, const std::string &ooc, int ExtraDelay, const std::string &User);
+	eSwitchLightReturnCode SwitchLight(uint64_t idx, const std::string &switchcmd, int level, _tColor color, bool ooc, int ExtraDelay, const std::string &User);
+	eSwitchLightReturnCode SwitchLightInt(const std::vector<std::string> &sd, std::string switchcmd, int level, _tColor color, bool IsTesting, const std::string &User);
 
 	bool SwitchScene(const std::string &idx, const std::string &switchcmd, const std::string& User);
 	bool SwitchScene(uint64_t idx, std::string switchcmd, const std::string &User);
@@ -62,16 +69,16 @@ public:
 	bool DoesDeviceActiveAScene(uint64_t DevRowIdx, int Cmnd);
 
 	bool SetSetPoint(const std::string &idx, float TempValue);
-	bool SetSetPoint(const std::string &idx, float TempValue, const std::string &newMode, const std::string &until);
 	bool SetSetPointInt(const std::vector<std::string> &sd, float TempValue);
+	bool SetSetPointEvo(const std::string& idx, float TempValue, const std::string& newMode, const std::string& until);
 	bool SetThermostatState(const std::string &idx, int newState);
-	bool SetClock(const std::string &idx, const std::string &clockstr);
-	bool SetClockInt(const std::vector<std::string> &sd, const std::string &clockstr);
-	bool SetZWaveThermostatMode(const std::string &idx, int tMode);
-	bool SetZWaveThermostatFanMode(const std::string &idx, int fMode);
-	bool SetZWaveThermostatModeInt(const std::vector<std::string> &sd, int tMode);
-	bool SetZWaveThermostatFanModeInt(const std::vector<std::string> &sd, int fMode);
 
+	bool SetTextDevice(const std::string& idx, const std::string & text);
+
+#ifdef WITH_OPENZWAVE
+	bool SetZWaveThermostatMode(const std::string& idx, int tMode);
+	bool SetZWaveThermostatFanMode(const std::string& idx, int fMode);
+#endif
 	bool SwitchEvoModal(const std::string &idx, const std::string &status, const std::string &action, const std::string &ooc, const std::string &until);
 
 	bool GetSunSettings();
@@ -85,13 +92,13 @@ public:
 				   const std::string &Username, const std::string &Password, const std::string &Extra, int Mode1, int Mode2, int Mode3, int Mode4, int Mode5, int Mode6,
 				   int DataTimeout, bool bDoStart);
 
-	void UpdateDomoticzSecurityStatus(int iSecStatus);
-	void SetInternalSecStatus();
+	void UpdateDomoticzSecurityStatus(const int iSecStatus, const std::string &User);
+	void SetInternalSecStatus(const std::string& User);
 	bool GetSensorData(uint64_t idx, int &nValue, std::string &sValue);
 
 	bool UpdateDevice(const int DevIdx, const int nValue, const std::string &sValue, const std::string &userName, const int signallevel = 12, const int batterylevel = 255,
 			  const bool parseTrigger = true);
-	bool UpdateDevice(const int HardwareID, const std::string &DeviceID, const int unit, const int devType, const int subType, const int nValue, std::string sValue,
+	bool UpdateDevice(const int HardwareID, const int OrgHardwareID, const std::string &DeviceID, const int unit, const int devType, const int subType, const int nValue, std::string sValue,
 			  const std::string &userName, const int signallevel = 12, const int batterylevel = 255, const bool parseTrigger = true);
 
 	boost::signals2::signal<void(const int m_HwdID, const uint64_t DeviceRowIdx, const std::string &DeviceName, const uint8_t *pRXCommand)> sOnDeviceReceived;
@@ -129,11 +136,20 @@ public:
 	std::map<uint64_t, _tTrendCalculator> m_trend_calculator;
 
 	time_t m_LastHeartbeat = 0;
-	std::string m_szLastSwitchUser;
+
+	struct _tHourPrice
+	{
+		time_t timestamp = 0;
+		float price = 0;
+	};
+	_tHourPrice m_hourPriceElectricity;
+	_tHourPrice m_hourPriceGas;
+	_tHourPrice m_hourPriceWater;
+	void HandleHourPrice();
 private:
 	void HandleAutomaticBackups();
-	uint64_t PerformRealActionFromDomoticzClient(const uint8_t *pRXCommand, CDomoticzHardwareBase **pOriginalHardware);
 	void HandleLogNotifications();
+
 	std::map<std::string, std::pair<time_t, bool> > m_componentheartbeats;
 	std::mutex m_heartbeatmutex;
 
@@ -146,14 +162,6 @@ private:
 	int m_SecCountdown;
 	int m_SecStatus;
 
-	int m_ScheduleLastMinute;
-	int m_ScheduleLastHour;
-	//fix for hardware clock that sets time back/ford
-	time_t m_ScheduleLastMinuteTime;
-	time_t m_ScheduleLastHourTime;
-	time_t m_ScheduleLastDayTime;
-
-
 	std::mutex m_devicemutex;
 
 	std::string m_szDomoticzUpdateChecksumURL;
@@ -166,6 +174,7 @@ private:
 #ifdef WWW_ENABLE_SSL
 	http::server::ssl_server_settings m_secure_webserver_settings;
 #endif
+	iamserver::iam_settings m_iamserver_settings;
 	std::shared_ptr<std::thread> m_thread;
 	std::mutex m_mutex;
 
@@ -211,8 +220,9 @@ private:
 
 	struct _tRxMessageProcessingResult {
 		std::string DeviceName;
-		uint64_t DeviceRowIdx;
-		bool bProcessBatteryValue;
+		uint64_t DeviceRowIdx = -1;
+		bool bProcessBatteryValue = true;
+		std::string Username;
 	};
 
 	//(RFX) Message decoders
@@ -235,7 +245,7 @@ private:
 	void decode_Lighting6(const CDomoticzHardwareBase *pHardware, const tRBUF *pResponse, _tRxMessageProcessingResult & procResult);
 	void decode_Fan(const CDomoticzHardwareBase *pHardware, const tRBUF *pResponse, _tRxMessageProcessingResult & procResult);
 	void decode_Curtain(const CDomoticzHardwareBase *pHardware, const tRBUF *pResponse, _tRxMessageProcessingResult & procResult);
-	void decode_BLINDS1(const CDomoticzHardwareBase *pHardware, const tRBUF *pResponse, _tRxMessageProcessingResult & procResult);
+	void decode_BLINDS1(const CDomoticzHardwareBase* pHardware, const tRBUF* pResponse, _tRxMessageProcessingResult& procResult);
 	void decode_RFY(const CDomoticzHardwareBase *pHardware, const tRBUF *pResponse, _tRxMessageProcessingResult & procResult);
 	void decode_Security1(const CDomoticzHardwareBase *pHardware, const tRBUF *pResponse, _tRxMessageProcessingResult & procResult);
 	void decode_Security2(const CDomoticzHardwareBase *pHardware, const tRBUF *pResponse, _tRxMessageProcessingResult & procResult);
@@ -285,7 +295,11 @@ private:
 	void decode_ASyncData(const CDomoticzHardwareBase *pHardware, const tRBUF *pResponse, _tRxMessageProcessingResult & procResult);
 	void decode_Weather(const CDomoticzHardwareBase *pHardware, const tRBUF *pResponse, _tRxMessageProcessingResult & procResult);
 	void decode_Solar(const CDomoticzHardwareBase *pHardware, const tRBUF* pResponse, _tRxMessageProcessingResult& procResult);
-	void decode_Hunter(const CDomoticzHardwareBase *pHardware, const tRBUF* pResponse, _tRxMessageProcessingResult& procResult);
+	void decode_Hunter(const CDomoticzHardwareBase* pHardware, const tRBUF* pResponse, _tRxMessageProcessingResult& procResult);
+	void decode_LevelSensor(const CDomoticzHardwareBase* pHardware, const tRBUF* pResponse, _tRxMessageProcessingResult& procResult);
+	void decode_LightningSensor(const CDomoticzHardwareBase* pHardware, const tRBUF* pResponse, _tRxMessageProcessingResult& procResult);
+	void decode_DDxxxx(const CDomoticzHardwareBase* pHardware, const tRBUF* pResponse, _tRxMessageProcessingResult& procResult);
+	void decode_Honeywell(const CDomoticzHardwareBase* pHardware, const tRBUF* pResponse, _tRxMessageProcessingResult& procResult);
 };
 
 extern MainWorker m_mainworker;
