@@ -2,9 +2,9 @@
 #include "../main/Logger.h"
 #include "../main/Helper.h"
 #include "../main/SQLHelper.h"
-#include "../main/localtime_r.h"
 #include "../main/RFXtrx.h"
 #include "../main/mainworker.h"
+#include "../main/WebServer.h"
 #include "../hardware/DomoticzHardware.h"
 #include "../hardware/hardwaretypes.h"
 #include "NotificationHelper.h"
@@ -272,8 +272,7 @@ bool CNotificationHelper::CheckAndHandleNotification(const uint64_t DevRowIdx, c
 bool CNotificationHelper::CheckAndHandleNotification(const uint64_t DevRowIdx, const int HardwareID, const std::string &ID, const std::string &sName, const unsigned char unit, const unsigned char cType, const unsigned char cSubType, const int nValue, const std::string &sValue, const float fValue) {
 	float fValue2;
 	bool r1, r2, r3;
-	int nsize;
-	int nexpected = 0;
+	size_t nexpected = 0;
 
 	// Don't send notification for devices not in db
 	// Notifications for switches are handled by CheckAndHandleSwitchNotification in UpdateValue() of SQLHelper
@@ -284,7 +283,7 @@ bool CNotificationHelper::CheckAndHandleNotification(const uint64_t DevRowIdx, c
 	int meterType = 0;
 	std::vector<std::string> strarray;
 	StringSplit(sValue, ";", strarray);
-	nsize = strarray.size();
+	size_t nsize = strarray.size();
 	switch(cType) {
 		case pTypeP1Power:
 			nexpected = 5;
@@ -303,10 +302,10 @@ bool CNotificationHelper::CheckAndHandleNotification(const uint64_t DevRowIdx, c
 					break;
 			}
 			break;
-		case pTypeThermostat:
+		case pTypeSetpoint:
 			switch(cSubType) {
-				case sTypeThermSetpoint:
-					return CheckAndHandleTempHumidityNotification(DevRowIdx, sName, fValue, 0, true, false);
+				case sTypeSetpoint:
+					return CheckAndHandleNotification(DevRowIdx, sName, cType, cSubType, NTYPE_SETPOINT, fValue);
 				default:
 					break;
 			}
@@ -341,8 +340,11 @@ bool CNotificationHelper::CheckAndHandleNotification(const uint64_t DevRowIdx, c
 		case pTypeRAIN:
 			nexpected = 2;
 			if (nsize >= nexpected) {
+				float rainRate = std::stof(strarray[0].c_str());
 				fValue2 = (float)atof(strarray[1].c_str());
-				return CheckAndHandleRainNotification(DevRowIdx, sName, cType, cSubType, NTYPE_RAIN, fValue2);
+				r1 = CheckAndHandleRainNotification(DevRowIdx, sName, cType, cSubType, NTYPE_RAIN, fValue2);
+				r2 = CheckAndHandleRainNotification(DevRowIdx, sName, cType, cSubType, NTYPE_RAINRATE, rainRate);
+				return r1 && r2;
 			}
 			break;
 		case pTypeTEMP_BARO:
@@ -459,8 +461,6 @@ bool CNotificationHelper::CheckAndHandleNotification(const uint64_t DevRowIdx, c
 						return CheckAndHandleNotification(DevRowIdx, sName, cType, cSubType, NTYPE_USAGE, fValue2);
 					}
 					break;
-				case sTypeZWaveAlarm:
-					return CheckAndHandleValueNotification(DevRowIdx, sName, nValue);
 				case sTypePercentage:
 					return CheckAndHandleNotification(DevRowIdx, sName, cType, cSubType, NTYPE_PERCENTAGE, fValue);
 				case sTypeSoilMoisture:
@@ -504,7 +504,7 @@ bool CNotificationHelper::CheckAndHandleNotification(const uint64_t DevRowIdx, c
 	}
 
 	if (nexpected > 0) {
-		_log.Log(LOG_STATUS, "Warning: Expecting svalue with at least %d elements separated by semicolon, %d elements received (\"%s\"), notification not sent (Hardware: %d - %s, ID: %s, Unit: %d, Type: %02X - %s, SubType: %d - %s)", nexpected, nsize, sValue.c_str(), HardwareID, hName.c_str(), ID.c_str(), unit, cType, RFX_Type_Desc(cType, 1), cSubType, RFX_Type_SubType_Desc(cType, cSubType));
+		_log.Log(LOG_STATUS, "Warning: Expecting svalue with at least %d elements separated by semicolon, %d elements received (\"%s\"), notification not sent (Hardware: %d - %s, ID: %s, Unit: %d, Type: %02X - %s, SubType: %d - %s)", static_cast<int>(nexpected), static_cast<int>(nsize), sValue.c_str(), HardwareID, hName.c_str(), ID.c_str(), unit, cType, RFX_Type_Desc(cType, 1), cSubType, RFX_Type_SubType_Desc(cType, cSubType));
 	}
 	else {
 		_log.Log(LOG_STATUS, "Warning: Notification NOT handled (Hardware: %d - %s, ID: %s, Unit: %d, Type: %02X - %s, SubType: %d - %s), please report on GitHub!", HardwareID, hName.c_str(), ID.c_str(), unit, cType, RFX_Type_Desc(cType, 1), cSubType, RFX_Type_SubType_Desc(cType, cSubType));
@@ -916,21 +916,20 @@ bool CNotificationHelper::CheckAndHandleNotification(
 	if (notifications.empty())
 		return false;
 
-	char szTmp[600];
 
 	double intpart;
 	std::string pvalue;
 	if (modf(mvalue, &intpart) == 0)
-		sprintf(szTmp, "%.0f", mvalue);
+		pvalue = std_format("%.0f", mvalue);
 	else
-		sprintf(szTmp, "%.1f", mvalue);
-	pvalue = szTmp;
+		pvalue = std_format("%.1f", mvalue);
 
 	std::vector<std::vector<std::string> > result;
-	result = m_sql.safe_query("SELECT SwitchType FROM DeviceStatus WHERE (ID=%" PRIu64 ")", Idx);
+	result = m_sql.safe_query("SELECT SwitchType, sValue FROM DeviceStatus WHERE (ID=%" PRIu64 ")", Idx);
 	if (result.empty())
 		return false;
 	std::string szExtraData = "|Name=" + devicename + "|SwitchType=" + result[0][0] + "|";
+	std::string sValue = result[0][1];
 
 	time_t atime = mytime(nullptr);
 
@@ -971,8 +970,11 @@ bool CNotificationHelper::CheckAndHandleNotification(
 				bSendNotification = ApplyRule(splitresults[1], (mvalue == svalue), (mvalue < svalue));
 				if (bSendNotification && (!bRecoveryMessage || n.SendAlways))
 				{
-					sprintf(szTmp, "%s %s is %s %s [%s %.1f %s]", devicename.c_str(), ltype.c_str(), pvalue.c_str(), label.c_str(), splitresults[1].c_str(), svalue, label.c_str());
-					msg = szTmp;
+					msg = std_format("%s %s is %s %s [%s %.1f %s]", devicename.c_str(), ltype.c_str(), pvalue.c_str(), label.c_str(), splitresults[1].c_str(), svalue, label.c_str());
+					if ((devType == pTypeGeneral) && (subType == sTypeAlert))
+					{
+						msg += " (" + sValue + ")";
+					}
 				}
 				else if (!bSendNotification && bRecoveryMessage)
 				{
@@ -989,7 +991,17 @@ bool CNotificationHelper::CheckAndHandleNotification(
 			if (bSendNotification)
 			{
 				if (bCustomMessage && !bRecoveryMessage)
-					msg = ParseCustomMessage(custommsg, devicename, pvalue);
+				{
+					if ((devType == pTypeGeneral) && (subType == sTypeAlert))
+					{
+						std::string sAlert = pvalue + " (" + sValue + ")";
+						msg = ParseCustomMessage(custommsg, devicename, sAlert);
+					}
+					else
+					{
+						msg = ParseCustomMessage(custommsg, devicename, pvalue);
+					}
+				}
 				SendMessageEx(Idx, devicename, n.ActiveSystems, n.CustomAction, msg, msg, szExtraData, n.Priority, std::string(""), true);
 				if (!bRecoveryMessage)
 				{
@@ -1240,32 +1252,39 @@ bool CNotificationHelper::CheckAndHandleRainNotification(
 	ltime.tm_mday = tm1.tm_mday;
 	sprintf(szDateEnd, "%04d-%02d-%02d", ltime.tm_year + 1900, ltime.tm_mon + 1, ltime.tm_mday);
 
-	if (subType == sTypeRAINWU || subType == sTypeRAINByRate)
+	if (ntype == NTYPE_RAIN)
 	{
-		//value is already total rain
-		double total_real = mvalue;
-		total_real *= AddjMulti;
-		CheckAndHandleNotification(Idx, devicename, devType, subType, NTYPE_RAIN, (float)total_real);
-	}
-	else
-	{
-		result = m_sql.safe_query("SELECT MIN(Total) FROM Rain WHERE (DeviceRowID=%" PRIu64 " AND Date>='%q')",
-			Idx, szDateEnd);
-		if (!result.empty())
+		if (subType == sTypeRAINWU || subType == sTypeRAINByRate)
 		{
-			std::vector<std::string> sd = result[0];
-
-			float total_min = static_cast<float>(atof(sd[0].c_str()));
-			float total_max = mvalue;
-			double total_real = total_max - total_min;
+			//value is already total rain
+			double total_real = mvalue;
 			total_real *= AddjMulti;
 			CheckAndHandleNotification(Idx, devicename, devType, subType, NTYPE_RAIN, (float)total_real);
 		}
+		else
+		{
+			result = m_sql.safe_query("SELECT MIN(Total) FROM Rain WHERE (DeviceRowID=%" PRIu64 " AND Date>='%q')",
+				Idx, szDateEnd);
+			if (!result.empty())
+			{
+				std::vector<std::string> sd = result[0];
+
+				float total_min = static_cast<float>(atof(sd[0].c_str()));
+				float total_max = mvalue;
+				double total_real = total_max - total_min;
+				total_real *= AddjMulti;
+				CheckAndHandleNotification(Idx, devicename, devType, subType, NTYPE_RAIN, (float)total_real);
+			}
+		}
+	}
+	else
+	{
+		//Rain Rate
+		CheckAndHandleNotification(Idx, devicename, devType, subType, NTYPE_RAINRATE, mvalue);
 	}
 	return false;
 }
 
-
 void CNotificationHelper::CheckAndHandleLastUpdateNotification()
 {
 	if (m_notifications.empty())
@@ -1472,6 +1491,7 @@ bool CNotificationHelper::CustomRecoveryMessage(const uint64_t ID, std::string &
 
 bool CNotificationHelper::AddNotification(
 	const std::string &DevIdx,
+	const bool Active,
 	const std::string &Param,
 	const std::string& CustomMessage,
 	const std::string& CustomAction,
@@ -1489,8 +1509,8 @@ bool CNotificationHelper::AddNotification(
 		return false;//already there!
 
 	int iSendAlways = (SendAlways == true) ? 1 : 0;
-	m_sql.safe_query("INSERT INTO Notifications (DeviceRowID, Params, CustomMessage, CustomAction, ActiveSystems, Priority, SendAlways) VALUES ('%q','%q','%q','%q','%q',%d,%d)",
-		DevIdx.c_str(), Param.c_str(), CustomMessage.c_str(), CustomAction.c_str(), ActiveSystems.c_str(), Priority, iSendAlways);
+	m_sql.safe_query("INSERT INTO Notifications (DeviceRowID, Active, Params, CustomMessage, CustomAction, ActiveSystems, Priority, SendAlways) VALUES ('%q',%d,'%q','%q','%q','%q',%d,%d)",
+		DevIdx.c_str(), (Active) ? 1 : 0, Param.c_str(), CustomMessage.c_str(), CustomAction.c_str(), ActiveSystems.c_str(), Priority, iSendAlways);
 	ReloadNotifications();
 	return true;
 }
@@ -1511,22 +1531,21 @@ bool CNotificationHelper::RemoveNotification(const std::string &ID)
 	return true;
 }
 
-std::vector<_tNotification> CNotificationHelper::GetNotifications(const std::string &DevIdx)
-{
-	std::stringstream s_str(DevIdx);
-	uint64_t idxll;
-	s_str >> idxll;
-	return GetNotifications(idxll);
-}
-
-std::vector<_tNotification> CNotificationHelper::GetNotifications(const uint64_t DevIdx)
+std::vector<_tNotification> CNotificationHelper::GetNotifications(const uint64_t DevIdx, const bool bActiveOnly)
 {
 	std::lock_guard<std::mutex> l(m_mutex);
 	std::vector<_tNotification> ret;
 	auto itt = m_notifications.find(DevIdx);
 	if (itt != m_notifications.end())
 	{
-		ret = itt->second;
+		if (!bActiveOnly)
+			return itt->second;
+		std::vector<_tNotification> tarray = itt->second;
+		for (const auto& itt : tarray)
+		{
+			if (itt.Active)
+				ret.push_back(itt);
+		}
 	}
 	return ret;
 }
@@ -1555,7 +1574,7 @@ void CNotificationHelper::ReloadNotifications()
 	m_sql.GetPreferencesVar("NotificationSensorInterval", m_NotificationSensorInterval);
 	m_sql.GetPreferencesVar("NotificationSwitchInterval", m_NotificationSwitchInterval);
 
-	result = m_sql.safe_query("SELECT ID, DeviceRowID, Params, CustomMessage, CustomAction, ActiveSystems, Priority, SendAlways, LastSend FROM Notifications ORDER BY DeviceRowID");
+	result = m_sql.safe_query("SELECT ID, DeviceRowID, Active, Params, CustomMessage, CustomAction, ActiveSystems, Priority, SendAlways, LastSend FROM Notifications ORDER BY DeviceRowID");
 	if (result.empty())
 		return;
 
@@ -1583,14 +1602,15 @@ void CNotificationHelper::ReloadNotifications()
 		sstr << sd[1];
 		sstr >> Idx;
 
-		notification.Params = sd[2];
-		notification.CustomMessage = sd[3];
-		notification.CustomAction = CURLEncode::URLDecode(sd[4]);
-		notification.ActiveSystems = sd[5];
-		notification.Priority = atoi(sd[6].c_str());
-		notification.SendAlways = (atoi(sd[7].c_str())!=0);
+		notification.Active = atoi(sd[2].c_str()) != 0;
+		notification.Params = sd[3];
+		notification.CustomMessage = sd[4];
+		notification.CustomAction = CURLEncode::URLDecode(sd[5]);
+		notification.ActiveSystems = sd[6];
+		notification.Priority = atoi(sd[7].c_str());
+		notification.SendAlways = (atoi(sd[8].c_str())!=0);
 
-		std::string stime = sd[8];
+		std::string stime = sd[9];
 		if (stime == "0")
 		{
 			notification.LastSend = 0;
@@ -1624,3 +1644,207 @@ void CNotificationHelper::ReloadNotifications()
 		m_notifications[Idx].push_back(notification);
 	}
 }
+
+//Webserver helpers
+namespace http {
+	namespace server {
+		void CWebServer::Cmd_GetNotifications(WebEmSession& session, const request& req, Json::Value& root)
+		{
+			root["status"] = "OK";
+			root["title"] = "getnotifications";
+
+			int ii = 0;
+
+			// Add known notification systems
+			for (const auto& notifier : m_notifications.m_notifiers)
+			{
+				root["notifiers"][ii]["name"] = notifier.first;
+				root["notifiers"][ii]["description"] = notifier.first;
+				ii++;
+			}
+
+			uint64_t idx = 0;
+			if (!request::findValue(&req, "idx").empty())
+			{
+				idx = std::stoull(request::findValue(&req, "idx"));
+			}
+
+			std::vector<_tNotification> notifications = m_notifications.GetNotifications(idx, false);
+			if (!notifications.empty())
+			{
+				ii = 0;
+				for (const auto& n : notifications)
+				{
+					root["result"][ii]["idx"] = Json::Value::UInt64(n.ID);
+					root["result"][ii]["Active"] = n.Active;
+					std::string sParams = n.Params;
+					if (sParams.empty())
+					{
+						sParams = "S";
+					}
+					root["result"][ii]["Params"] = sParams;
+					root["result"][ii]["Priority"] = n.Priority;
+					root["result"][ii]["SendAlways"] = n.SendAlways;
+					root["result"][ii]["CustomMessage"] = n.CustomMessage;
+					root["result"][ii]["CustomAction"] = CURLEncode::URLEncode(n.CustomAction);
+					root["result"][ii]["ActiveSystems"] = n.ActiveSystems;
+					ii++;
+				}
+			}
+		}
+		void CWebServer::Cmd_AddNotification(WebEmSession& session, const request& req, Json::Value& root)
+		{
+			if (session.rights < 2)
+			{
+				session.reply_status = reply::forbidden;
+				return; // Only admin user allowed
+			}
+
+			std::string idx = request::findValue(&req, "idx");
+			if (idx.empty())
+				return;
+
+			std::string sactive = request::findValue(&req, "tactive");
+			std::string stype = request::findValue(&req, "ttype");
+			std::string swhen = request::findValue(&req, "twhen");
+			std::string svalue = request::findValue(&req, "tvalue");
+			std::string scustommessage = request::findValue(&req, "tmsg");
+			std::string scustomaction = CURLEncode::URLDecode(request::findValue(&req, "taction"));
+			std::string sactivesystems = request::findValue(&req, "tsystems");
+			std::string spriority = request::findValue(&req, "tpriority");
+			std::string ssendalways = request::findValue(&req, "tsendalways");
+			std::string srecovery = (request::findValue(&req, "trecovery") == "true") ? "1" : "0";
+
+			if (sactive.empty() || stype.empty() || swhen.empty() || svalue.empty() || spriority.empty() || ssendalways.empty() || srecovery.empty())
+				return;
+
+			std::string Param;
+
+			_eNotificationTypes ntype = (_eNotificationTypes)atoi(stype.c_str());
+			std::string ttype = Notification_Type_Desc(ntype, 1);
+			if ((ntype == NTYPE_SWITCH_ON) || (ntype == NTYPE_SWITCH_OFF) || (ntype == NTYPE_DEWPOINT))
+			{
+				if ((ntype == NTYPE_SWITCH_ON) && (swhen == "2"))
+				{ // '='
+					unsigned char twhen = '=';
+					Param = std_format("%s;%c;%s", ttype.c_str(), twhen, svalue.c_str());
+				}
+				else
+					Param = ttype;
+			}
+			else
+			{
+				std::string twhen;
+				if (swhen == "0")
+					twhen = ">";
+				else if (swhen == "1")
+					twhen = ">=";
+				else if (swhen == "2")
+					twhen = "=";
+				else if (swhen == "3")
+					twhen = "!=";
+				else if (swhen == "4")
+					twhen = "<=";
+				else
+					twhen = "<";
+				Param = std_format("%s;%s;%s;%s", ttype.c_str(), twhen.c_str(), svalue.c_str(), srecovery.c_str());
+			}
+			int priority = atoi(spriority.c_str());
+			bool bOK = m_notifications.AddNotification(idx, (sactive == "true") ? true : false, Param, scustommessage, scustomaction, sactivesystems, priority, (ssendalways == "true") ? true : false);
+			if (bOK)
+			{
+				root["status"] = "OK";
+				root["title"] = "AddNotification";
+			}
+		}
+		void CWebServer::Cmd_UpdateNotification(WebEmSession& session, const request& req, Json::Value& root)
+		{
+			if (session.rights < 2)
+			{
+				session.reply_status = reply::forbidden;
+				return; // Only admin user allowed
+			}
+
+			std::string idx = request::findValue(&req, "idx");
+			std::string devidx = request::findValue(&req, "devidx");
+			if ((idx.empty()) || (devidx.empty()))
+				return;
+
+			std::string sactive = request::findValue(&req, "tactive");
+			std::string stype = request::findValue(&req, "ttype");
+			std::string swhen = request::findValue(&req, "twhen");
+			std::string svalue = request::findValue(&req, "tvalue");
+			std::string scustommessage = request::findValue(&req, "tmsg");
+			std::string scustomaction = CURLEncode::URLDecode(request::findValue(&req, "taction"));
+			std::string sactivesystems = request::findValue(&req, "tsystems");
+			std::string spriority = request::findValue(&req, "tpriority");
+			std::string ssendalways = request::findValue(&req, "tsendalways");
+			std::string srecovery = (request::findValue(&req, "trecovery") == "true") ? "1" : "0";
+
+			if (stype.empty() || sactive.empty() || swhen.empty() || svalue.empty() || spriority.empty() || ssendalways.empty() || srecovery.empty())
+				return;
+			root["status"] = "OK";
+			root["title"] = "UpdateNotification";
+
+			std::string recoverymsg;
+			if ((srecovery == "1") && (m_notifications.CustomRecoveryMessage(strtoull(idx.c_str(), nullptr, 0), recoverymsg, true)))
+			{
+				scustommessage.append(";;");
+				scustommessage.append(recoverymsg);
+			}
+			// delete old record
+			m_notifications.RemoveNotification(idx);
+
+			std::string Param;
+
+			_eNotificationTypes ntype = (_eNotificationTypes)atoi(stype.c_str());
+			std::string ttype = Notification_Type_Desc(ntype, 1);
+			if ((ntype == NTYPE_SWITCH_ON) || (ntype == NTYPE_SWITCH_OFF) || (ntype == NTYPE_DEWPOINT))
+			{
+				if ((ntype == NTYPE_SWITCH_ON) && (swhen == "2"))
+				{ // '='
+					unsigned char twhen = '=';
+					Param = std_format("%s;%c;%s", ttype.c_str(), twhen, svalue.c_str());
+				}
+				else
+					Param = ttype;
+			}
+			else
+			{
+				std::string twhen;
+				if (swhen == "0")
+					twhen = ">";
+				else if (swhen == "1")
+					twhen = ">=";
+				else if (swhen == "2")
+					twhen = "=";
+				else if (swhen == "3")
+					twhen = "!=";
+				else if (swhen == "4")
+					twhen = "<=";
+				else
+					twhen = "<";
+				Param = std_format("%s;%s;%s;%s", ttype.c_str(), twhen.c_str(), svalue.c_str(), srecovery.c_str());
+			}
+			int priority = atoi(spriority.c_str());
+			m_notifications.AddNotification(devidx, (sactive == "true") ? true : false, Param, scustommessage, scustomaction, sactivesystems, priority, (ssendalways == "true") ? true : false);
+		}
+		void CWebServer::Cmd_DeleteNotification(WebEmSession& session, const request& req, Json::Value& root)
+		{
+			if (session.rights < 2)
+			{
+				session.reply_status = reply::forbidden;
+				return; // Only admin user allowed
+			}
+
+			std::string idx = request::findValue(&req, "idx");
+			if (idx.empty())
+				return;
+
+			root["status"] = "OK";
+			root["title"] = "DeleteNotification";
+
+			m_notifications.RemoveNotification(idx);
+		}
+	} // namespace server
+} // namespace http
