@@ -4,19 +4,13 @@
 class CNotificationKodi : public CNotificationBase {
 public:
 	CNotificationKodi();
-	~CNotificationKodi();
-	virtual bool IsConfigured();
+	~CNotificationKodi() override = default;
+	bool IsConfigured() override;
 	std::string	 GetIconFile(const std::string &ExtraData);
 protected:
-	virtual bool SendMessageImplementation(
-		const uint64_t Idx,
-		const std::string &Name,
-		const std::string &Subject,
-		const std::string &Text,
-		const std::string &ExtraData,
-		const int Priority,
-		const std::string &Sound,
-		const bool bFromNotification);
+  bool SendMessageImplementation(uint64_t Idx, const std::string &Name, const std::string &Subject, const std::string &Text, const std::string &ExtraData, int Priority, const std::string &Sound,
+				 bool bFromNotification) override;
+
 private:
 	std::string _IPAddress;
 	int			_Port;
