@@ -7,7 +7,6 @@
 #include "../main/RFXtrx.h"
 #include "../main/SQLHelper.h"
 #include "../webserver/Base64.h"
-#include "../main/localtime_r.h"
 #include "../main/WebServer.h"
 #include "../webserver/cWebem.h"
 #include "../main/mainworker.h"
@@ -112,22 +111,17 @@ void CHttpPush::DoHttpPush(const uint64_t DeviceRowIdx)
 
 		unsigned long tzoffset = get_tzoffset();
 
-#ifdef WIN32
-		unsigned __int64 localTime = lastUpdate;
-		unsigned __int64 localTimeUtc = lastUpdate - tzoffset;
-#else
-		unsigned long long int localTime = lastUpdate;
-		unsigned long long int localTimeUtc = lastUpdate - tzoffset;
-#endif
+		uint64_t localTime = lastUpdate;
+		uint64_t localTimeUtc = lastUpdate - tzoffset;
 
 		char szLocalTime[21];
-		sprintf(szLocalTime, "%llu", localTime);
+		sprintf(szLocalTime, "%" PRIu64, localTime);
 		char szLocalTimeUtc[21];
-		sprintf(szLocalTimeUtc, "%llu", localTimeUtc);
+		sprintf(szLocalTimeUtc, "%" PRIu64, localTimeUtc);
 		char szLocalTimeMs[21];
-		sprintf(szLocalTimeMs, "%llu", localTime * 1000);
+		sprintf(szLocalTimeMs, "%" PRIu64, localTime * 1000);
 		char szLocalTimeUtcMs[21];
-		sprintf(szLocalTimeUtcMs, "%llu", localTimeUtc * 1000);
+		sprintf(szLocalTimeUtcMs, "%" PRIu64, localTimeUtc * 1000);
 
 		std::string llastUpdate = get_lastUpdate(localTimeUtc);
 
@@ -163,12 +157,12 @@ void CHttpPush::DoHttpPush(const uint64_t DeviceRowIdx)
 			if (int(strarray.size()) >= delpos && delpos > 0)
 			{
 				std::string rawsendValue = strarray[delpos - 1];
-				sendValue = ProcessSendValue(DeviceRowIdx, rawsendValue, delpos, nValue, false, dType, dSubType, metertype);
+				sendValue = ProcessSendValue(DeviceRowIdx, rawsendValue, delpos, nValue, sValue, false, dType, dSubType, metertype);
 			}
 		}
 		else
 		{
-			sendValue = ProcessSendValue(DeviceRowIdx, sendValue, delpos, nValue, false, dType, dSubType, metertype);
+			sendValue = ProcessSendValue(DeviceRowIdx, sendValue, delpos, nValue, sValue, false, dType, dSubType, metertype);
 		}
 		if (sendValue.empty())
 			continue;
