@@ -2,14 +2,13 @@
 #include "WebsocketPush.h"
 #include "../webserver/WebsocketHandler.h"
 #include "../main/mainworker.h"
+#include "../main/Logger.h"
 
 extern boost::signals2::signal<void(const std::string &Subject, const std::string &Text, const std::string &ExtraData, const int Priority, const std::string & Sound, const bool bFromNotification)> sOnNotificationReceived;
 
 CWebSocketPush::CWebSocketPush(http::server::CWebsocketHandler *sock)
 {
 	m_PushType = PushType::PUSHTYPE_WEBSOCKET;
-	listenRoomplan = false;
-	listenDeviceTable = false;
 	m_sock = sock;
 	isStarted = false;
 }
@@ -23,6 +22,9 @@ void CWebSocketPush::Start()
 	m_sDeviceUpdate = m_mainworker.sOnDeviceUpdate.connect([this](auto id, auto idx) { OnDeviceUpdate(id, idx); });
 	m_sNotification = sOnNotificationReceived.connect([this](auto &&s, auto &&t, auto &&e, auto p, auto &&sound, auto n) { OnNotificationReceived(s, t, e, p, sound, n); });
 	m_sSceneChanged = m_mainworker.sOnSwitchScene.connect([this](auto idx, auto &&name) { OnSceneChange(idx, name); });
+
+	_log.sOnLogMessage.connect(this, &CWebSocketPush::OnLogMessage, &m_sLogMessage);
+
 	isStarted = true;
 }
 
@@ -31,6 +33,8 @@ void CWebSocketPush::Stop()
 	if (!isStarted) 
 		return;
 
+	isStarted = false;
+
 	std::unique_lock<std::mutex> lock(handlerMutex);
 
 	if (m_sConnection.connected())
@@ -45,72 +49,10 @@ void CWebSocketPush::Stop()
 	if (m_sSceneChanged.connected())
 		m_sSceneChanged.disconnect();
 
-	isStarted = false;
-	ClearListenTable();
+	m_sLogMessage.disconnect();
 }
 
-void CWebSocketPush::ListenTo(const unsigned long long DeviceRowIdx)
-{
-	std::unique_lock<std::mutex> lock(listenMutex);
-	bool bExists = std::find(listenIdxs.begin(), listenIdxs.end(), DeviceRowIdx) != listenIdxs.end();
-	if (!bExists) {
-		listenIdxs.push_back(DeviceRowIdx);
-	}
-}
-
-void CWebSocketPush::UnlistenTo(const unsigned long long DeviceRowIdx)
-{
-	std::unique_lock<std::mutex> lock(listenMutex);
-	listenIdxs.erase(std::remove(listenIdxs.begin(), listenIdxs.end(), DeviceRowIdx), listenIdxs.end());
-}
-
-void CWebSocketPush::ClearListenTable()
-{
-	std::unique_lock<std::mutex> lock(listenMutex);
-	listenIdxs.clear();
-}
-
-void CWebSocketPush::ListenToRoomplan()
-{
-	listenRoomplan = true;
-}
-
-void CWebSocketPush::UnlistenToRoomplan()
-{
-	listenRoomplan = false;
-}
-
-void CWebSocketPush::ListenToDeviceTable()
-{
-	listenDeviceTable = true;
-}
-
-void CWebSocketPush::UnlistenToDeviceTable()
-{
-	listenDeviceTable = false;
-}
-
-void CWebSocketPush::onRoomplanChanged()
-{
-	if (listenRoomplan) {
-		// send notification to web socket
-	}
-}
-
-void CWebSocketPush::onDeviceTableChanged()
-{
-	if (listenDeviceTable) {
-		// send notification to web socket
-	}
-}
-
-bool CWebSocketPush::WeListenTo(const unsigned long long DeviceRowIdx)
-{
-	std::unique_lock<std::mutex> lock(listenMutex);
-	return std::find(listenIdxs.begin(), listenIdxs.end(), DeviceRowIdx) != listenIdxs.end();
-}
-
-void CWebSocketPush::OnDeviceReceived(const int m_HwdID, const unsigned long long DeviceRowIdx, const std::string &DeviceName, const unsigned char *pRXCommand)
+void CWebSocketPush::OnDeviceReceived(const int m_HwdID, const uint64_t DeviceRowIdx, const std::string &DeviceName, const unsigned char *pRXCommand)
 {
 	std::unique_lock<std::mutex> lock(handlerMutex);
 	if (!isStarted) {
@@ -118,12 +60,9 @@ void CWebSocketPush::OnDeviceReceived(const int m_HwdID, const unsigned long lon
 	}
 
 	m_sock->OnDeviceChanged(DeviceRowIdx);
-	if (WeListenTo(DeviceRowIdx)) {
-		// push notification to web socket
-	}
 }
 
-void CWebSocketPush::OnDeviceUpdate(const int m_HwdID, const unsigned long long DeviceRowIdx)
+void CWebSocketPush::OnDeviceUpdate(const int m_HwdID, const uint64_t DeviceRowIdx)
 {
 	std::unique_lock<std::mutex> lock(handlerMutex);
 	if (!isStarted) {
@@ -131,12 +70,9 @@ void CWebSocketPush::OnDeviceUpdate(const int m_HwdID, const unsigned long long
 	}
 
 	m_sock->OnDeviceChanged(DeviceRowIdx);
-	if (WeListenTo(DeviceRowIdx)) {
-		// push notification to web socket
-	}
 }
 
-void CWebSocketPush::OnSceneChange(const unsigned long long SceneRowIdx, const std::string& SceneName)
+void CWebSocketPush::OnSceneChange(const uint64_t SceneRowIdx, const std::string& SceneName)
 {
 	std::unique_lock<std::mutex> lock(handlerMutex);
 	if (!isStarted) {
@@ -155,3 +91,12 @@ void CWebSocketPush::OnNotificationReceived(const std::string & Subject, const s
 	// push message to websocket
 	m_sock->SendNotification(Subject, Text, ExtraData, Priority, Sound, bFromNotification);
 }
+
+void CWebSocketPush::OnLogMessage(const _eLogLevel level, const std::string& sLogline)
+{
+	//std::unique_lock<std::mutex> lock(logMutex);
+	if (!isStarted) {
+		return;
+	}
+	m_sock->SendLogMessage(static_cast<int>(level), sLogline);
+}
