@@ -1,7 +1,7 @@
 /* 
    base64.cpp and base64.h
 
-   Copyright (C) 2004-2008 Ren Nyffenegger
+   Copyright (C) 2004-2008 René Nyffenegger
 
    This source code is provided 'as-is', without any express or implied
    warranty. In no event will the author be held liable for any damages
@@ -21,15 +21,16 @@
 
    3. This notice may not be removed or altered from any source distribution.
 
-   Ren Nyffenegger rene.nyffenegger@adp-gmbh.ch
+   René Nyffenegger rene.nyffenegger@adp-gmbh.ch
    Extended by GizMoCuz
+   Extended by KidDigital
 
    Usages:
 	   #include "base64.h"
 	   #include <iostream>
 
 	   int main() {
-	   const std::string s = "ADP GmbH\nAnalyse Design & Programmierung\nGesellschaft mit beschrnkter Haftung" ;
+	   const std::string s = "ADP GmbH\nAnalyse Design & Programmierung\nGesellschaft mit beschränkter Haftung" ;
 
 	   std::string encoded = base64_encode(s);
 	   std::string decoded = base64_decode(encoded);
@@ -50,12 +51,20 @@ static const std::string base64_chars =
              "abcdefghijklmnopqrstuvwxyz"
              "0123456789+/";
 
+static const std::string base64url_chars = 
+             "ABCDEFGHIJKLMNOPQRSTUVWXYZ"
+             "abcdefghijklmnopqrstuvwxyz"
+             "0123456789-_";
 
 static inline bool is_base64(unsigned char c) {
   return (isalnum(c) || (c == '+') || (c == '/'));
 }
 
-std::string base64_encode(unsigned char const* bytes_to_encode, unsigned int in_len) {
+static inline bool is_base64url(unsigned char c) {
+  return (isalnum(c) || (c == '-') || (c == '_'));
+}
+
+std::string base64_encode_buf(unsigned char const* bytes_to_encode, unsigned int in_len) {
   std::string ret;
   int i = 0;
   unsigned char char_array_3[3];
@@ -99,7 +108,50 @@ std::string base64_encode(unsigned char const* bytes_to_encode, unsigned int in_
 }
 
 std::string base64_encode(std::string const& s) {
-	return base64_encode((unsigned char const*)s.c_str(), (unsigned int)s.size());
+	return base64_encode_buf((unsigned char const*)s.c_str(), (unsigned int)s.size());
+}
+
+std::string base64url_encode_buf(unsigned char const* bytes_to_encode, unsigned int in_len) {
+  std::string ret;
+  int i = 0;
+  unsigned char char_array_3[3];
+  unsigned char char_array_4[4];
+
+  while (in_len--) {
+    char_array_3[i++] = *(bytes_to_encode++);
+    if (i == 3) {
+      char_array_4[0] = (char_array_3[0] & 0xfc) >> 2;
+      char_array_4[1] = ((char_array_3[0] & 0x03) << 4) + ((char_array_3[1] & 0xf0) >> 4);
+      char_array_4[2] = ((char_array_3[1] & 0x0f) << 2) + ((char_array_3[2] & 0xc0) >> 6);
+      char_array_4[3] = char_array_3[2] & 0x3f;
+
+      for(i = 0; (i <4) ; i++)
+        ret += base64url_chars[char_array_4[i]];
+      i = 0;
+    }
+  }
+
+  if (i)
+  {
+	  int j = 0;
+	  for (j = i; j < 3; j++)
+		char_array_3[j] = '\0';
+
+    char_array_4[0] = (char_array_3[0] & 0xfc) >> 2;
+    char_array_4[1] = ((char_array_3[0] & 0x03) << 4) + ((char_array_3[1] & 0xf0) >> 4);
+    char_array_4[2] = ((char_array_3[1] & 0x0f) << 2) + ((char_array_3[2] & 0xc0) >> 6);
+    char_array_4[3] = char_array_3[2] & 0x3f;
+
+    for (j = 0; (j < i + 1); j++)
+      ret += base64url_chars[char_array_4[j]];
+
+  }
+
+  return ret;
+}
+
+std::string base64url_encode(std::string const& s) {
+	return base64url_encode_buf((unsigned char const*)s.c_str(), (unsigned int)s.size());
 }
 
 std::string base64_decode(std::string const& encoded_string) {
@@ -142,3 +194,44 @@ std::string base64_decode(std::string const& encoded_string) {
 
   return ret;
 }
+
+std::string base64url_decode(std::string const& encoded_string) {
+  size_t in_len = encoded_string.size();
+  int i = 0;
+  int in_ = 0;
+  unsigned char char_array_4[4], char_array_3[3];
+  std::string ret;
+
+  while (in_len-- && ( encoded_string[in_] != '=') && is_base64url(encoded_string[in_])) {
+    char_array_4[i++] = encoded_string[in_]; in_++;
+    if (i ==4) {
+      for (i = 0; i <4; i++)
+        char_array_4[i] = (unsigned char)base64url_chars.find(char_array_4[i]);
+
+      char_array_3[0] = (char_array_4[0] << 2) + ((char_array_4[1] & 0x30) >> 4);
+      char_array_3[1] = ((char_array_4[1] & 0xf) << 4) + ((char_array_4[2] & 0x3c) >> 2);
+      char_array_3[2] = ((char_array_4[2] & 0x3) << 6) + char_array_4[3];
+
+      for (i = 0; (i < 3); i++)
+        ret += char_array_3[i];
+      i = 0;
+    }
+  }
+
+  if (i) {
+	  int j = 0;
+	  for (j = i; j < 4; j++)
+		char_array_4[j] = 0;
+
+    for (j = 0; j <4; j++)
+      char_array_4[j] = (unsigned char)base64url_chars.find(char_array_4[j]);
+
+    char_array_3[0] = (char_array_4[0] << 2) + ((char_array_4[1] & 0x30) >> 4);
+    char_array_3[1] = ((char_array_4[1] & 0xf) << 4) + ((char_array_4[2] & 0x3c) >> 2);
+    char_array_3[2] = ((char_array_4[2] & 0x3) << 6) + char_array_4[3];
+
+    for (j = 0; (j < i - 1); j++) ret += char_array_3[j];
+  }
+
+  return ret;
+}
