@@ -13,7 +13,7 @@
 #include "connection_manager.hpp"
 #include "request_handler.hpp"
 #include "mime_types.hpp"
-#include "../main/localtime_r.h"
+#include "../main/Helper.h"
 #include "../main/Logger.h"
 
 namespace http {
@@ -22,13 +22,13 @@ namespace http {
 		extern time_t last_write_time(const std::string& path);
 
 		// this is the constructor for plain connections
-		connection::connection(boost::asio::io_service &io_service, connection_manager &manager, request_handler &handler, int read_timeout)
+		connection::connection(boost::asio::io_context &io_context, connection_manager &manager, request_handler &handler, int read_timeout)
 			: send_buffer_(nullptr)
 			, read_timeout_(read_timeout)
-			, read_timer_(io_service, boost::posix_time::seconds(read_timeout))
+			, read_timer_(io_context, boost::posix_time::seconds(read_timeout))
 			, default_abandoned_timeout_(20 * 60)
 			// 20mn before stopping abandoned connection
-			, abandoned_timer_(io_service, boost::posix_time::seconds(default_abandoned_timeout_))
+			, abandoned_timer_(io_context, boost::posix_time::seconds(default_abandoned_timeout_))
 			, connection_manager_(manager)
 			, request_handler_(handler)
 			, status_(INITIALIZING)
@@ -39,18 +39,18 @@ namespace http {
 			keepalive_ = false;
 			write_in_progress = false;
 			connection_type = ConnectionType::connection_http;
-			socket_ = std::make_unique<boost::asio::ip::tcp::socket>(io_service);
+			socket_ = std::make_unique<boost::asio::ip::tcp::socket>(io_context);
 		}
 
 #ifdef WWW_ENABLE_SSL
 		// this is the constructor for secure connections
-		connection::connection(boost::asio::io_service &io_service, connection_manager &manager, request_handler &handler, int read_timeout, boost::asio::ssl::context &context)
+		connection::connection(boost::asio::io_context &io_context, connection_manager &manager, request_handler &handler, int read_timeout, boost::asio::ssl::context &context)
 			: send_buffer_(nullptr)
 			, read_timeout_(read_timeout)
-			, read_timer_(io_service, boost::posix_time::seconds(read_timeout))
+			, read_timer_(io_context, boost::posix_time::seconds(read_timeout))
 			, default_abandoned_timeout_(20 * 60)
 			// 20mn before stopping abandoned connection
-			, abandoned_timer_(io_service, boost::posix_time::seconds(default_abandoned_timeout_))
+			, abandoned_timer_(io_context, boost::posix_time::seconds(default_abandoned_timeout_))
 			, connection_manager_(manager)
 			, request_handler_(handler)
 			, status_(INITIALIZING)
@@ -62,7 +62,7 @@ namespace http {
 			write_in_progress = false;
 			connection_type = ConnectionType::connection_http;
 			socket_ = nullptr;
-			sslsocket_ = std::make_unique<ssl_socket>(io_service, context);
+			sslsocket_ = std::make_unique<ssl_socket>(io_context, context);
 		}
 #endif
 
@@ -86,7 +86,7 @@ namespace http {
 		void connection::start()
 		{
 			boost::system::error_code ec;
-			boost::asio::ip::tcp::endpoint endpoint = socket().remote_endpoint(ec);
+			boost::asio::ip::tcp::endpoint remote_endpoint = socket().remote_endpoint(ec);
 			if (ec) {
 				// Prevent the exception to be thrown to run to avoid the server to be locked (still listening but no more connection or stop).
 				// If the exception returns to WebServer to also create a exception loop.
@@ -94,10 +94,19 @@ namespace http {
 				connection_manager_.stop(shared_from_this());
 				return;
 			}
-			host_endpoint_address_ = endpoint.address().to_string();
-			//std::stringstream sstr;
-			//sstr << endpoint.port();
-			//sstr >> host_endpoint_port_;
+			host_remote_endpoint_address_ = remote_endpoint.address().to_string();
+			host_remote_endpoint_port_ = std::to_string(remote_endpoint.port());
+
+			boost::asio::ip::tcp::endpoint local_endpoint = socket().local_endpoint(ec);
+			if (ec) {
+				// Prevent the exception to be thrown to run to avoid the server to be locked (still listening but no more connection or stop).
+				// If the exception returns to WebServer to also create a exception loop.
+				_log.Log(LOG_ERROR, "Getting error '%s' while getting local_endpoint in connection::start", ec.message().c_str());
+				connection_manager_.stop(shared_from_this());
+				return;
+			}
+			host_local_endpoint_address_ = local_endpoint.address().to_string();
+			host_local_endpoint_port_ = std::to_string(local_endpoint.port());
 
 			set_abandoned_timeout();
 
@@ -143,9 +152,9 @@ namespace http {
 			if (error != boost::asio::error::operation_aborted) {
 				switch (connection_type) {
 				case ConnectionType::connection_http:
-					// Timers should be cancelled before stopping to remove tasks from the io_service.
-					// The io_service will stop naturally when every tasks are removed.
-					// If timers are not cancelled, the exception ERROR_ABANDONED_WAIT_0 is thrown up to the io_service::run() caller.
+					// Timers should be cancelled before stopping to remove tasks from the io_context.
+					// The io_context will stop naturally when every tasks are removed.
+					// If timers are not cancelled, the exception ERROR_ABANDONED_WAIT_0 is thrown up to the io_context::run() caller.
 					cancel_abandoned_timeout();
 					cancel_read_timeout();
 
@@ -157,7 +166,7 @@ namespace http {
 						socket().close(ignored_ec);
 					}
 					catch (...) {
-						_log.Log(LOG_ERROR, "%s -> exception thrown while stopping connection", host_endpoint_address_.c_str());
+						_log.Log(LOG_ERROR, "%s -> exception thrown while stopping connection", host_remote_endpoint_address_.c_str());
 					}
 					break;
 				case ConnectionType::connection_websocket:
@@ -179,7 +188,7 @@ namespace http {
 				}
 				else
 				{
-					// _log.Log(LOG_ERROR, "connection::handle_handshake Error: %s", error.message().c_str());
+					_log.Debug(DEBUG_WEBSERVER, "connection::handle_handshake Error: %s", error.message().c_str());
 					connection_manager_.stop(shared_from_this());
 				}
 			}
@@ -310,8 +319,8 @@ namespace http {
 
 			reply::add_header(&rep, "Cache-Control", "max-age=0, private");
 			reply::add_header(&rep, "Accept-Ranges", "bytes");
-			reply::add_header(&rep, "Date", convert_to_http_date(time(nullptr)));
-			reply::add_header(&rep, "Last-Modified", convert_to_http_date(ftime));
+			reply::add_header(&rep, "Date", make_web_time(time(nullptr)));
+			reply::add_header(&rep, "Last-Modified", make_web_time(ftime));
 			reply::add_header(&rep, "Server", "Apache/2.2.22");
 
 			std::size_t last_dot_pos = filename.find_last_of('.');
@@ -363,7 +372,7 @@ namespace http {
 				switch (connection_type)
 				{
 				case ConnectionType::connection_http:
-					begin = boost::asio::buffer_cast<const char*>(_buf.data());
+					begin = static_cast<const char*>(_buf.data().data());
 					try
 					{
 						request_parser_.reset();
@@ -372,23 +381,84 @@ namespace http {
 					}
 					catch (...)
 					{
-						_log.Log(LOG_ERROR, "Exception parsing HTTP. Address: %s", host_endpoint_address_.c_str());
+						_log.Log(LOG_ERROR, "Exception parsing HTTP. Address: %s", host_remote_endpoint_address_.c_str());
 					}
 
 					if (result) {
-						size_t sizeread = begin - boost::asio::buffer_cast<const char*>(_buf.data());
+						struct timeval tv;
+						std::time_t newt;
+
+						if(_log.IsACLFlogEnabled())
+						{
+							// Record timestamp (with milliseconds) before starting to process
+						#ifdef CLOCK_REALTIME
+							struct timespec ts;
+							if (!clock_gettime(CLOCK_REALTIME, &ts))
+							{
+								tv.tv_sec = ts.tv_sec;
+								tv.tv_usec = ts.tv_nsec / 1000;
+							}
+							else
+						#endif
+								gettimeofday(&tv, nullptr);
+							newt = std::chrono::system_clock::to_time_t(std::chrono::system_clock::now());
+						}
+
+						size_t sizeread = begin - static_cast<const char*>(_buf.data().data());
 						_buf.consume(sizeread);
 						reply_.reset();
 						const char* pConnection = request_.get_req_header(&request_, "Connection");
 						keepalive_ = pConnection != nullptr && boost::iequals(pConnection, "Keep-Alive");
 						request_.keep_alive = keepalive_;
-						request_.host_address = host_endpoint_address_;
-						request_.host_port = host_endpoint_port_;
-						if (request_.host_address.substr(0, 7) == "::ffff:") {
-							request_.host_address = request_.host_address.substr(7);
+						request_.host_remote_address = host_remote_endpoint_address_;
+						request_.host_local_address = host_local_endpoint_address_;
+						if (request_.host_remote_address.substr(0, 7) == "::ffff:") {
+							request_.host_remote_address = request_.host_remote_address.substr(7);
 						}
+						if (request_.host_local_address.substr(0, 7) == "::ffff:") {
+							request_.host_local_address = request_.host_local_address.substr(7);
+						}
+						request_.host_remote_port = host_remote_endpoint_port_;
+						request_.host_local_port = host_local_endpoint_port_;
+						host_last_request_uri_ = request_.uri;
 						request_handler_.handle_request(request_, reply_);
 
+						if(_log.IsACLFlogEnabled())	// Only do this if we are gonna use it, otherwise don't spend the compute power
+						{
+							// Generate webserver logentry
+							std::string wlHost = (reply_.originHost.empty()) ? request_.host_remote_address : reply_.originHost;
+							std::string wlUser = "-";	// Maybe we can fill this sometime? Or maybe not so we don't expose sensitive data?
+							std::string wlReqUri = request_.method + " " + request_.uri + " HTTP/" + std::to_string(request_.http_version_major) + (request_.http_version_minor ? "." + std::to_string(request_.http_version_minor): "");
+							std::string wlReqRef = "-";
+							if (request_.get_req_header(&request_, "Referer") != nullptr)
+							{
+								std::string shdr = request_.get_req_header(&request_, "Referer");
+								wlReqRef = "\"" + shdr + "\"";
+							}
+							std::string wlBrowser = "-";
+							if (request_.get_req_header(&request_, "User-Agent") != nullptr)
+							{
+								std::string shdr = request_.get_req_header(&request_, "User-Agent");
+								wlBrowser = "\"" + shdr + "\"";
+							}
+							int wlResCode = (int)reply_.status;
+							int wlContentSize = (int)reply_.content.length();
+
+							std::stringstream sstr;
+							sstr << std::setw(3) << std::setfill('0') << ((int)tv.tv_usec / 1000);
+							std::string wlReqTimeMs = sstr.str();
+
+							char wlReqTime[32];
+							std::strftime(wlReqTime, sizeof(wlReqTime), "%d/%b/%Y:%H:%M:%S", std::localtime(&newt));
+							wlReqTime[sizeof(wlReqTime) - 1] = '\0';
+
+							char wlReqTimeZone[16];
+							std::strftime(wlReqTimeZone, sizeof(wlReqTimeZone), "%z", std::localtime(&newt));
+							wlReqTimeZone[sizeof(wlReqTimeZone) - 1] = '\0';
+
+							_log.ACLFlog("%s - %s [%s.%s %s] \"%s\" %d %d %s %s", wlHost.c_str(), wlUser.c_str(), wlReqTime, wlReqTimeMs.c_str(), wlReqTimeZone, wlReqUri.c_str(), wlResCode, wlContentSize, wlReqRef.c_str(), wlBrowser.c_str());
+						}
+
 						if (reply_.status == reply::switching_protocols) {
 							// this was an upgrade request
 							connection_type = ConnectionType::connection_websocket;
@@ -435,7 +505,7 @@ namespace http {
 					}
 					else if (!result)
 					{
-						_log.Log(LOG_ERROR, "Error parsing http request address: %s", host_endpoint_address_.c_str());
+						_log.Log(LOG_ERROR, "Error parsing http request address: %s", host_remote_endpoint_address_.c_str());
 						keepalive_ = false;
 						reply_ = reply::stock_reply(reply::bad_request);
 						MyWrite(reply_.to_string(request_.method));
@@ -450,7 +520,7 @@ namespace http {
 					break;
 				case ConnectionType::connection_websocket:
 				case ConnectionType::connection_websocket_closing:
-					begin = boost::asio::buffer_cast<const char*>(_buf.data());
+					begin = static_cast<const char*>(_buf.data().data());
 					result = websocket_parser.parse((const unsigned char*)begin, _buf.size(), bytes_consumed, keepalive_);
 					_buf.consume(bytes_consumed);
 					if (result) {
@@ -537,11 +607,11 @@ namespace http {
 				boost::system::error_code ignored_ec;
 				read_timer_.cancel(ignored_ec);
 				if (ignored_ec) {
-					_log.Log(LOG_ERROR, "%s -> exception thrown while canceling read timeout : %s", host_endpoint_address_.c_str(), ignored_ec.message().c_str());
+					_log.Log(LOG_ERROR, "%s -> exception thrown while canceling read timeout : %s", host_remote_endpoint_address_.c_str(), ignored_ec.message().c_str());
 				}
 			}
 			catch (...) {
-				_log.Log(LOG_ERROR, "%s -> exception thrown while canceling read timeout", host_endpoint_address_.c_str());
+				_log.Log(LOG_ERROR, "%s -> exception thrown while canceling read timeout", host_remote_endpoint_address_.c_str());
 			}
 		}
 
@@ -580,11 +650,11 @@ namespace http {
 				boost::system::error_code ignored_ec;
 				abandoned_timer_.cancel(ignored_ec);
 				if (ignored_ec) {
-					_log.Log(LOG_ERROR, "%s -> exception thrown while canceling abandoned timeout : %s", host_endpoint_address_.c_str(), ignored_ec.message().c_str());
+					_log.Log(LOG_ERROR, "%s -> exception thrown while canceling abandoned timeout : %s", host_remote_endpoint_address_.c_str(), ignored_ec.message().c_str());
 				}
 			}
 			catch (...) {
-				_log.Log(LOG_ERROR, "%s -> exception thrown while canceling abandoned timeout", host_endpoint_address_.c_str());
+				_log.Log(LOG_ERROR, "%s -> exception thrown while canceling abandoned timeout", host_remote_endpoint_address_.c_str());
 			}
 		}
 
@@ -597,7 +667,7 @@ namespace http {
 		/// stop connection on abandoned timeout
 		void connection::handle_abandoned_timeout(const boost::system::error_code& error) {
 			if (error != boost::asio::error::operation_aborted) {
-				_log.Log(LOG_STATUS, "%s -> handle abandoned timeout (status=%d)", host_endpoint_address_.c_str(), status_);
+				_log.Log(LOG_STATUS, "%s -> handle abandoned timeout (status=%d)", host_remote_endpoint_address_.c_str(), status_);
 				connection_manager_.stop(shared_from_this());
 			}
 		}
