@@ -12,6 +12,7 @@
 #define HTTP_CONNECTION_HPP
 
 #include <boost/asio.hpp>
+#include <boost/asio/deadline_timer.hpp>
 #include <deque>
 #include <fstream>
 #include "reply.hpp"
@@ -36,11 +37,18 @@ namespace http {
 			private domoticz::noncopyable
 		{
 		public:
-			/// Construct a connection with the given io_service.
-			explicit connection(boost::asio::io_service& io_service,
+			struct _tRemoteClients
+			{
+				time_t last_seen = 0;
+				std::string host_remote_endpoint_address_;
+				std::string host_local_endpoint_port_;
+				std::string host_last_request_uri_;
+			};
+			/// Construct a connection with the given io_context.
+			explicit connection(boost::asio::io_context& io_context,
 				connection_manager& manager, request_handler& handler, int timeout);
 #ifdef WWW_ENABLE_SSL
-			explicit connection(boost::asio::io_service& io_service,
+			explicit connection(boost::asio::io_context& io_context,
 				connection_manager& manager, request_handler& handler, int timeout, boost::asio::ssl::context& context);
 #endif
 			~connection() = default;
@@ -106,9 +114,12 @@ namespace http {
 
 			/// Socket for the (PLAIN) connection.
 			std::unique_ptr<boost::asio::ip::tcp::socket> socket_;
-			//Host EndPoint
-			std::string host_endpoint_address_;
-			std::string host_endpoint_port_;
+			//Host EndPoints
+			std::string host_remote_endpoint_address_;
+			std::string host_remote_endpoint_port_;
+			std::string host_local_endpoint_address_;
+			std::string host_local_endpoint_port_;
+			std::string host_last_request_uri_;
 
 			/// If this is a keep-alive connection or not
 			bool keepalive_;
