@@ -14,6 +14,9 @@ namespace server {
 typedef struct _tWebEmStoredSession {
 	std::string id;
 	std::string remote_host;
+	std::string local_host;
+	std::string remote_port;
+	std::string local_port;
 	std::string auth_token;
 	std::string username;
 	time_t expires;
