@@ -3,8 +3,9 @@ define(['app'], function (app) {
 
 		(function init() {
 			var permissionList = {
-				isloggedin: true,
-				rights: -1
+				isloggedin: false,
+				rights: -1,
+				user: ''
 			};
 			permissions.setPermissions(permissionList);
 			$.ajax({
@@ -20,12 +21,14 @@ define(['app'], function (app) {
 							if (data.status === "OK") {
 								if (data.user !== "") {
 									permissionList.isloggedin = true;
+									permissionList.user = data.user;
+									permissionList.rights = parseInt(data.rights);
 								}
-								permissionList.rights = parseInt(data.rights, 10);
 							}
 						}
 					});
 					permissions.setPermissions(permissionList);
+					$rootScope.GetGlobalConfig();
 					window.location = '#/Dashboard';
 				},
 				error: function (xhr, status, error) {
