@@ -62,8 +62,8 @@ define(['app'], function (app) {
 
 		$scope.RefreshUserVariablesTable = function () {
 			$('#modal').show();
-			$('#uservariableupdate').attr("class", "btnstyle3-dis");
-			$('#uservariabledelete').attr("class", "btnstyle3-dis");
+			$('#uservariableupdate').hide();
+			$('#uservariabledelete').hide();
 			$("#uservariableupdate").attr("href", "");
 			$("#uservariabledelete").attr("href", "");
 
@@ -104,10 +104,11 @@ define(['app'], function (app) {
 							var addId = oTable.fnAddData({
 								"DT_RowId": item.idx,
 								"DT_ItemType": item.Type,
+								"DT_Value": item.Value,
 								"0": item.idx,
 								"1": item.Name,
 								"2": typeWording,
-								"3": item.Value,
+								"3": truncateString(item.Value, 150),
 								"4": item.LastUpdate
 							});
 						});
@@ -119,8 +120,8 @@ define(['app'], function (app) {
 			$("#uservariablestable tbody").on('click', 'tr', function () {
 				if ($(this).hasClass('row_selected')) {
 					$(this).removeClass('row_selected');
-					$('#uservariableupdate').attr("class", "btnstyle3-dis");
-					$('#uservariabledelete').attr("class", "btnstyle3-dis");
+					$('#uservariableupdate').hide();
+					$('#uservariabledelete').hide();
 					$("#uservariableupdate").attr("href", "");
 					$("#uservariabledelete").attr("href", "");
 				}
@@ -134,11 +135,11 @@ define(['app'], function (app) {
 						var idx = data["DT_RowId"];
 						$("#uservariableupdate").attr("href", "javascript:AddUpdateVariable('u', " + idx + ")");
 						$("#uservariabledelete").attr("href", "javascript:DeleteVariable(" + idx + ")");
-						$('#uservariableupdate').attr("class", "btnstyle3");
-						$('#uservariabledelete').attr("class", "btnstyle3");
+						$('#uservariableupdate').show();
+						$('#uservariabledelete').show();
 						$("#uservariablesedittable #uservariablename").val(data["1"]);
 						$("#uservariablesedittable #uservariabletype").val(data["DT_ItemType"]);
-						$("#uservariablesedittable #uservariablevalue").val(data["3"]);
+						$("#uservariablesedittable #uservariablevalue").val(data["DT_Value"]);
 					}
 				}
 			});
@@ -174,4 +175,4 @@ define(['app'], function (app) {
 			$scope.ShowUserVariables();
 		};
 	}]);
-});
\ No newline at end of file
+});
