@@ -206,7 +206,8 @@ define(['angularAMD', 'app.routes', 'app.constants', 'app.notifications', 'app.p
 					if (response && response.status === 401) {
 						var permissionList = {
 							isloggedin: false,
-							rights: -1
+							rights: -1,
+							user: ''
 						};
 						permissions.setPermissions(permissionList);
 						$location.path('/Login');
@@ -288,7 +289,8 @@ define(['angularAMD', 'app.routes', 'app.constants', 'app.notifications', 'app.p
 	app.run(function ($rootScope, $location, $window, $route, $http, dzTimeAndSun, permissions) {
 		var permissionList = {
 			isloggedin: false,
-			rights: -1
+			rights: -1,
+			user: ''
 		};
 		permissions.setPermissions(permissionList);
 
@@ -327,10 +329,12 @@ define(['angularAMD', 'app.routes', 'app.constants', 'app.notifications', 'app.p
 			if (typeof $rootScope.config.DegreeDaysBaseTemperature != 'undefined') {
 				$.myglobals.DegreeDaysBaseTemperature = $rootScope.config.DegreeDaysBaseTemperature;
 			}
+			if (typeof $rootScope.config.CurrencySign != 'undefined') {
+				$.myglobals.currencysign = $rootScope.config.CurrencySign;
+			}
 		}
 		$rootScope.currentyear = new Date().getFullYear();
 		$rootScope.config = {
-			EnableTabProxy: false,
 			EnableTabDashboard: false,
 			EnableTabFloorplans: false,
 			EnableTabLights: false,
@@ -349,6 +353,7 @@ define(['angularAMD', 'app.routes', 'app.constants', 'app.notifications', 'app.p
 			WindScale: 3.600000143051148,
 			WindSign: "km/h",
 			language: "en",
+			CurrencySign: "€",
 			HaveUpdate: false,
 			UseUpdate: true,
 			appversion: 0,
@@ -357,7 +362,8 @@ define(['angularAMD', 'app.routes', 'app.constants', 'app.notifications', 'app.p
 			pythonversion: "",
 			versiontooltip: "",
 			ShowUpdatedEffect: true,
-			DateFormat: "yy-mm-dd"
+			DateFormat: "yy-mm-dd",
+			userName: "Unknown"
 		};
 
 		$rootScope.GetGlobalConfig = function () {
@@ -378,7 +384,8 @@ define(['angularAMD', 'app.routes', 'app.constants', 'app.notifications', 'app.p
 						$rootScope.config.WindScale = data.WindScale;
 						$rootScope.config.WindSign = data.WindSign;
 						$rootScope.config.language = data.language;
-						$rootScope.config.EnableTabProxy = data.result.EnableTabProxy,
+						$rootScope.config.CurrencySign = data.CurrencySign;
+						$rootScope.config.DegreeDaysBaseTemperature = data.DegreeDaysBaseTemperature;
 						$rootScope.config.EnableTabDashboard = data.result.EnableTabDashboard,
 						$rootScope.config.EnableTabFloorplans = data.result.EnableTabFloorplans;
 						$rootScope.config.EnableTabLights = data.result.EnableTabLights;
@@ -387,13 +394,49 @@ define(['angularAMD', 'app.routes', 'app.constants', 'app.notifications', 'app.p
 						$rootScope.config.EnableTabWeather = data.result.EnableTabWeather;
 						$rootScope.config.EnableTabUtility = data.result.EnableTabUtility;
 						$rootScope.config.ShowUpdatedEffect = data.result.ShowUpdatedEffect;
-						$rootScope.config.DegreeDaysBaseTemperature = data.result.DegreeDaysBaseTemperature;
+						if (typeof data.UserName != 'undefined') {
+							$rootScope.config.userName = data.UserName;
+							$rootScope.config.appversion = data.version;
+							$rootScope.config.apphash = data.hash;
+							$rootScope.config.appdate = data.build_time;
+							$rootScope.config.dzventsversion = data.dzvents_version;
+							$rootScope.config.pythonversion = data.python_version;
+							$rootScope.config.isproxied = data.isproxied;
+							$rootScope.config.versiontooltip = "'Build Hash: <b>" + $rootScope.config.apphash + "</b><br>" + "Build Date: " + $rootScope.config.appdate + "'";
+						}
 
 						SetLanguage(data.language);
 
 						//Translate Highcharts (partly)
+						const formattedNumber = Intl.NumberFormat().format(1234.5);
+						const decimalPoint = formattedNumber[5] === '.' || formattedNumber[5] === ',' ? formattedNumber[5] : '.';
+						const thousandsSep = formattedNumber[1] === ',' || formattedNumber[1] === '.' || formattedNumber[1] === '\u00A0' ? formattedNumber[1] : ',';
+						Highcharts.Templating.helpers.abs3 = value => Math.abs(value).toFixed(3);
 						Highcharts.setOptions({
+							noData: {
+								style: {
+									fontWeight: 'bold',
+									fontSize: '15px',
+									color: '#d0d0d0'
+								}
+							},
+							accessibility: {
+								enabled: false
+							},
+							tooltip: {
+								xDateFormat: '%a %d %b, %H:%M',
+							},							
+							xAxis: {
+								dateTimeLabelFormats: {
+									minute: '%H:%M',
+									hour: '%H:%M'
+								}
+							},
 							lang: {
+								//locale: $rootScope.config.language,
+								noData: $.t('No data to display'),
+								decimalPoint: decimalPoint,
+								thousandsSep: thousandsSep,
 								months: [
 									$.t('January'),
 									$.t('February'),
@@ -442,8 +485,8 @@ define(['angularAMD', 'app.routes', 'app.constants', 'app.notifications', 'app.p
 						var customHTML = "";
 						if (typeof data.result.templates != 'undefined')  {
 							$.each(data.result.templates, function (i, item) {
-								var cFile = item;
-								var cName = cFile.charAt(0).toUpperCase() + cFile.slice(1);
+								var cFile = item.file;
+								var cName = item.name;
 								var cURL = "templates/" + cFile;
 								customHTML += '<li><a href="javascript:SwitchLayout(\'' + cURL + '\')">' + cName + '</a></li>';
 							});
@@ -459,6 +502,13 @@ define(['angularAMD', 'app.routes', 'app.constants', 'app.notifications', 'app.p
 							$("#custommenu").html(customHTML);
 							$rootScope.config.EnableTabCustom = data.result.EnableTabCustom;
 						}
+						
+						$("#appversion").text(data.version);
+						$rootScope.config.HaveUpdate = data.HaveUpdate;
+						$rootScope.config.UseUpdate = data.UseUpdate;
+						if ((data.HaveUpdate == true) && (data.UseUpdate)) {
+							ShowUpdateNotification(data.Revision, data.SystemName, data.DomoticzUpdateURL);
+						}
 					}
 				},
 				error: function () {
@@ -468,32 +518,6 @@ define(['angularAMD', 'app.routes', 'app.constants', 'app.notifications', 'app.p
 		}
 
 		$rootScope.GetGlobalConfig();
-		$.ajax({
-			url: "json.htm?type=command&param=getversion",
-			async: false,
-			dataType: 'json',
-			success: function (data) {
-			    isOnline = true;
-				if (data.status == "OK") {
-				    $rootScope.config.appversion = data.version;
-					$rootScope.config.apphash = data.hash;
-					$rootScope.config.appdate = data.build_time;
-					$rootScope.config.dzventsversion = data.dzvents_version;
-					$rootScope.config.pythonversion = data.python_version;
-					$rootScope.config.isproxied = data.isproxied;
-					$rootScope.config.versiontooltip = "'Build Hash: <b>" + $rootScope.config.apphash + "</b><br>" + "Build Date: " + $rootScope.config.appdate + "'";
-					$("#appversion").text(data.version);
-					$rootScope.config.HaveUpdate = data.HaveUpdate;
-					$rootScope.config.UseUpdate = data.UseUpdate;
-					if ((data.HaveUpdate == true) && (data.UseUpdate)) {
-						ShowUpdateNotification(data.Revision, data.SystemName, data.DomoticzUpdateURL);
-					}
-				}
-			},
-			error: function () {
-				isOnline = false;
-			}
-		});
 
 		$.ajax({
 			url: "json.htm?type=command&param=getauth",
@@ -502,9 +526,11 @@ define(['angularAMD', 'app.routes', 'app.constants', 'app.notifications', 'app.p
 			success: function (data) {
 				isOnline = true;
 				if (data.status == "OK") {
-					permissionList.isloggedin = (data.user != "");
-					permissionList.rights = parseInt(data.rights);
-					dashboardType = data.DashboardType;
+					if (data.user !== "") {
+						permissionList.isloggedin = true;
+						permissionList.rights = parseInt(data.rights);
+						permissionList.user = data.user;
+					}
 				}
 			},
 			error: function () {
@@ -550,6 +576,7 @@ define(['angularAMD', 'app.routes', 'app.constants', 'app.notifications', 'app.p
 				}
 			}
 		});
+
 		permissions.setPermissions(permissionList);
 
 		Highcharts.setOptions({
@@ -576,25 +603,51 @@ define(['angularAMD', 'app.routes', 'app.constants', 'app.notifications', 'app.p
                     fontFamily: 'Trebuchet MS, Verdana, sans-serif',
                     fontWeight: 'normal'
                 },
-				backgroundColor: '#373739'
+				//backgroundColor: '#373739'
             }
 		});
 
+		$rootScope.HandleTbLinkClick = function (fn) {
+			window[fn]();
+		};
+		$rootScope.GetRoomPlans  = function(){
+			var RoomPlans={};
+			RoomPlans = [{ idx: 0, name: $.t("All") }];
+			$.ajax({
+				url: "json.htm?type=command&param=getplans",
+				async: false,
+				dataType: 'json',
+				success: function (data) {
+					if (typeof data.result != 'undefined') {
+						var totalItems = data.result.length;
+						if (totalItems > 0) {
+							$.each(data.result, function (i, item) {
+								RoomPlans.push({
+									idx: item.idx,
+									name: item.Name
+								});
+							});
+						}
+					}
+				}
+			});
+			return RoomPlans;
+
+		}
+
+		/*
+		$rootScope.HandleTbSearch = function () {
+			WatchLiveSearch();
+		};
+		*/
+		
 		// TODO: use <timesun /> component instead
 		$rootScope.SetTimeAndSun = function (sunRise, sunSet, ServerTime) {
-			var month = ServerTime.split(' ')[0];
-			ServerTime = ServerTime.replace(month, $.t(month));
+			var mytime=ServerTime.split(' ')[1];
+			$("#jsTbTime").html(mytime);
+			$("#jsTbSunRise").html(sunRise);
+			$("#jsTbSunSet").html(sunSet);
 
-			var suntext;
-			var bIsMobile = $.myglobals.ismobile;
-			if (bIsMobile == true) {
-				suntext = '<div><font color="yellow">&#9728;</font>' + '&#9650;' + sunRise + ' ' + '&#9660;' + sunSet + '</div>';
-			}
-			else {
-				//$.t('SunRise') + $.t('SunSet')
-				suntext = '<div>' + ServerTime + ' <font color="yellow">&#9728;</font>' + '&#9650;' + sunRise + ' ' + '&#9660;' + sunSet + '</div>';
-			}
-			$("#timesun").html(suntext);
 		}
 
 		$rootScope.RefreshTimeAndSun = function (placeholder) {
@@ -609,6 +662,8 @@ define(['angularAMD', 'app.routes', 'app.constants', 'app.notifications', 'app.p
                         dzTimeAndSun.updateData(response.data);
 						$rootScope.SetTimeAndSun(data.Sunrise, data.Sunset, data.ServerTime);
 					}
+				}, function errorCallback(response) {
+					return;
 				});
 			}
 		};
