@@ -34,7 +34,7 @@ define(['app', 'livesocket'], function(app) {
         controllerAs: '$ctrl',
         controller: function($scope, deviceApi, sceneApi) {
             var $ctrl = this;
-            $ctrl.device = Object.assign($scope.device);
+            $ctrl.device = JSON.parse(JSON.stringify($scope.device));
 
             $ctrl.renameDevice = function() {
                 $ctrl.isSaving = true;
@@ -118,7 +118,7 @@ define(['app', 'livesocket'], function(app) {
                 table.on('click', '.js-include-device', function() {
                     var row = table.api().row($(this).closest('tr')).data();
                     var scope = $scope.$new(true);
-                    scope.device = row;
+                    scope.device = Object.assign({}, row);
 
                     $uibModal
                         .open(Object.assign({ scope: scope }, addDeviceModal)).result
@@ -534,9 +534,8 @@ define(['app', 'livesocket'], function(app) {
             }
 
             function loadRooms() {
-                return domoticzApi.sendRequest({
-                    type: 'plans',
-                    displayhidden: 0,
+                return domoticzApi.sendCommand('getplans', {
+                    displayhidden: 0
                 })
                     .then(domoticzApi.errorHandler)
                     .then(function(response) {
@@ -614,9 +613,9 @@ define(['app', 'livesocket'], function(app) {
         }
 
         function refreshDevices() {
-            domoticzApi.sendRequest({
-                type: 'devices',
+            domoticzApi.sendCommand('getdevices',{
                 displayhidden: 1,
+                displaydisabled: 1,
                 filter: 'all',
                 used: 'all'
             })
