@@ -1,11 +1,14 @@
 define([
     'app',
     'hardware/setup/BleBox',
+    'hardware/setup/EnOceanESP3',
     'hardware/setup/Kodi',
     'hardware/setup/MySensors',
     'hardware/setup/PanasonicTV',
     'hardware/setup/Pinger',
     'hardware/setup/WakeOnLan',
+    'hardware/setup/MQTT-AD',
+    'hardware/setup/MQTT',
     'hardware/setup/ZWave',
 ], function (app) {
     app.controller('HardwareSetupController', function ($routeParams, domoticzApi) {
@@ -15,7 +18,7 @@ define([
         function init() {
             vm.hardwareId = $routeParams.id;
 
-            domoticzApi.sendRequest({ type: 'hardware' })
+            domoticzApi.sendCommand('gethardware', {})
                 .then(domoticzApi.errorHandler)
                 .then(function (response) {
                     vm.hardware = response.result.find(function (item) {
