@@ -15,7 +15,7 @@ define(['app', 'log/Chart'], function (app) {
     app.factory('counterLogParams', function (chart) {
         return {
             chartParamsDay: chartParamsDay,
-            chartParamsWeek: chartParamsWeek,
+            chartParamsHour: chartParamsHour,
             chartParamsMonthYear: chartParamsMonthYear,
             chartParamsCompare: chartParamsCompare,
             chartParamsCompareTemplate: chartParamsCompareTemplate
@@ -28,9 +28,25 @@ define(['app', 'log/Chart'], function (app) {
                         xAxis: {
                             dateTimeLabelFormats: {
                                 day: '%a'
-                            }
+                            },
+							events: {
+								afterSetExtremes: function (event) {
+									var xMin = event.min;
+									var xMax = event.max;
+/*	
+									var chart = Highcharts.charts[4]; //need_some_help: this is not always the hour chart!?
+									var ex = chart.xAxis[0].getExtremes();
+									if (ex.min != xMin || ex.max != xMax) {
+										chart.xAxis[0].setExtremes(xMin, xMax, true, false);
+									}
+*/
+								}
+							}
                         },
                         plotOptions: {
+							column: {
+								pointPlacement: 'between'
+							},
                             series: {
                                 matchExtremes: true
                             }
@@ -56,31 +72,46 @@ define(['app', 'log/Chart'], function (app) {
             );
         }
 
-        function chartParamsWeek(domoticzGlobals, ctrl, chartParamsTemplate, dataSupplierTemplate, seriesSuppliers) {
+        function chartParamsHour(domoticzGlobals, ctrl, chartParamsTemplate, dataSupplierTemplate, seriesSuppliers) {
             return _.merge(
                 {
                     highchartTemplate: {
-                        chart: {
-                            type: 'column',
-                            zoomType: false,
-                            marginRight: 10
-                        },
                         xAxis: {
                             dateTimeLabelFormats: {
-                                day: '%a'
+                                hour: '%H:00',
+                                day: '%H:00'
                             },
-                            tickInterval: 24 * 3600 * 1000
+							events: {
+								afterSetExtremes: function (event) {
+									var xMin = event.min;
+									var xMax = event.max;
+/*									
+									var chart = Highcharts.charts[0]; //need_some_help: this is not always the day chart!?
+									var ex = chart.xAxis[0].getExtremes();
+									if (ex.min != xMin || ex.max != xMax) {
+										chart.xAxis[0].setExtremes(xMin, xMax, true, false);
+									}
+*/
+								}
+							},
+                            tickInterval: 1 * 3600 * 1000
                         },
                         tooltip: {
-                            shared: false,
                             crosshairs: false
-                        }
+                        },
+						plotOptions: {
+							column: {
+								grouping: false,
+								shadow: false,
+								borderWidth: 0
+							}
+						}
                     },
                     ctrl: ctrl,
                     range: ctrl.range,
                     device: ctrl.device,
                     sensorType: 'counter',
-                    chartName: ctrl.device.SwitchTypeVal === chart.deviceTypes.EnergyGenerated ? $.t('Generated') : $.t('Usage'),
+                    chartName: $.t('Usage') + ' / ' + $.t('Hour'),
                     autoRefreshIsEnabled: function () {
                         return ctrl.logCtrl.autoRefresh;
                     },
@@ -100,12 +131,14 @@ define(['app', 'log/Chart'], function (app) {
             return _.merge(
                 {
                     highchartTemplate: {
-                        chart: {
-                            marginRight: 10
-                        },
                         tooltip: {
                             crosshairs: false
-                        }
+                        },
+						plotOptions: {
+							column: {
+								pointPlacement: 0
+							}
+						}
                     },
                     ctrl: ctrl,
                     range: ctrl.range,
@@ -174,7 +207,7 @@ define(['app', 'log/Chart'], function (app) {
         function chartParamsCompareTemplate(ctrl, deviceUnit) {
             const deviceType = ctrl.device.SwitchTypeVal;
             const template = {
-                chartName: $.t('Comparing') + ' ' + $.t(deviceType === chart.deviceTypes.EnergyUsed ? 'Usage' : deviceType === chart.deviceTypes.EnergyGenerated ? 'Generated' : chart.deviceTypes.fromIndex(deviceType)),
+                chartName: ($.t('Comparing') + ' ' + $.t(deviceType === chart.deviceTypes.EnergyUsed ? 'Usage' : deviceType === chart.deviceTypes.EnergyGenerated ? 'Generated' : '')).trim(),
                 trendValuationIsReversed: function () {
                     return deviceType === chart.deviceTypes.EnergyGenerated;
                 },
@@ -199,7 +232,7 @@ define(['app', 'log/Chart'], function (app) {
                         formatter: function () {
                             return ''
                                 + '<table>'
-                                + '<tr><td colspan="2"><b>' + categoryKeyToString(this.x) + '</b></td></tr>'
+                                + '<tr><td colspan="2"><b>' + categoryKeyToStringEx(this.x) + '</b></td></tr>'
                                 + this.points.reduce(
                                     function (rowsHtml, point) {
                                         return rowsHtml
@@ -275,27 +308,42 @@ define(['app', 'log/Chart'], function (app) {
             };
             return template;
 
-            function categoryKeyToString(categoryKey) {
-                return ctrl.groupingBy === 'month' ? monthToString(categoryKey) : categoryKey;
-            }
+			function categoryKeyToString(categoryKey) {
+				if (ctrl.groupingBy === 'month') {
+					return monthToString(parseInt(categoryKey));
+				}
+				return categoryKey;
+			}
 
-            function monthToString(month) {
-                const months = {
-                    '01': $.t('Jan'),
-                    '02': $.t('Feb'),
-                    '03': $.t('Mar'),
-                    '04': $.t('Apr'),
-                    '05': $.t('May'),
-                    '06': $.t('Jun'),
-                    '07': $.t('Jul'),
-                    '08': $.t('Aug'),
-                    '09': $.t('Sep'),
-                    '10': $.t('Oct'),
-                    '11': $.t('Nov'),
-                    '12': $.t('Dec'),
-                };
-                return months[month];
-            }
-        }
+			function categoryKeyToStringEx(categoryKey) {
+				if (ctrl.groupingBy === 'month') {
+					return monthToString(parseInt(categoryKey)+1);
+				} else if (ctrl.groupingBy === 'quarter') {
+					return 'Q' + (parseInt(categoryKey)+1).toString();
+				} else if (ctrl.groupingBy === 'year') {
+					return parseInt(ctrl.chart.seriesSuppliers[0].id) + parseInt(categoryKey);
+				} else {
+					return categoryKey;
+				}
+			}
+
+			function monthToString(month) {
+				const months = {
+					1: $.t('Jan'),
+					2: $.t('Feb'),
+					3: $.t('Mar'),
+					4: $.t('Apr'),
+					5: $.t('May'),
+					6: $.t('Jun'),
+					7: $.t('Jul'),
+					8: $.t('Aug'),
+					9: $.t('Sep'),
+					10: $.t('Oct'),
+					11: $.t('Nov'),
+					12: $.t('Dec'),
+				};
+				return months[month];
+			}
+        }		
     });
-});
\ No newline at end of file
+});
