@@ -1,14 +1,23 @@
-define(['app', 'log/TextLog', 'log/TemperatureLog', 'log/LightLog', 'log/GraphLog', 'log/CounterLog', 'log/CounterLogInstantAndCounter', 'log/CounterLogP1Energy'], function (app) {
-    app.controller('DeviceLogController', function ($location, $routeParams, domoticzApi, deviceApi, counterLogSubtypeRegistry) {
+define(['app', 'log/Chart', 'log/TextLog', 'log/TemperatureLog', 'log/LightLog', 'log/GraphLog', 'log/CounterLog', 'log/CounterLogCounter', 'log/CounterLogInstantAndCounter', 'log/CounterLogP1Energy', 'log/RainLog', 'log/SetpointLog'], function (app) {
+    app.controller('DeviceLogController', function ($location, $routeParams, domoticzApi, deviceApi, chart) {
         var vm = this;
 
         vm.isTextLog = isTextLog;
         vm.isLightLog = isLightLog;
         vm.isGraphLog = isGraphLog;
+		vm.isRainLog = isRainLog;
         vm.isTemperatureLog = isTemperatureLog;
+        vm.isSetpointLog = isSetpointLog;
         vm.isReportAvailable = isReportAvailable;
         vm.isInstantAndCounterLog = isInstantAndCounterLog;
         vm.isP1EnergyLog = isP1EnergyLog;
+        vm.isCounterLog = isCounterLog;
+        vm.isEnergyUsedDevice = isEnergyUsedDevice;
+        vm.isGasDevice = isGasDevice;
+        vm.isWaterDevice = isWaterDevice;
+        vm.isCounterDevice = isCounterDevice;
+        vm.isEnergyGeneratedDevice = isEnergyGeneratedDevice;
+        vm.isTimeDevice = isTimeDevice;
 
         init();
 
@@ -19,7 +28,8 @@ define(['app', 'log/TextLog', 'log/TemperatureLog', 'log/LightLog', 'log/GraphLo
                 vm.device = device;
                 vm.pageName = device.Name;
 
-                if (isCounterLog()) {
+                // TODO REMOVE THIS false
+                if (false && isCounterLog()) {
                     ShowCounterLog('.js-device-log-content', 'ShowUtilities', device.idx, device.Name, device.SwitchTypeVal);
                 }
             });
@@ -40,7 +50,7 @@ define(['app', 'log/TextLog', 'log/TemperatureLog', 'log/LightLog', 'log/GraphLo
             }
 
             if (vm.device.Type === 'Heating') {
-                return ((vm.device.SubType != 'Zone') && (vm.device.SubType != 'Hot Water'));
+                return ((vm.device.SubType !== 'Zone') && (vm.device.SubType !== 'Hot Water'));
             }
 
             var isLightType = [
@@ -65,13 +75,19 @@ define(['app', 'log/TextLog', 'log/TemperatureLog', 'log/LightLog', 'log/GraphLo
             if (vm.device.Type === 'Heating') {
                 return ((vm.device.SubType === 'Zone') || (vm.device.SubType === 'Hot Water'));
             }
-
             //This goes wrong (when we also use this log call from the weather tab), for wind sensors
             //as this is placed in weather and temperature, we might have to set a parameter in the url
             //for now, we assume it is a temperature
             return (/Temp|Thermostat|Humidity|RFXSensor|Radiator|Wind/i).test(vm.device.Type)
         }
 
+        function isSetpointLog() {
+            if (!vm.device) {
+                return undefined;
+            }
+            return (/Setpoint/i).test(vm.device.Type)
+        }
+
         function isGraphLog() {
             if (!vm.device) {
                 return undefined;
@@ -84,12 +100,19 @@ define(['app', 'log/TextLog', 'log/TemperatureLog', 'log/LightLog', 'log/GraphLo
             ].includes(vm.device.SubType)
         }
 
+        function isRainLog() {
+            if (!vm.device) {
+                return undefined;
+            }
+            return (vm.device.Type === 'Rain');
+        }
+
         function isP1EnergyLog() {
             if (!vm.device) {
                 return undefined;
             }
 
-            return (vm.device.Type == 'P1 Smart Meter' && vm.device.SubType == 'Energy')
+            return (vm.device.Type === 'P1 Smart Meter' && vm.device.SubType === 'Energy')
         }
 
         function isCounterLog() {
@@ -104,10 +127,34 @@ define(['app', 'log/TextLog', 'log/TemperatureLog', 'log/LightLog', 'log/GraphLo
             }
 
             return vm.device.Type === 'RFXMeter'
-                || (vm.device.Type == 'P1 Smart Meter' && vm.device.SubType == 'Gas')
+                || (vm.device.Type === 'P1 Smart Meter' && vm.device.SubType === 'Gas')
                 || (typeof vm.device.Counter != 'undefined' && !isInstantAndCounterLog());
         }
 
+        function isEnergyUsedDevice() {
+            return vm.device.SwitchTypeVal === chart.deviceTypes.EnergyUsed;
+        }
+
+        function isGasDevice() {
+            return vm.device.SwitchTypeVal === chart.deviceTypes.Gas;
+        }
+
+        function isWaterDevice() {
+            return vm.device.SwitchTypeVal === chart.deviceTypes.Water;
+        }
+
+        function isCounterDevice() {
+            return vm.device.SwitchTypeVal === chart.deviceTypes.Counter;
+        }
+
+        function isEnergyGeneratedDevice() {
+            return vm.device.SwitchTypeVal === chart.deviceTypes.EnergyGenerated;
+        }
+
+        function isTimeDevice() {
+            return vm.device.SwitchTypeVal === chart.deviceTypes.Time;
+        }
+
         function isInstantAndCounterLog() {
             if (!vm.device) {
                 return undefined;
@@ -118,7 +165,7 @@ define(['app', 'log/TextLog', 'log/TemperatureLog', 'log/LightLog', 'log/GraphLo
 
             return ['Power', 'Energy'].includes(vm.device.Type)
                 || ['kWh'].includes(vm.device.SubType)
-                || (vm.device.Type == 'YouLess Meter' && [0, 4].includes(vm.device.SwitchTypeVal));
+                || (vm.device.Type === 'YouLess Meter' && [0, 4].includes(vm.device.SwitchTypeVal));
         }
 
         function isReportAvailable() {
