@@ -1,4 +1,4 @@
-define(['app', 'RefreshingChart', 'log/factories'], function (app, RefreshingChart) {
+define(['app', 'RefreshingChart', 'DataLoader', 'ChartLoader', 'log/Chart', 'log/factories'], function (app, RefreshingChart, DataLoader, ChartLoader) {
 
     app.component('deviceTemperatureLog', {
         bindings: {
@@ -100,10 +100,10 @@ define(['app', 'RefreshingChart', 'log/factories'], function (app, RefreshingCha
                                 setpointAverageSeriesSupplier(),
                                 setpointRangeSeriesSupplier(),
                                 setpointPreviousSeriesSupplier(),
-                                temperatureAverageSeriesSupplier(),
-                                temperatureRangeSeriesSupplier(),
+                                temperatureAverageSeriesSupplier(self.device.Type),
+                                temperatureRangeSeriesSupplier(self.device.Type),
                                 temperaturePreviousSeriesSupplier(),
-                                temperatureTrendlineSeriesSupplier()
+                                temperatureTrendlineSeriesSupplier(self.device.Type)
                             ]
                         )
                     );
@@ -111,14 +111,112 @@ define(['app', 'RefreshingChart', 'log/factories'], function (app, RefreshingCha
             }
         }
     });
+	
+	changeCompType = function() {
+			alert("Change!!");
+	}
+
+    app.directive('temperatureCompareChart', function () {
+        return {
+            require: {
+                logCtrl: '^deviceTemperatureLog'
+            },
+            scope: {
+                device: '<',
+                degreeType: '<',
+                range: '@'
+            },
+            templateUrl: function($element, $attrs) { return 'app/log/chart-' + $attrs.range + '-temp.html'; },
+            replace: true,
+            bindToController: true,
+            controllerAs: 'vm',
+            controller: function ($location, $route, $scope, $timeout, $element, domoticzGlobals, domoticzApi, domoticzDataPointApi, chart) {
+                const self = this;
+				self.groupingBy = 'month';
+				//self.deviceType = this.device.Type;
+				//console.log(self.deviceType);
+                self.sensorType = 'temp';
+				self.var_name = 'Temp_Avg';
+				self.valueSuffix = degreeSuffix;
+
+                self.$onInit = function() {
+					let bIsHumidity = (this.device.Type === 'Humidity');
+					if (bIsHumidity) {
+						self.sensorType = 'hum';
+						self.var_name = 'Humidity';
+						self.valueSuffix = '%';
+					}
+					
+                    self.chart = new RefreshingChart(
+                        chart.baseParams($),
+                        chart.angularParams($location, $route, $scope, $timeout, $element),
+                        chart.domoticzParams(domoticzGlobals, domoticzApi, domoticzDataPointApi),
+						chart.chartParamsCompare(
+							domoticzGlobals,
+							self,
+							chart.chartParamsCompareTemplate(self, 'Temperature', self.valueSuffix),
+                            {
+                                isShortLogChart: false,
+                                yAxes: [{
+											title: {
+												text: (!bIsHumidity) ? $.t('Degrees') : $.t('Humidity') + ' ' + self.valueSuffix
+											}
+										}],
+                                extendDataRequest: function (dataRequest) {
+                                    dataRequest['groupby'] = self.groupingBy;
+									dataRequest['var_name'] = self.var_name;
+                                    return dataRequest;
+                                },
+                                preprocessData: function (data) {
+                                    this.firstYear = data.firstYear;
+                                    this.categories = categoriesFromGroupingBy.call(this, self.groupingBy);
+                                    if (self.chart.chart.xAxis[0].categories === true) {
+                                        self.chart.chart.xAxis[0].categories = [];
+                                    } else {
+                                        self.chart.chart.xAxis[0].categories.length = 0;
+                                    }
+                                    this.categories.forEach(function (c) {
+                                        self.chart.chart.xAxis[0].categories.push(c); });
+
+                                    function categoriesFromGroupingBy(groupingBy) {
+                                        if (groupingBy === 'year') {
+                                            if (this.firstYear === undefined) {
+                                                return [];
+                                            }
+                                            return _.range(this.firstYear, new Date().getFullYear() + 1).map(year => year.toString());
+                                        } else if (groupingBy === 'quarter') {
+                                            return ['Q1', 'Q2', 'Q3', 'Q4'];
+                                        } else if (groupingBy === 'month') {
+                                            return _.range(1, 13).map(month => pad2(month));
+                                        }
+
+                                        function pad2(i) {
+                                            return (i < 10 ? '0' : '') + i.toString();
+                                        }
+                                    }
+                                },
+                            },
+                            chart.compareSeriesSuppliers(self)
+                        ),
+                        new DataLoader(),
+                        new ChartLoader($location),
+                        null
+                    );
+                };
+            }
+        }
+    });
 
     function humiditySeriesSupplier() {
         return {
             id: 'humidity',
             dataItemKeys: ['hu'],
+            showWithoutDatapoints: false,
+            label: 'Hu',
             template: {
                 name: $.t('Humidity'),
                 color: 'limegreen',
+				type: 'spline',
                 yAxis: 1,
                 tooltip: {
                     valueSuffix: ' %',
@@ -132,6 +230,8 @@ define(['app', 'RefreshingChart', 'log/factories'], function (app, RefreshingCha
         return {
             id: 'chill',
             dataItemKeys: ['ch'],
+            showWithoutDatapoints: false,
+            label: 'Ch',
             template: {
                 name: $.t('Chill'),
                 color: 'red',
@@ -139,7 +239,6 @@ define(['app', 'RefreshingChart', 'log/factories'], function (app, RefreshingCha
                 zIndex: 1,
                 tooltip: {
                     valueSuffix: ' ' + degreeSuffix,
-                    valueDecimals: 1
                 }
             }
         };
@@ -149,6 +248,8 @@ define(['app', 'RefreshingChart', 'log/factories'], function (app, RefreshingCha
         return {
             id: 'setpoint',
             dataItemKeys: ['se'],
+            showWithoutDatapoints: false,
+            label: 'Se',
             template: {
                 name: $.t('Set Point'),
                 color: 'blue',
@@ -166,14 +267,15 @@ define(['app', 'RefreshingChart', 'log/factories'], function (app, RefreshingCha
         return {
             id: 'temperature',
             dataItemKeys: ['te'],
+			showWithoutDatapoints: (deviceType !== 'Humidity'),
+            label: 'Te',
             template: {
                 name: $.t('Temperature'),
                 color: 'yellow',
                 yAxis: 0,
-                step: deviceType === 'Thermostat' ? 'left' : undefined,
+                step: deviceType === 'Setpoint' ? 'left' : undefined,
                 tooltip: {
                     valueSuffix: ' ' + degreeSuffix,
-                    valueDecimals: 1
                 }
             }
         };
@@ -183,9 +285,11 @@ define(['app', 'RefreshingChart', 'log/factories'], function (app, RefreshingCha
         return {
             id: 'chillmin',
             dataItemKeys: ['cm'],
-            dataItemIsValid: function (dataItem) {
+            dataItemIsComplete: function (dataItem) {
                 return dataItem.ch !== undefined;
             },
+            showWithoutDatapoints: false,
+            label: 'Cm',
             template: {
                 name: $.t('Chill') + ' ' + $.t('Minimum'),
                 color: 'rgba(255,127,39,0.8)',
@@ -193,7 +297,6 @@ define(['app', 'RefreshingChart', 'log/factories'], function (app, RefreshingCha
                 zIndex: 1,
                 tooltip: {
                     valueSuffix: ' ' + degreeSuffix,
-                    valueDecimals: 1
                 },
                 yAxis: 0
             }
@@ -204,6 +307,8 @@ define(['app', 'RefreshingChart', 'log/factories'], function (app, RefreshingCha
         return {
             id: 'setpointavg',
             dataItemKeys: ['se'],
+            showWithoutDatapoints: false,
+            label: 'Sa',
             template: {
                 name: $.t('Set Point') + ' ' + $.t('Average'),
                 color: 'blue',
@@ -222,9 +327,11 @@ define(['app', 'RefreshingChart', 'log/factories'], function (app, RefreshingCha
         return {
             id: 'setpointrange',
             dataItemKeys: ['sm', 'sx'],
-            dataItemIsValid: function (dataItem) {
+            dataItemIsComplete: function (dataItem) {
                 return dataItem.se !== undefined;
             },
+            showWithoutDatapoints: false,
+            label: 'Sr',
             template: {
                 name: $.t('Set Point') + ' ' + $.t('Range'),
                 color: 'rgba(164,75,148,1.0)',
@@ -247,6 +354,8 @@ define(['app', 'RefreshingChart', 'log/factories'], function (app, RefreshingCha
             id: 'prev_setpoint',
             dataItemKeys: ['se'],
             useDataItemsFromPrevious: true,
+            showWithoutDatapoints: false,
+            label: 'Sp',
             template: {
                 name: $.t('Past') + ' ' + $.t('Set Point'),
                 color: 'rgba(223,212,246,0.8)',
@@ -261,13 +370,15 @@ define(['app', 'RefreshingChart', 'log/factories'], function (app, RefreshingCha
         };
     }
 
-    function temperatureAverageSeriesSupplier() {
+    function temperatureAverageSeriesSupplier(deviceType) {
         return {
             id: 'temperature_avg',
             dataItemKeys: ['ta'],
-            dataItemIsValid: function (dataItem) {
+			showWithoutDatapoints: (deviceType !== 'Humidity'),
+            dataItemIsComplete: function (dataItem) {
                 return dataItem.te !== undefined && dataItem.ta !== undefined;
             },
+            label: 'Ta',
             template: {
                 name: $.t('Temperature') + ' ' + $.t('Average'),
                 color: 'yellow',
@@ -282,13 +393,15 @@ define(['app', 'RefreshingChart', 'log/factories'], function (app, RefreshingCha
         };
     }
 
-    function temperatureRangeSeriesSupplier() {
+    function temperatureRangeSeriesSupplier(deviceType) {
         return {
             id: 'temperature',
             dataItemKeys: ['tm', 'te'],
-            dataItemIsValid: function (dataItem) {
+			showWithoutDatapoints: (deviceType !== 'Humidity'),
+            dataItemIsComplete: function (dataItem) {
                 return dataItem.te !== undefined;
             },
+            label: 'Tr',
             template: {
                 name: $.t('Temperature') + ' ' + $.t('Range'),
                 color: 'rgba(3,190,252,1.0)',
@@ -300,7 +413,6 @@ define(['app', 'RefreshingChart', 'log/factories'], function (app, RefreshingCha
                 yAxis: 0,
                 tooltip: {
                     valueSuffix: ' ' + degreeSuffix,
-                    valueDecimals: 1
                 }
             }
         };
@@ -311,6 +423,8 @@ define(['app', 'RefreshingChart', 'log/factories'], function (app, RefreshingCha
             id: 'prev_temperature',
             dataItemKeys: ['ta'],
             useDataItemsFromPrevious: true,
+            showWithoutDatapoints: false,
+            label: 'Tp',
             template: {
                 name: $.t('Past') + ' ' + $.t('Temperature'),
                 color: 'rgba(224,224,230,0.8)',
@@ -325,14 +439,15 @@ define(['app', 'RefreshingChart', 'log/factories'], function (app, RefreshingCha
         };
     }
 
-    function temperatureTrendlineSeriesSupplier() {
+    function temperatureTrendlineSeriesSupplier(deviceType) {
         return {
             id: 'temp_trendline',
             dataItemKeys: ['ta'],
-            dataItemIsValid: function (dataItem) {
+			showWithoutDatapoints: (deviceType !== 'Humidity'),
+            dataItemIsComplete: function (dataItem) {
                 return dataItem.te !== undefined && dataItem.ta !== undefined;
             },
-            aggregateDatapoints: function (datapoints) {
+            postprocessDatapoints: function (datapoints) {
                 const trendline = CalculateTrendLine(datapoints);
                 datapoints.length = 0;
                 if (trendline !== undefined) {
@@ -340,12 +455,12 @@ define(['app', 'RefreshingChart', 'log/factories'], function (app, RefreshingCha
                     datapoints.push([trendline.x1, trendline.y1]);
                 }
             },
+            label: 'Tt',
             template: {
                 name: $.t('Trendline') + ' ' + $.t('Temperature'),
                 zIndex: 1,
                 tooltip: {
                     valueSuffix: ' ' + degreeSuffix,
-                    valueDecimals: 1
                 },
                 color: 'rgba(255,3,3,0.8)',
                 dashStyle: 'LongDash',
@@ -380,18 +495,20 @@ define(['app', 'RefreshingChart', 'log/factories'], function (app, RefreshingCha
         return {
             highchartTemplate: {
                 chart: {
-                    type: ctrl.device.Type === 'Thermostat' ? 'line' : undefined
+                    type: ctrl.device.Type === 'Setpoint' ? 'line' : undefined
                 }
             },
+            ctrl: ctrl,
             range: ctrl.range,
             device: ctrl.device,
             sensorType: ctrl.sensorType,
-            chartName: ctrl.device.Type === 'Humidity' ? $.t('Humidity') : $.t('Temperature'),
+            chartName:  (ctrl.device.Type === 'Humidity') ? $.t('Humidity') : $.t('Temperature'),
             autoRefreshIsEnabled: function() { return ctrl.logCtrl.autoRefresh; },
             dataSupplier: {
                 yAxes:
                     [
                         {
+							visible: (ctrl.device.Type !== 'Humidity'),
                             title: {
                                 text: $.t('Degrees') + ' \u00B0' + ctrl.degreeType
                             },
@@ -415,7 +532,7 @@ define(['app', 'RefreshingChart', 'log/factories'], function (app, RefreshingCha
                             ceiling: 100,			//max limit for auto zoom, bug in highcharts makes this sometimes not considered.
                             floor: 0,				//min limit for auto zoom
                             minRange: 10,			//min range for auto zoom
-                            opposite: true
+                            opposite: (ctrl.device.Type !== 'Humidity')
                         }
                     ],
                 timestampFromDataItem: timestampFromDataItem,
