@@ -5,10 +5,9 @@ define(['app', 'report/helpers'], function (app, reportHelpers) {
         };
 
         function fetch(device, year, month) {
-            var costs = domoticzApi.sendCommand('getcosts', { idx: device.idx });
+			var costs = domoticzApi.sendCommand('getcosts', { idx: device.idx });
 
-            var stats = domoticzApi.sendRequest({
-                type: 'graph',
+            var stats = domoticzApi.sendCommand('graph', {
                 sensor: 'counter',
                 range: 'year',
                 idx: device.idx,
@@ -18,6 +17,7 @@ define(['app', 'report/helpers'], function (app, reportHelpers) {
 
             return $q.all([costs, stats]).then(function (responses) {
                 var cost = getCost(device, responses[0]);
+
                 var stats = responses[1];
 
                 if (!stats.result || !stats.result.length) {
@@ -34,10 +34,11 @@ define(['app', 'report/helpers'], function (app, reportHelpers) {
                 if (!source) {
                     return null;
                 }
-
+				
                 return {
                     cost: source.cost,
                     usage: source.usage,
+                    decimals: (device.SwitchTypeVal === 3) ? device.Divider.numDecimalsDiv1() : 3,
                     counter: month ? source.counter : parseFloat(stats.counter),
                     items: month ? source.days : source.months
                 };
@@ -79,13 +80,16 @@ define(['app', 'report/helpers'], function (app, reportHelpers) {
                     }
                 }
 
+				let cprice = parseFloat(item.p);
+
                 result.years[year].months[month].days[day] = {
                     date: item.d,
                     usage: parseFloat(item.v),
                     counter: parseFloat(item.c),
-                    cost: parseFloat(item.v) * cost
+                    cost: (cprice) != 0 ? cprice : parseFloat(item.v) * cost
                 }
             });
+			console.log(result);
 
             Object.keys(result.years).forEach(function (year) {
                 var yearsData = result.years[year];
@@ -147,11 +151,15 @@ define(['app', 'report/helpers'], function (app, reportHelpers) {
 
         function init() {
             vm.unit = vm.device.getUnit();
+            vm.decimals = (vm.device.SwitchTypeVal == 3) ? vm.device.Divider.numDecimalsDiv1() : 3;
             vm.isMonthView = vm.selectedMonth > 0;
 
+			$.devIdx = vm.device.idx;
+
             getData();
         }
-
+        
+       
         function getData() {
             DeviceCounterReportData
                 .fetch(vm.device, vm.selectedYear, vm.selectedMonth)
@@ -171,12 +179,15 @@ define(['app', 'report/helpers'], function (app, reportHelpers) {
             var table = $element.find('#reporttable');
             var columns = [];
 
-            var counterRenderer = function (data) {
+            var counterRendererDecimals = function (data) {
                 return data.toFixed(3);
             };
+            var counterRenderer = function (data) {
+                return data.toFixed(vm.device.Divider.numDecimalsDiv1());
+            };
 
             var costRenderer = function (data) {
-                return data.toFixed(2);
+                return data.toFixed(2) + ' ' + $.myglobals.currencysign;
             };
 
             if (vm.isMonthView) {
@@ -208,12 +219,12 @@ define(['app', 'report/helpers'], function (app, reportHelpers) {
             }
 
             if (vm.isMonthView && !vm.isOnlyUsage) {
-                columns.push({ title: $.t('Counter'), data: 'counter', render: counterRenderer });
+                columns.push({ title: $.t('Counter'), data: 'counter', render: (vm.device.SwitchTypeVal === 3) ? counterRenderer : counterRendererDecimals });
             }
 
-            columns.push({ title: (vm.device.SwitchTypeVal === 4) ? $.t('Generated') : $.t('Usage'), data: 'usage', render: counterRenderer });
+            columns.push({ title: (vm.device.SwitchTypeVal === 4) ? $.t('Generated') : $.t('Usage'), data: 'usage', render: (vm.device.SwitchTypeVal === 3) ? counterRenderer : counterRendererDecimals });
 
-            if (!['Counter Incremental'].includes(vm.device.SubType) && (vm.device.SwitchTypeVal != 3))
+            if (vm.device.SwitchTypeVal != 3)
                 columns.push({ title: (vm.device.SwitchTypeVal === 4) ? $.t('Earnings') : $.t('Costs'), data: 'cost', render: costRenderer });
 
             columns.push({
@@ -221,9 +232,9 @@ define(['app', 'report/helpers'], function (app, reportHelpers) {
                 orderable: false,
                 data: 'trend',
                 render: function (data) {
-					var ret='<img src="images/';
-					if (vm.device.SwitchTypeVal === 4) ret+="g";
-					ret+=data + '.png">';
+                    var ret='<img src="images/';
+                    if (vm.device.SwitchTypeVal === 4) ret+="g";
+                    ret+=data + '.png">';
                     return ret;
                 }
             });
@@ -240,10 +251,14 @@ define(['app', 'report/helpers'], function (app, reportHelpers) {
                 .draw();
         }
 
+		function reloadPage() {
+			window.location.reload();
+		}
+
         function showUsageChart(data) {
             var chartElement = $element.find('#usagegraph');
             var series = [];
-            var valueQuantity = "Count";
+            var valueQuantity = "Custom";
             if (typeof vm.device.ValueQuantity != 'undefined') {
                     valueQuantity = vm.device.ValueQuantity;
             }
@@ -259,10 +274,36 @@ define(['app', 'report/helpers'], function (app, reportHelpers) {
                 data: data.items.map(function (item) {
                     return {
                         x: +(new Date(item.date)),
-                        y: parseFloat(item.usage.toFixed(3))
+                        y: parseFloat(item.usage.toFixed(vm.decimals))
                     }
                 })
             });
+			if (vm.device.SwitchTypeVal != 3) {
+				series.push({
+					id: 'CRP',
+					type: 'spline',
+					name: $.t('Costs'),
+					zIndex: 3,
+					tooltip: {
+						valueSuffix: ' ' + $.myglobals.currencysign
+					},
+					marker: {
+						enabled: false
+					},
+					lineWidth: 2,
+					color: 'rgba(190,252,60,0.8)',
+					showInLegend: true,
+					convertZeroToNull: true,
+					showWithoutDatapoints: false,
+					yAxis: 1,
+					data: data.items.map(function (item) {
+						return {
+							x: +(new Date(item.date)),
+							y: parseFloat(item.cost.toFixed(vm.decimals))
+						}
+					})
+				});
+			}
 
             chartElement.highcharts({
                 chart: {
@@ -274,24 +315,52 @@ define(['app', 'report/helpers'], function (app, reportHelpers) {
                 xAxis: {
                     type: 'datetime'
                 },
-                yAxis: {
-                    title: {
-                        text: $.t(yAxisName) + ' (' + vm.unit + ')'
-                    },
-                    maxPadding: 0.2,
-                    min: 0
-                },
+                yAxis: [{
+						labels: {
+							formatter: function () {
+								return Highcharts.numberFormat(this.value, 0, '', '');
+							}
+						},
+						title: {
+							text: $.t(yAxisName) + ' (' + vm.unit + ')'
+						},
+						maxPadding: 0.2,
+						//min: 0
+					},
+                    {
+						visible: true,
+						showEmpty: false,
+						opposite: true,
+                        title: {
+                            text: $.t('Price') + ' (' + $.myglobals.currencysign + ')'
+                        }
+                    }
+				],
                 tooltip: {
                     valueSuffix: ' ' + vm.unit,
-                    valueDecimals: 3
+                    valueDecimals: vm.decimals,
+					outside: true,
+					crosshairs: true,
+					shared: true
                 },
                 plotOptions: {
+					series: {
+						point: {
+							events: {
+								click: function (event) {
+									if (vm.isMonthView) {
+										chartPointClickNew(event, false, reloadPage);
+									}
+								}
+							}
+						}
+					},
                     column: {
                         minPointLength: 4,
                         pointPadding: 0.1,
                         groupPadding: 0,
                         dataLabels: {
-                            enabled: true,
+                            enabled: !vm.isMonthView,
                             color: 'white'
                         }
                     }
